!function(e){var t={};function n(r){if(t[r])return t[r].exports;var i=t[r]={i:r,l:!1,exports:{}};return e[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var i in e)n.d(r,i,function(t){return e[t]}.bind(null,i));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=268)}({1:function(e,t,n){var r=n(14),i=n(81);void 0===i.jQuery&&(i.jQuery=r),e.exports=r},131:function(e,t,n){var r,i;!function(o,s){"use strict";void 0===(i="function"==typeof(r=function(){var e="1.5.1",t=Array.prototype.slice;function n(e,t){var n;for(n in t)t.hasOwnProperty(n)&&(void 0===t[n]?delete e[n]:e[n]=t[n]);return e}function r(e,t){var n;for(n=0;n<e.length;n+=1)if(e[n]===t)return n;return-1}function i(e,t){var n=r(e,t);return-1!==n?e.splice(n,1):[]}function o(e){return void 0!==e&&void 0!==e.requireExpects&&e.requireExpects}function s(e){return!!e.result}function a(e){return!s(e)}function u(e){return a(e)&&void 0===e.expected&&void 0===e.actual}function l(e){return e.replace(/(\r?\n)/g,"$&# ")}function c(e){return e.replace(/^\s+/,"")}function f(e){return e}function d(e,t,n,r){e.push(t+": "+r(n))}function p(e,t,n,r,i){e&&void 0!==r&&d(t,n,r,i)}function h(e,t){return t?e+" - "+l(t):e}var g=function(e){return function(e,n,r){var i=function(){n[r].apply(n,t.apply(arguments))};return(0,e[r])(i),i}};function v(v,m,y){if(!v)throw new Error('should pass QUnit object reference. Please check QUnit\'s "require" path if you are using Node.js (or any CommonJS env).');if("function"!=typeof m)throw new Error("should pass print-like function");var b=v,x={},w=function(e,t){y&&"object"==typeof y&&void 0!==y[e]&&(m('# WARNING: Option "'+e+'" is deprecated and will be removed in future version.'),t(y[e]))},k=["moduleStart","testStart","log","testDone","done"],T={},C=void 0!==b.dump&&"function"==typeof b.dump.parse?function(e){return b.dump.parse(e)}:void 0!==b.jsDump&&"function"==typeof b.jsDump.parse?function(e){return b.jsDump.parse(e)}:f;function E(e){return x.config[e]}function S(e){if(s(e))return e.message;var t=[];return e.message&&t.push(e.message),E("showExpectationOnFailure")&&!u(e)&&(d(t,"expected",e.expected,C),d(t,"got",e.actual,C)),p(E("showTestNameOnFailure"),t,"test",e.name,f),p(E("showModuleNameOnFailure"),t,"module",e.module,f),p(E("showSourceOnFailure"),t,"source",e.source,c),t.join(", ")}function j(e){x.puts(x.config.initialCount+".."+e)}function N(e){var t;-1!==r(k,e)&&void 0!==(t=b.config[e])&&i(t,T[e])}function q(e){var t;for(t=0;t<e.length;t+=1)N(e[t])}return x.config=n({initialCount:1,showModuleNameOnFailure:!0,showTestNameOnFailure:!0,showExpectationOnFailure:!0,showSourceOnFailure:!0},y),w("noPlan",(function(e){m('# Now QUnit-TAP works as with "noPlan: true" by default. If you want to delare plan explicitly, please use "QUnit.config.requireExpects" option instead.'),x.config.noPlan=e})),w("count",(function(e){x.config.initialCount=e+1})),w("showDetailsOnFailure",(function(e){x.config.showModuleNameOnFailure=e,x.config.showTestNameOnFailure=e,x.config.showExpectationOnFailure=e,x.config.showSourceOnFailure=e})),x.VERSION=e,x.puts=m,x.count=x.config.initialCount-1,x.expectedCount=x.config.initialCount-1,x.explain=C,x.note=function(e){x.puts(l("# "+e))},x.diag=function(e){return x.note(e),!1},x.moduleStart=function(e){var t="string"==typeof e?e:e.name;x.note("module: "+t)},x.testStart=function(e){var t="string"==typeof e?e:e.name;x.note("test: "+t)},x.log=function(e){var t="";x.count+=1,a(e)&&(t+="not "),t+="ok "+x.count,x.puts(h(t,S(e)))},x.testDone=function(){o(b.config)&&(x.expectedCount+=b.config.current.expected)},x.done=function(){(void 0===x.config.noPlan||x.config.noPlan)&&(o(b.config)?j(x.expectedCount):j(x.count))},x.unsubscribe=function(){void 0!==b.config&&q(0===arguments.length?k:t.apply(arguments))},function(){var e,t,n,r=g(b);for(t=0;t<k.length;t+=1)e=k[t],n=r(b,x,e),T[e]=n}(),x}return v.qunitTap=function(){throw new Error('[BC BREAK] Since 1.4.0, QUnit-TAP exports single qunitTap function as module.exports. Therefore, require("qunit-tap") returns qunitTap function itself. Please fix your code if you are using Node.js (or any CommonJS env).')},v})?r.call(t,n,t,e):r)||(e.exports=i)}()},14:function(e,t,n){var r;
/*!
 * jQuery JavaScript Library v3.5.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2020-05-04T22:49Z
 */!function(t,n){"use strict";"object"==typeof e.exports?e.exports=t.document?n(t,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return n(e)}:n(t)}("undefined"!=typeof window?window:this,(function(n,i){"use strict";var o=[],s=Object.getPrototypeOf,a=o.slice,u=o.flat?function(e){return o.flat.call(e)}:function(e){return o.concat.apply([],e)},l=o.push,c=o.indexOf,f={},d=f.toString,p=f.hasOwnProperty,h=p.toString,g=h.call(Object),v={},m=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType},y=function(e){return null!=e&&e===e.window},b=n.document,x={type:!0,src:!0,nonce:!0,noModule:!0};function w(e,t,n){var r,i,o=(n=n||b).createElement("script");if(o.text=e,t)for(r in x)(i=t[r]||t.getAttribute&&t.getAttribute(r))&&o.setAttribute(r,i);n.head.appendChild(o).parentNode.removeChild(o)}function k(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?f[d.call(e)]||"object":typeof e}var T="3.5.1",C=function(e,t){return new C.fn.init(e,t)};function E(e){var t=!!e&&"length"in e&&e.length,n=k(e);return!m(e)&&!y(e)&&("array"===n||0===t||"number"==typeof t&&t>0&&t-1 in e)}C.fn=C.prototype={jquery:T,constructor:C,length:0,toArray:function(){return a.call(this)},get:function(e){return null==e?a.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=C.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return C.each(this,e)},map:function(e){return this.pushStack(C.map(this,(function(t,n){return e.call(t,n,t)})))},slice:function(){return this.pushStack(a.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},even:function(){return this.pushStack(C.grep(this,(function(e,t){return(t+1)%2})))},odd:function(){return this.pushStack(C.grep(this,(function(e,t){return t%2})))},eq:function(e){var t=this.length,n=+e+(e<0?t:0);return this.pushStack(n>=0&&n<t?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:l,sort:o.sort,splice:o.splice},C.extend=C.fn.extend=function(){var e,t,n,r,i,o,s=arguments[0]||{},a=1,u=arguments.length,l=!1;for("boolean"==typeof s&&(l=s,s=arguments[a]||{},a++),"object"==typeof s||m(s)||(s={}),a===u&&(s=this,a--);a<u;a++)if(null!=(e=arguments[a]))for(t in e)r=e[t],"__proto__"!==t&&s!==r&&(l&&r&&(C.isPlainObject(r)||(i=Array.isArray(r)))?(n=s[t],o=i&&!Array.isArray(n)?[]:i||C.isPlainObject(n)?n:{},i=!1,s[t]=C.extend(l,o,r)):void 0!==r&&(s[t]=r));return s},C.extend({expando:"jQuery"+(T+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,n;return!(!e||"[object Object]"!==d.call(e))&&(!(t=s(e))||"function"==typeof(n=p.call(t,"constructor")&&t.constructor)&&h.call(n)===g)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t,n){w(e,{nonce:t&&t.nonce},n)},each:function(e,t){var n,r=0;if(E(e))for(n=e.length;r<n&&!1!==t.call(e[r],r,e[r]);r++);else for(r in e)if(!1===t.call(e[r],r,e[r]))break;return e},makeArray:function(e,t){var n=t||[];return null!=e&&(E(Object(e))?C.merge(n,"string"==typeof e?[e]:e):l.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:c.call(t,e,n)},merge:function(e,t){for(var n=+t.length,r=0,i=e.length;r<n;r++)e[i++]=t[r];return e.length=i,e},grep:function(e,t,n){for(var r=[],i=0,o=e.length,s=!n;i<o;i++)!t(e[i],i)!==s&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=0,s=[];if(E(e))for(r=e.length;o<r;o++)null!=(i=t(e[o],o,n))&&s.push(i);else for(o in e)null!=(i=t(e[o],o,n))&&s.push(i);return u(s)},guid:1,support:v}),"function"==typeof Symbol&&(C.fn[Symbol.iterator]=o[Symbol.iterator]),C.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),(function(e,t){f["[object "+t+"]"]=t.toLowerCase()}));var S=
/*!
 * Sizzle CSS Selector Engine v2.3.5
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://js.foundation/
 *
 * Date: 2020-03-14
 */
function(e){var t,n,r,i,o,s,a,u,l,c,f,d,p,h,g,v,m,y,b,x="sizzle"+1*new Date,w=e.document,k=0,T=0,C=ue(),E=ue(),S=ue(),j=ue(),N=function(e,t){return e===t&&(f=!0),0},q={}.hasOwnProperty,A=[],D=A.pop,O=A.push,M=A.push,I=A.slice,L=function(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1},_="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",P="[\\x20\\t\\r\\n\\f]",R="(?:\\\\[\\da-fA-F]{1,6}[\\x20\\t\\r\\n\\f]?|\\\\[^\\r\\n\\f]|[\\w-]|[^\0-\\x7f])+",H="\\[[\\x20\\t\\r\\n\\f]*("+R+")(?:"+P+"*([*^$|!~]?=)"+P+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+R+"))|)"+P+"*\\]",F=":("+R+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+H+")*)|.*)\\)|)",B=new RegExp(P+"+","g"),U=new RegExp("^[\\x20\\t\\r\\n\\f]+|((?:^|[^\\\\])(?:\\\\.)*)[\\x20\\t\\r\\n\\f]+$","g"),$=new RegExp("^[\\x20\\t\\r\\n\\f]*,[\\x20\\t\\r\\n\\f]*"),W=new RegExp("^[\\x20\\t\\r\\n\\f]*([>+~]|[\\x20\\t\\r\\n\\f])[\\x20\\t\\r\\n\\f]*"),Q=new RegExp(P+"|>"),z=new RegExp(F),X=new RegExp("^"+R+"$"),V={ID:new RegExp("^#("+R+")"),CLASS:new RegExp("^\\.("+R+")"),TAG:new RegExp("^("+R+"|[*])"),ATTR:new RegExp("^"+H),PSEUDO:new RegExp("^"+F),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\([\\x20\\t\\r\\n\\f]*(even|odd|(([+-]|)(\\d*)n|)[\\x20\\t\\r\\n\\f]*(?:([+-]|)[\\x20\\t\\r\\n\\f]*(\\d+)|))[\\x20\\t\\r\\n\\f]*\\)|)","i"),bool:new RegExp("^(?:"+_+")$","i"),needsContext:new RegExp("^[\\x20\\t\\r\\n\\f]*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\([\\x20\\t\\r\\n\\f]*((?:-\\d)?\\d*)[\\x20\\t\\r\\n\\f]*\\)|)(?=[^-]|$)","i")},G=/HTML$/i,J=/^(?:input|select|textarea|button)$/i,Y=/^h\d$/i,K=/^[^{]+\{\s*\[native \w/,Z=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ee=/[+~]/,te=new RegExp("\\\\[\\da-fA-F]{1,6}[\\x20\\t\\r\\n\\f]?|\\\\([^\\r\\n\\f])","g"),ne=function(e,t){var n="0x"+e.slice(1)-65536;return t||(n<0?String.fromCharCode(n+65536):String.fromCharCode(n>>10|55296,1023&n|56320))},re=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ie=function(e,t){return t?"\0"===e?"�":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e},oe=function(){d()},se=xe((function(e){return!0===e.disabled&&"fieldset"===e.nodeName.toLowerCase()}),{dir:"parentNode",next:"legend"});try{M.apply(A=I.call(w.childNodes),w.childNodes),A[w.childNodes.length].nodeType}catch(e){M={apply:A.length?function(e,t){O.apply(e,I.call(t))}:function(e,t){for(var n=e.length,r=0;e[n++]=t[r++];);e.length=n-1}}}function ae(e,t,r,i){var o,a,l,c,f,h,m,y=t&&t.ownerDocument,w=t?t.nodeType:9;if(r=r||[],"string"!=typeof e||!e||1!==w&&9!==w&&11!==w)return r;if(!i&&(d(t),t=t||p,g)){if(11!==w&&(f=Z.exec(e)))if(o=f[1]){if(9===w){if(!(l=t.getElementById(o)))return r;if(l.id===o)return r.push(l),r}else if(y&&(l=y.getElementById(o))&&b(t,l)&&l.id===o)return r.push(l),r}else{if(f[2])return M.apply(r,t.getElementsByTagName(e)),r;if((o=f[3])&&n.getElementsByClassName&&t.getElementsByClassName)return M.apply(r,t.getElementsByClassName(o)),r}if(n.qsa&&!j[e+" "]&&(!v||!v.test(e))&&(1!==w||"object"!==t.nodeName.toLowerCase())){if(m=e,y=t,1===w&&(Q.test(e)||W.test(e))){for((y=ee.test(e)&&me(t.parentNode)||t)===t&&n.scope||((c=t.getAttribute("id"))?c=c.replace(re,ie):t.setAttribute("id",c=x)),a=(h=s(e)).length;a--;)h[a]=(c?"#"+c:":scope")+" "+be(h[a]);m=h.join(",")}try{return M.apply(r,y.querySelectorAll(m)),r}catch(t){j(e,!0)}finally{c===x&&t.removeAttribute("id")}}}return u(e.replace(U,"$1"),t,r,i)}function ue(){var e=[];return function t(n,i){return e.push(n+" ")>r.cacheLength&&delete t[e.shift()],t[n+" "]=i}}function le(e){return e[x]=!0,e}function ce(e){var t=p.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function fe(e,t){for(var n=e.split("|"),i=n.length;i--;)r.attrHandle[n[i]]=t}function de(e,t){var n=t&&e,r=n&&1===e.nodeType&&1===t.nodeType&&e.sourceIndex-t.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===t)return-1;return e?1:-1}function pe(e){return function(t){return"input"===t.nodeName.toLowerCase()&&t.type===e}}function he(e){return function(t){var n=t.nodeName.toLowerCase();return("input"===n||"button"===n)&&t.type===e}}function ge(e){return function(t){return"form"in t?t.parentNode&&!1===t.disabled?"label"in t?"label"in t.parentNode?t.parentNode.disabled===e:t.disabled===e:t.isDisabled===e||t.isDisabled!==!e&&se(t)===e:t.disabled===e:"label"in t&&t.disabled===e}}function ve(e){return le((function(t){return t=+t,le((function(n,r){for(var i,o=e([],n.length,t),s=o.length;s--;)n[i=o[s]]&&(n[i]=!(r[i]=n[i]))}))}))}function me(e){return e&&void 0!==e.getElementsByTagName&&e}for(t in n=ae.support={},o=ae.isXML=function(e){var t=e.namespaceURI,n=(e.ownerDocument||e).documentElement;return!G.test(t||n&&n.nodeName||"HTML")},d=ae.setDocument=function(e){var t,i,s=e?e.ownerDocument||e:w;return s!=p&&9===s.nodeType&&s.documentElement?(h=(p=s).documentElement,g=!o(p),w!=p&&(i=p.defaultView)&&i.top!==i&&(i.addEventListener?i.addEventListener("unload",oe,!1):i.attachEvent&&i.attachEvent("onunload",oe)),n.scope=ce((function(e){return h.appendChild(e).appendChild(p.createElement("div")),void 0!==e.querySelectorAll&&!e.querySelectorAll(":scope fieldset div").length})),n.attributes=ce((function(e){return e.className="i",!e.getAttribute("className")})),n.getElementsByTagName=ce((function(e){return e.appendChild(p.createComment("")),!e.getElementsByTagName("*").length})),n.getElementsByClassName=K.test(p.getElementsByClassName),n.getById=ce((function(e){return h.appendChild(e).id=x,!p.getElementsByName||!p.getElementsByName(x).length})),n.getById?(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){return e.getAttribute("id")===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&g){var n=t.getElementById(e);return n?[n]:[]}}):(r.filter.ID=function(e){var t=e.replace(te,ne);return function(e){var n=void 0!==e.getAttributeNode&&e.getAttributeNode("id");return n&&n.value===t}},r.find.ID=function(e,t){if(void 0!==t.getElementById&&g){var n,r,i,o=t.getElementById(e);if(o){if((n=o.getAttributeNode("id"))&&n.value===e)return[o];for(i=t.getElementsByName(e),r=0;o=i[r++];)if((n=o.getAttributeNode("id"))&&n.value===e)return[o]}return[]}}),r.find.TAG=n.getElementsByTagName?function(e,t){return void 0!==t.getElementsByTagName?t.getElementsByTagName(e):n.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,r=[],i=0,o=t.getElementsByTagName(e);if("*"===e){for(;n=o[i++];)1===n.nodeType&&r.push(n);return r}return o},r.find.CLASS=n.getElementsByClassName&&function(e,t){if(void 0!==t.getElementsByClassName&&g)return t.getElementsByClassName(e)},m=[],v=[],(n.qsa=K.test(p.querySelectorAll))&&(ce((function(e){var t;h.appendChild(e).innerHTML="<a id='"+x+"'></a><select id='"+x+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&v.push("[*^$]=[\\x20\\t\\r\\n\\f]*(?:''|\"\")"),e.querySelectorAll("[selected]").length||v.push("\\[[\\x20\\t\\r\\n\\f]*(?:value|"+_+")"),e.querySelectorAll("[id~="+x+"-]").length||v.push("~="),(t=p.createElement("input")).setAttribute("name",""),e.appendChild(t),e.querySelectorAll("[name='']").length||v.push("\\[[\\x20\\t\\r\\n\\f]*name[\\x20\\t\\r\\n\\f]*=[\\x20\\t\\r\\n\\f]*(?:''|\"\")"),e.querySelectorAll(":checked").length||v.push(":checked"),e.querySelectorAll("a#"+x+"+*").length||v.push(".#.+[+~]"),e.querySelectorAll("\\\f"),v.push("[\\r\\n\\f]")})),ce((function(e){e.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var t=p.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&v.push("name[\\x20\\t\\r\\n\\f]*[*^$|!~]?="),2!==e.querySelectorAll(":enabled").length&&v.push(":enabled",":disabled"),h.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&v.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),v.push(",.*:")}))),(n.matchesSelector=K.test(y=h.matches||h.webkitMatchesSelector||h.mozMatchesSelector||h.oMatchesSelector||h.msMatchesSelector))&&ce((function(e){n.disconnectedMatch=y.call(e,"*"),y.call(e,"[s!='']:x"),m.push("!=",F)})),v=v.length&&new RegExp(v.join("|")),m=m.length&&new RegExp(m.join("|")),t=K.test(h.compareDocumentPosition),b=t||K.test(h.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):e.compareDocumentPosition&&16&e.compareDocumentPosition(r)))}:function(e,t){if(t)for(;t=t.parentNode;)if(t===e)return!0;return!1},N=t?function(e,t){if(e===t)return f=!0,0;var r=!e.compareDocumentPosition-!t.compareDocumentPosition;return r||(1&(r=(e.ownerDocument||e)==(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!n.sortDetached&&t.compareDocumentPosition(e)===r?e==p||e.ownerDocument==w&&b(w,e)?-1:t==p||t.ownerDocument==w&&b(w,t)?1:c?L(c,e)-L(c,t):0:4&r?-1:1)}:function(e,t){if(e===t)return f=!0,0;var n,r=0,i=e.parentNode,o=t.parentNode,s=[e],a=[t];if(!i||!o)return e==p?-1:t==p?1:i?-1:o?1:c?L(c,e)-L(c,t):0;if(i===o)return de(e,t);for(n=e;n=n.parentNode;)s.unshift(n);for(n=t;n=n.parentNode;)a.unshift(n);for(;s[r]===a[r];)r++;return r?de(s[r],a[r]):s[r]==w?-1:a[r]==w?1:0},p):p},ae.matches=function(e,t){return ae(e,null,null,t)},ae.matchesSelector=function(e,t){if(d(e),n.matchesSelector&&g&&!j[t+" "]&&(!m||!m.test(t))&&(!v||!v.test(t)))try{var r=y.call(e,t);if(r||n.disconnectedMatch||e.document&&11!==e.document.nodeType)return r}catch(e){j(t,!0)}return ae(t,p,null,[e]).length>0},ae.contains=function(e,t){return(e.ownerDocument||e)!=p&&d(e),b(e,t)},ae.attr=function(e,t){(e.ownerDocument||e)!=p&&d(e);var i=r.attrHandle[t.toLowerCase()],o=i&&q.call(r.attrHandle,t.toLowerCase())?i(e,t,!g):void 0;return void 0!==o?o:n.attributes||!g?e.getAttribute(t):(o=e.getAttributeNode(t))&&o.specified?o.value:null},ae.escape=function(e){return(e+"").replace(re,ie)},ae.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},ae.uniqueSort=function(e){var t,r=[],i=0,o=0;if(f=!n.detectDuplicates,c=!n.sortStable&&e.slice(0),e.sort(N),f){for(;t=e[o++];)t===e[o]&&(i=r.push(o));for(;i--;)e.splice(r[i],1)}return c=null,e},i=ae.getText=function(e){var t,n="",r=0,o=e.nodeType;if(o){if(1===o||9===o||11===o){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=i(e)}else if(3===o||4===o)return e.nodeValue}else for(;t=e[r++];)n+=i(t);return n},(r=ae.selectors={cacheLength:50,createPseudo:le,match:V,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(te,ne),e[3]=(e[3]||e[4]||e[5]||"").replace(te,ne),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||ae.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&ae.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return V.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&z.test(n)&&(t=s(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(te,ne).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=C[e+" "];return t||(t=new RegExp("(^|[\\x20\\t\\r\\n\\f])"+e+"("+P+"|$)"))&&C(e,(function(e){return t.test("string"==typeof e.className&&e.className||void 0!==e.getAttribute&&e.getAttribute("class")||"")}))},ATTR:function(e,t,n){return function(r){var i=ae.attr(r,e);return null==i?"!="===t:!t||(i+="","="===t?i===n:"!="===t?i!==n:"^="===t?n&&0===i.indexOf(n):"*="===t?n&&i.indexOf(n)>-1:"$="===t?n&&i.slice(-n.length)===n:"~="===t?(" "+i.replace(B," ")+" ").indexOf(n)>-1:"|="===t&&(i===n||i.slice(0,n.length+1)===n+"-"))}},CHILD:function(e,t,n,r,i){var o="nth"!==e.slice(0,3),s="last"!==e.slice(-4),a="of-type"===t;return 1===r&&0===i?function(e){return!!e.parentNode}:function(t,n,u){var l,c,f,d,p,h,g=o!==s?"nextSibling":"previousSibling",v=t.parentNode,m=a&&t.nodeName.toLowerCase(),y=!u&&!a,b=!1;if(v){if(o){for(;g;){for(d=t;d=d[g];)if(a?d.nodeName.toLowerCase()===m:1===d.nodeType)return!1;h=g="only"===e&&!h&&"nextSibling"}return!0}if(h=[s?v.firstChild:v.lastChild],s&&y){for(b=(p=(l=(c=(f=(d=v)[x]||(d[x]={}))[d.uniqueID]||(f[d.uniqueID]={}))[e]||[])[0]===k&&l[1])&&l[2],d=p&&v.childNodes[p];d=++p&&d&&d[g]||(b=p=0)||h.pop();)if(1===d.nodeType&&++b&&d===t){c[e]=[k,p,b];break}}else if(y&&(b=p=(l=(c=(f=(d=t)[x]||(d[x]={}))[d.uniqueID]||(f[d.uniqueID]={}))[e]||[])[0]===k&&l[1]),!1===b)for(;(d=++p&&d&&d[g]||(b=p=0)||h.pop())&&((a?d.nodeName.toLowerCase()!==m:1!==d.nodeType)||!++b||(y&&((c=(f=d[x]||(d[x]={}))[d.uniqueID]||(f[d.uniqueID]={}))[e]=[k,b]),d!==t)););return(b-=i)===r||b%r==0&&b/r>=0}}},PSEUDO:function(e,t){var n,i=r.pseudos[e]||r.setFilters[e.toLowerCase()]||ae.error("unsupported pseudo: "+e);return i[x]?i(t):i.length>1?(n=[e,e,"",t],r.setFilters.hasOwnProperty(e.toLowerCase())?le((function(e,n){for(var r,o=i(e,t),s=o.length;s--;)e[r=L(e,o[s])]=!(n[r]=o[s])})):function(e){return i(e,0,n)}):i}},pseudos:{not:le((function(e){var t=[],n=[],r=a(e.replace(U,"$1"));return r[x]?le((function(e,t,n,i){for(var o,s=r(e,null,i,[]),a=e.length;a--;)(o=s[a])&&(e[a]=!(t[a]=o))})):function(e,i,o){return t[0]=e,r(t,null,o,n),t[0]=null,!n.pop()}})),has:le((function(e){return function(t){return ae(e,t).length>0}})),contains:le((function(e){return e=e.replace(te,ne),function(t){return(t.textContent||i(t)).indexOf(e)>-1}})),lang:le((function(e){return X.test(e||"")||ae.error("unsupported lang: "+e),e=e.replace(te,ne).toLowerCase(),function(t){var n;do{if(n=g?t.lang:t.getAttribute("xml:lang")||t.getAttribute("lang"))return(n=n.toLowerCase())===e||0===n.indexOf(e+"-")}while((t=t.parentNode)&&1===t.nodeType);return!1}})),target:function(t){var n=e.location&&e.location.hash;return n&&n.slice(1)===t.id},root:function(e){return e===h},focus:function(e){return e===p.activeElement&&(!p.hasFocus||p.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:ge(!1),disabled:ge(!0),checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!r.pseudos.empty(e)},header:function(e){return Y.test(e.nodeName)},input:function(e){return J.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:ve((function(){return[0]})),last:ve((function(e,t){return[t-1]})),eq:ve((function(e,t,n){return[n<0?n+t:n]})),even:ve((function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e})),odd:ve((function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e})),lt:ve((function(e,t,n){for(var r=n<0?n+t:n>t?t:n;--r>=0;)e.push(r);return e})),gt:ve((function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e}))}}).pseudos.nth=r.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})r.pseudos[t]=pe(t);for(t in{submit:!0,reset:!0})r.pseudos[t]=he(t);function ye(){}function be(e){for(var t=0,n=e.length,r="";t<n;t++)r+=e[t].value;return r}function xe(e,t,n){var r=t.dir,i=t.next,o=i||r,s=n&&"parentNode"===o,a=T++;return t.first?function(t,n,i){for(;t=t[r];)if(1===t.nodeType||s)return e(t,n,i);return!1}:function(t,n,u){var l,c,f,d=[k,a];if(u){for(;t=t[r];)if((1===t.nodeType||s)&&e(t,n,u))return!0}else for(;t=t[r];)if(1===t.nodeType||s)if(c=(f=t[x]||(t[x]={}))[t.uniqueID]||(f[t.uniqueID]={}),i&&i===t.nodeName.toLowerCase())t=t[r]||t;else{if((l=c[o])&&l[0]===k&&l[1]===a)return d[2]=l[2];if(c[o]=d,d[2]=e(t,n,u))return!0}return!1}}function we(e){return e.length>1?function(t,n,r){for(var i=e.length;i--;)if(!e[i](t,n,r))return!1;return!0}:e[0]}function ke(e,t,n,r,i){for(var o,s=[],a=0,u=e.length,l=null!=t;a<u;a++)(o=e[a])&&(n&&!n(o,r,i)||(s.push(o),l&&t.push(a)));return s}function Te(e,t,n,r,i,o){return r&&!r[x]&&(r=Te(r)),i&&!i[x]&&(i=Te(i,o)),le((function(o,s,a,u){var l,c,f,d=[],p=[],h=s.length,g=o||function(e,t,n){for(var r=0,i=t.length;r<i;r++)ae(e,t[r],n);return n}(t||"*",a.nodeType?[a]:a,[]),v=!e||!o&&t?g:ke(g,d,e,a,u),m=n?i||(o?e:h||r)?[]:s:v;if(n&&n(v,m,a,u),r)for(l=ke(m,p),r(l,[],a,u),c=l.length;c--;)(f=l[c])&&(m[p[c]]=!(v[p[c]]=f));if(o){if(i||e){if(i){for(l=[],c=m.length;c--;)(f=m[c])&&l.push(v[c]=f);i(null,m=[],l,u)}for(c=m.length;c--;)(f=m[c])&&(l=i?L(o,f):d[c])>-1&&(o[l]=!(s[l]=f))}}else m=ke(m===s?m.splice(h,m.length):m),i?i(null,s,m,u):M.apply(s,m)}))}function Ce(e){for(var t,n,i,o=e.length,s=r.relative[e[0].type],a=s||r.relative[" "],u=s?1:0,c=xe((function(e){return e===t}),a,!0),f=xe((function(e){return L(t,e)>-1}),a,!0),d=[function(e,n,r){var i=!s&&(r||n!==l)||((t=n).nodeType?c(e,n,r):f(e,n,r));return t=null,i}];u<o;u++)if(n=r.relative[e[u].type])d=[xe(we(d),n)];else{if((n=r.filter[e[u].type].apply(null,e[u].matches))[x]){for(i=++u;i<o&&!r.relative[e[i].type];i++);return Te(u>1&&we(d),u>1&&be(e.slice(0,u-1).concat({value:" "===e[u-2].type?"*":""})).replace(U,"$1"),n,u<i&&Ce(e.slice(u,i)),i<o&&Ce(e=e.slice(i)),i<o&&be(e))}d.push(n)}return we(d)}return ye.prototype=r.filters=r.pseudos,r.setFilters=new ye,s=ae.tokenize=function(e,t){var n,i,o,s,a,u,l,c=E[e+" "];if(c)return t?0:c.slice(0);for(a=e,u=[],l=r.preFilter;a;){for(s in n&&!(i=$.exec(a))||(i&&(a=a.slice(i[0].length)||a),u.push(o=[])),n=!1,(i=W.exec(a))&&(n=i.shift(),o.push({value:n,type:i[0].replace(U," ")}),a=a.slice(n.length)),r.filter)!(i=V[s].exec(a))||l[s]&&!(i=l[s](i))||(n=i.shift(),o.push({value:n,type:s,matches:i}),a=a.slice(n.length));if(!n)break}return t?a.length:a?ae.error(e):E(e,u).slice(0)},a=ae.compile=function(e,t){var n,i=[],o=[],a=S[e+" "];if(!a){for(t||(t=s(e)),n=t.length;n--;)(a=Ce(t[n]))[x]?i.push(a):o.push(a);(a=S(e,function(e,t){var n=t.length>0,i=e.length>0,o=function(o,s,a,u,c){var f,h,v,m=0,y="0",b=o&&[],x=[],w=l,T=o||i&&r.find.TAG("*",c),C=k+=null==w?1:Math.random()||.1,E=T.length;for(c&&(l=s==p||s||c);y!==E&&null!=(f=T[y]);y++){if(i&&f){for(h=0,s||f.ownerDocument==p||(d(f),a=!g);v=e[h++];)if(v(f,s||p,a)){u.push(f);break}c&&(k=C)}n&&((f=!v&&f)&&m--,o&&b.push(f))}if(m+=y,n&&y!==m){for(h=0;v=t[h++];)v(b,x,s,a);if(o){if(m>0)for(;y--;)b[y]||x[y]||(x[y]=D.call(u));x=ke(x)}M.apply(u,x),c&&!o&&x.length>0&&m+t.length>1&&ae.uniqueSort(u)}return c&&(k=C,l=w),b};return n?le(o):o}(o,i))).selector=e}return a},u=ae.select=function(e,t,n,i){var o,u,l,c,f,d="function"==typeof e&&e,p=!i&&s(e=d.selector||e);if(n=n||[],1===p.length){if((u=p[0]=p[0].slice(0)).length>2&&"ID"===(l=u[0]).type&&9===t.nodeType&&g&&r.relative[u[1].type]){if(!(t=(r.find.ID(l.matches[0].replace(te,ne),t)||[])[0]))return n;d&&(t=t.parentNode),e=e.slice(u.shift().value.length)}for(o=V.needsContext.test(e)?0:u.length;o--&&(l=u[o],!r.relative[c=l.type]);)if((f=r.find[c])&&(i=f(l.matches[0].replace(te,ne),ee.test(u[0].type)&&me(t.parentNode)||t))){if(u.splice(o,1),!(e=i.length&&be(u)))return M.apply(n,i),n;break}}return(d||a(e,p))(i,t,!g,n,!t||ee.test(e)&&me(t.parentNode)||t),n},n.sortStable=x.split("").sort(N).join("")===x,n.detectDuplicates=!!f,d(),n.sortDetached=ce((function(e){return 1&e.compareDocumentPosition(p.createElement("fieldset"))})),ce((function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")}))||fe("type|href|height|width",(function(e,t,n){if(!n)return e.getAttribute(t,"type"===t.toLowerCase()?1:2)})),n.attributes&&ce((function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")}))||fe("value",(function(e,t,n){if(!n&&"input"===e.nodeName.toLowerCase())return e.defaultValue})),ce((function(e){return null==e.getAttribute("disabled")}))||fe(_,(function(e,t,n){var r;if(!n)return!0===e[t]?t.toLowerCase():(r=e.getAttributeNode(t))&&r.specified?r.value:null})),ae}(n);C.find=S,C.expr=S.selectors,C.expr[":"]=C.expr.pseudos,C.uniqueSort=C.unique=S.uniqueSort,C.text=S.getText,C.isXMLDoc=S.isXML,C.contains=S.contains,C.escapeSelector=S.escape;var j=function(e,t,n){for(var r=[],i=void 0!==n;(e=e[t])&&9!==e.nodeType;)if(1===e.nodeType){if(i&&C(e).is(n))break;r.push(e)}return r},N=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},q=C.expr.match.needsContext;function A(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}var D=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function O(e,t,n){return m(t)?C.grep(e,(function(e,r){return!!t.call(e,r,e)!==n})):t.nodeType?C.grep(e,(function(e){return e===t!==n})):"string"!=typeof t?C.grep(e,(function(e){return c.call(t,e)>-1!==n})):C.filter(t,e,n)}C.filter=function(e,t,n){var r=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===r.nodeType?C.find.matchesSelector(r,e)?[r]:[]:C.find.matches(e,C.grep(t,(function(e){return 1===e.nodeType})))},C.fn.extend({find:function(e){var t,n,r=this.length,i=this;if("string"!=typeof e)return this.pushStack(C(e).filter((function(){for(t=0;t<r;t++)if(C.contains(i[t],this))return!0})));for(n=this.pushStack([]),t=0;t<r;t++)C.find(e,i[t],n);return r>1?C.uniqueSort(n):n},filter:function(e){return this.pushStack(O(this,e||[],!1))},not:function(e){return this.pushStack(O(this,e||[],!0))},is:function(e){return!!O(this,"string"==typeof e&&q.test(e)?C(e):e||[],!1).length}});var M,I=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(C.fn.init=function(e,t,n){var r,i;if(!e)return this;if(n=n||M,"string"==typeof e){if(!(r="<"===e[0]&&">"===e[e.length-1]&&e.length>=3?[null,e,null]:I.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1]){if(t=t instanceof C?t[0]:t,C.merge(this,C.parseHTML(r[1],t&&t.nodeType?t.ownerDocument||t:b,!0)),D.test(r[1])&&C.isPlainObject(t))for(r in t)m(this[r])?this[r](t[r]):this.attr(r,t[r]);return this}return(i=b.getElementById(r[2]))&&(this[0]=i,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):m(e)?void 0!==n.ready?n.ready(e):e(C):C.makeArray(e,this)}).prototype=C.fn,M=C(b);var L=/^(?:parents|prev(?:Until|All))/,_={children:!0,contents:!0,next:!0,prev:!0};function P(e,t){for(;(e=e[t])&&1!==e.nodeType;);return e}C.fn.extend({has:function(e){var t=C(e,this),n=t.length;return this.filter((function(){for(var e=0;e<n;e++)if(C.contains(this,t[e]))return!0}))},closest:function(e,t){var n,r=0,i=this.length,o=[],s="string"!=typeof e&&C(e);if(!q.test(e))for(;r<i;r++)for(n=this[r];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(s?s.index(n)>-1:1===n.nodeType&&C.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(o.length>1?C.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?c.call(C(e),this[0]):c.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(C.uniqueSort(C.merge(this.get(),C(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),C.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return j(e,"parentNode")},parentsUntil:function(e,t,n){return j(e,"parentNode",n)},next:function(e){return P(e,"nextSibling")},prev:function(e){return P(e,"previousSibling")},nextAll:function(e){return j(e,"nextSibling")},prevAll:function(e){return j(e,"previousSibling")},nextUntil:function(e,t,n){return j(e,"nextSibling",n)},prevUntil:function(e,t,n){return j(e,"previousSibling",n)},siblings:function(e){return N((e.parentNode||{}).firstChild,e)},children:function(e){return N(e.firstChild)},contents:function(e){return null!=e.contentDocument&&s(e.contentDocument)?e.contentDocument:(A(e,"template")&&(e=e.content||e),C.merge([],e.childNodes))}},(function(e,t){C.fn[e]=function(n,r){var i=C.map(this,t,n);return"Until"!==e.slice(-5)&&(r=n),r&&"string"==typeof r&&(i=C.filter(r,i)),this.length>1&&(_[e]||C.uniqueSort(i),L.test(e)&&i.reverse()),this.pushStack(i)}}));var R=/[^\x20\t\r\n\f]+/g;function H(e){return e}function F(e){throw e}function B(e,t,n,r){var i;try{e&&m(i=e.promise)?i.call(e).done(t).fail(n):e&&m(i=e.then)?i.call(e,t,n):t.apply(void 0,[e].slice(r))}catch(e){n.apply(void 0,[e])}}C.Callbacks=function(e){e="string"==typeof e?function(e){var t={};return C.each(e.match(R)||[],(function(e,n){t[n]=!0})),t}(e):C.extend({},e);var t,n,r,i,o=[],s=[],a=-1,u=function(){for(i=i||e.once,r=t=!0;s.length;a=-1)for(n=s.shift();++a<o.length;)!1===o[a].apply(n[0],n[1])&&e.stopOnFalse&&(a=o.length,n=!1);e.memory||(n=!1),t=!1,i&&(o=n?[]:"")},l={add:function(){return o&&(n&&!t&&(a=o.length-1,s.push(n)),function t(n){C.each(n,(function(n,r){m(r)?e.unique&&l.has(r)||o.push(r):r&&r.length&&"string"!==k(r)&&t(r)}))}(arguments),n&&!t&&u()),this},remove:function(){return C.each(arguments,(function(e,t){for(var n;(n=C.inArray(t,o,n))>-1;)o.splice(n,1),n<=a&&a--})),this},has:function(e){return e?C.inArray(e,o)>-1:o.length>0},empty:function(){return o&&(o=[]),this},disable:function(){return i=s=[],o=n="",this},disabled:function(){return!o},lock:function(){return i=s=[],n||t||(o=n=""),this},locked:function(){return!!i},fireWith:function(e,n){return i||(n=[e,(n=n||[]).slice?n.slice():n],s.push(n),t||u()),this},fire:function(){return l.fireWith(this,arguments),this},fired:function(){return!!r}};return l},C.extend({Deferred:function(e){var t=[["notify","progress",C.Callbacks("memory"),C.Callbacks("memory"),2],["resolve","done",C.Callbacks("once memory"),C.Callbacks("once memory"),0,"resolved"],["reject","fail",C.Callbacks("once memory"),C.Callbacks("once memory"),1,"rejected"]],r="pending",i={state:function(){return r},always:function(){return o.done(arguments).fail(arguments),this},catch:function(e){return i.then(null,e)},pipe:function(){var e=arguments;return C.Deferred((function(n){C.each(t,(function(t,r){var i=m(e[r[4]])&&e[r[4]];o[r[1]]((function(){var e=i&&i.apply(this,arguments);e&&m(e.promise)?e.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,i?[e]:arguments)}))})),e=null})).promise()},then:function(e,r,i){var o=0;function s(e,t,r,i){return function(){var a=this,u=arguments,l=function(){var n,l;if(!(e<o)){if((n=r.apply(a,u))===t.promise())throw new TypeError("Thenable self-resolution");l=n&&("object"==typeof n||"function"==typeof n)&&n.then,m(l)?i?l.call(n,s(o,t,H,i),s(o,t,F,i)):(o++,l.call(n,s(o,t,H,i),s(o,t,F,i),s(o,t,H,t.notifyWith))):(r!==H&&(a=void 0,u=[n]),(i||t.resolveWith)(a,u))}},c=i?l:function(){try{l()}catch(n){C.Deferred.exceptionHook&&C.Deferred.exceptionHook(n,c.stackTrace),e+1>=o&&(r!==F&&(a=void 0,u=[n]),t.rejectWith(a,u))}};e?c():(C.Deferred.getStackHook&&(c.stackTrace=C.Deferred.getStackHook()),n.setTimeout(c))}}return C.Deferred((function(n){t[0][3].add(s(0,n,m(i)?i:H,n.notifyWith)),t[1][3].add(s(0,n,m(e)?e:H)),t[2][3].add(s(0,n,m(r)?r:F))})).promise()},promise:function(e){return null!=e?C.extend(e,i):i}},o={};return C.each(t,(function(e,n){var s=n[2],a=n[5];i[n[1]]=s.add,a&&s.add((function(){r=a}),t[3-e][2].disable,t[3-e][3].disable,t[0][2].lock,t[0][3].lock),s.add(n[3].fire),o[n[0]]=function(){return o[n[0]+"With"](this===o?void 0:this,arguments),this},o[n[0]+"With"]=s.fireWith})),i.promise(o),e&&e.call(o,o),o},when:function(e){var t=arguments.length,n=t,r=Array(n),i=a.call(arguments),o=C.Deferred(),s=function(e){return function(n){r[e]=this,i[e]=arguments.length>1?a.call(arguments):n,--t||o.resolveWith(r,i)}};if(t<=1&&(B(e,o.done(s(n)).resolve,o.reject,!t),"pending"===o.state()||m(i[n]&&i[n].then)))return o.then();for(;n--;)B(i[n],s(n),o.reject);return o.promise()}});var U=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;C.Deferred.exceptionHook=function(e,t){n.console&&n.console.warn&&e&&U.test(e.name)&&n.console.warn("jQuery.Deferred exception: "+e.message,e.stack,t)},C.readyException=function(e){n.setTimeout((function(){throw e}))};var $=C.Deferred();function W(){b.removeEventListener("DOMContentLoaded",W),n.removeEventListener("load",W),C.ready()}C.fn.ready=function(e){return $.then(e).catch((function(e){C.readyException(e)})),this},C.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--C.readyWait:C.isReady)||(C.isReady=!0,!0!==e&&--C.readyWait>0||$.resolveWith(b,[C]))}}),C.ready.then=$.then,"complete"===b.readyState||"loading"!==b.readyState&&!b.documentElement.doScroll?n.setTimeout(C.ready):(b.addEventListener("DOMContentLoaded",W),n.addEventListener("load",W));var Q=function(e,t,n,r,i,o,s){var a=0,u=e.length,l=null==n;if("object"===k(n))for(a in i=!0,n)Q(e,t,a,n[a],!0,o,s);else if(void 0!==r&&(i=!0,m(r)||(s=!0),l&&(s?(t.call(e,r),t=null):(l=t,t=function(e,t,n){return l.call(C(e),n)})),t))for(;a<u;a++)t(e[a],n,s?r:r.call(e[a],a,t(e[a],n)));return i?e:l?t.call(e):u?t(e[0],n):o},z=/^-ms-/,X=/-([a-z])/g;function V(e,t){return t.toUpperCase()}function G(e){return e.replace(z,"ms-").replace(X,V)}var J=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function Y(){this.expando=C.expando+Y.uid++}Y.uid=1,Y.prototype={cache:function(e){var t=e[this.expando];return t||(t={},J(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var r,i=this.cache(e);if("string"==typeof t)i[G(t)]=n;else for(r in t)i[G(r)]=t[r];return i},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][G(t)]},access:function(e,t,n){return void 0===t||t&&"string"==typeof t&&void 0===n?this.get(e,t):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,r=e[this.expando];if(void 0!==r){if(void 0!==t){n=(t=Array.isArray(t)?t.map(G):(t=G(t))in r?[t]:t.match(R)||[]).length;for(;n--;)delete r[t[n]]}(void 0===t||C.isEmptyObject(r))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!C.isEmptyObject(t)}};var K=new Y,Z=new Y,ee=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,te=/[A-Z]/g;function ne(e,t,n){var r;if(void 0===n&&1===e.nodeType)if(r="data-"+t.replace(te,"-$&").toLowerCase(),"string"==typeof(n=e.getAttribute(r))){try{n=function(e){return"true"===e||"false"!==e&&("null"===e?null:e===+e+""?+e:ee.test(e)?JSON.parse(e):e)}(n)}catch(e){}Z.set(e,t,n)}else n=void 0;return n}C.extend({hasData:function(e){return Z.hasData(e)||K.hasData(e)},data:function(e,t,n){return Z.access(e,t,n)},removeData:function(e,t){Z.remove(e,t)},_data:function(e,t,n){return K.access(e,t,n)},_removeData:function(e,t){K.remove(e,t)}}),C.fn.extend({data:function(e,t){var n,r,i,o=this[0],s=o&&o.attributes;if(void 0===e){if(this.length&&(i=Z.get(o),1===o.nodeType&&!K.get(o,"hasDataAttrs"))){for(n=s.length;n--;)s[n]&&0===(r=s[n].name).indexOf("data-")&&(r=G(r.slice(5)),ne(o,r,i[r]));K.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof e?this.each((function(){Z.set(this,e)})):Q(this,(function(t){var n;if(o&&void 0===t)return void 0!==(n=Z.get(o,e))||void 0!==(n=ne(o,e))?n:void 0;this.each((function(){Z.set(this,e,t)}))}),null,t,arguments.length>1,null,!0)},removeData:function(e){return this.each((function(){Z.remove(this,e)}))}}),C.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=K.get(e,t),n&&(!r||Array.isArray(n)?r=K.access(e,t,C.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=C.queue(e,t),r=n.length,i=n.shift(),o=C._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,(function(){C.dequeue(e,t)}),o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return K.get(e,n)||K.access(e,n,{empty:C.Callbacks("once memory").add((function(){K.remove(e,[t+"queue",n])}))})}}),C.fn.extend({queue:function(e,t){var n=2;return"string"!=typeof e&&(t=e,e="fx",n--),arguments.length<n?C.queue(this[0],e):void 0===t?this:this.each((function(){var n=C.queue(this,e,t);C._queueHooks(this,e),"fx"===e&&"inprogress"!==n[0]&&C.dequeue(this,e)}))},dequeue:function(e){return this.each((function(){C.dequeue(this,e)}))},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=C.Deferred(),o=this,s=this.length,a=function(){--r||i.resolveWith(o,[o])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";s--;)(n=K.get(o[s],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(a));return a(),i.promise(t)}});var re=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ie=new RegExp("^(?:([+-])=|)("+re+")([a-z%]*)$","i"),oe=["Top","Right","Bottom","Left"],se=b.documentElement,ae=function(e){return C.contains(e.ownerDocument,e)},ue={composed:!0};se.getRootNode&&(ae=function(e){return C.contains(e.ownerDocument,e)||e.getRootNode(ue)===e.ownerDocument});var le=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&ae(e)&&"none"===C.css(e,"display")};function ce(e,t,n,r){var i,o,s=20,a=r?function(){return r.cur()}:function(){return C.css(e,t,"")},u=a(),l=n&&n[3]||(C.cssNumber[t]?"":"px"),c=e.nodeType&&(C.cssNumber[t]||"px"!==l&&+u)&&ie.exec(C.css(e,t));if(c&&c[3]!==l){for(u/=2,l=l||c[3],c=+u||1;s--;)C.style(e,t,c+l),(1-o)*(1-(o=a()/u||.5))<=0&&(s=0),c/=o;c*=2,C.style(e,t,c+l),n=n||[]}return n&&(c=+c||+u||0,i=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=l,r.start=c,r.end=i)),i}var fe={};function de(e){var t,n=e.ownerDocument,r=e.nodeName,i=fe[r];return i||(t=n.body.appendChild(n.createElement(r)),i=C.css(t,"display"),t.parentNode.removeChild(t),"none"===i&&(i="block"),fe[r]=i,i)}function pe(e,t){for(var n,r,i=[],o=0,s=e.length;o<s;o++)(r=e[o]).style&&(n=r.style.display,t?("none"===n&&(i[o]=K.get(r,"display")||null,i[o]||(r.style.display="")),""===r.style.display&&le(r)&&(i[o]=de(r))):"none"!==n&&(i[o]="none",K.set(r,"display",n)));for(o=0;o<s;o++)null!=i[o]&&(e[o].style.display=i[o]);return e}C.fn.extend({show:function(){return pe(this,!0)},hide:function(){return pe(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each((function(){le(this)?C(this).show():C(this).hide()}))}});var he,ge,ve=/^(?:checkbox|radio)$/i,me=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,ye=/^$|^module$|\/(?:java|ecma)script/i;he=b.createDocumentFragment().appendChild(b.createElement("div")),(ge=b.createElement("input")).setAttribute("type","radio"),ge.setAttribute("checked","checked"),ge.setAttribute("name","t"),he.appendChild(ge),v.checkClone=he.cloneNode(!0).cloneNode(!0).lastChild.checked,he.innerHTML="<textarea>x</textarea>",v.noCloneChecked=!!he.cloneNode(!0).lastChild.defaultValue,he.innerHTML="<option></option>",v.option=!!he.lastChild;var be={thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function xe(e,t){var n;return n=void 0!==e.getElementsByTagName?e.getElementsByTagName(t||"*"):void 0!==e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&A(e,t)?C.merge([e],n):n}function we(e,t){for(var n=0,r=e.length;n<r;n++)K.set(e[n],"globalEval",!t||K.get(t[n],"globalEval"))}be.tbody=be.tfoot=be.colgroup=be.caption=be.thead,be.th=be.td,v.option||(be.optgroup=be.option=[1,"<select multiple='multiple'>","</select>"]);var ke=/<|&#?\w+;/;function Te(e,t,n,r,i){for(var o,s,a,u,l,c,f=t.createDocumentFragment(),d=[],p=0,h=e.length;p<h;p++)if((o=e[p])||0===o)if("object"===k(o))C.merge(d,o.nodeType?[o]:o);else if(ke.test(o)){for(s=s||f.appendChild(t.createElement("div")),a=(me.exec(o)||["",""])[1].toLowerCase(),u=be[a]||be._default,s.innerHTML=u[1]+C.htmlPrefilter(o)+u[2],c=u[0];c--;)s=s.lastChild;C.merge(d,s.childNodes),(s=f.firstChild).textContent=""}else d.push(t.createTextNode(o));for(f.textContent="",p=0;o=d[p++];)if(r&&C.inArray(o,r)>-1)i&&i.push(o);else if(l=ae(o),s=xe(f.appendChild(o),"script"),l&&we(s),n)for(c=0;o=s[c++];)ye.test(o.type||"")&&n.push(o);return f}var Ce=/^key/,Ee=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Se=/^([^.]*)(?:\.(.+)|)/;function je(){return!0}function Ne(){return!1}function qe(e,t){return e===function(){try{return b.activeElement}catch(e){}}()==("focus"===t)}function Ae(e,t,n,r,i,o){var s,a;if("object"==typeof t){for(a in"string"!=typeof n&&(r=r||n,n=void 0),t)Ae(e,a,n,r,t[a],o);return e}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=Ne;else if(!i)return e;return 1===o&&(s=i,(i=function(e){return C().off(e),s.apply(this,arguments)}).guid=s.guid||(s.guid=C.guid++)),e.each((function(){C.event.add(this,t,i,r,n)}))}function De(e,t,n){n?(K.set(e,t,!1),C.event.add(e,t,{namespace:!1,handler:function(e){var r,i,o=K.get(this,t);if(1&e.isTrigger&&this[t]){if(o.length)(C.event.special[t]||{}).delegateType&&e.stopPropagation();else if(o=a.call(arguments),K.set(this,t,o),r=n(this,t),this[t](),o!==(i=K.get(this,t))||r?K.set(this,t,!1):i={},o!==i)return e.stopImmediatePropagation(),e.preventDefault(),i.value}else o.length&&(K.set(this,t,{value:C.event.trigger(C.extend(o[0],C.Event.prototype),o.slice(1),this)}),e.stopImmediatePropagation())}})):void 0===K.get(e,t)&&C.event.add(e,t,je)}C.event={global:{},add:function(e,t,n,r,i){var o,s,a,u,l,c,f,d,p,h,g,v=K.get(e);if(J(e))for(n.handler&&(n=(o=n).handler,i=o.selector),i&&C.find.matchesSelector(se,i),n.guid||(n.guid=C.guid++),(u=v.events)||(u=v.events=Object.create(null)),(s=v.handle)||(s=v.handle=function(t){return void 0!==C&&C.event.triggered!==t.type?C.event.dispatch.apply(e,arguments):void 0}),l=(t=(t||"").match(R)||[""]).length;l--;)p=g=(a=Se.exec(t[l])||[])[1],h=(a[2]||"").split(".").sort(),p&&(f=C.event.special[p]||{},p=(i?f.delegateType:f.bindType)||p,f=C.event.special[p]||{},c=C.extend({type:p,origType:g,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&C.expr.match.needsContext.test(i),namespace:h.join(".")},o),(d=u[p])||((d=u[p]=[]).delegateCount=0,f.setup&&!1!==f.setup.call(e,r,h,s)||e.addEventListener&&e.addEventListener(p,s)),f.add&&(f.add.call(e,c),c.handler.guid||(c.handler.guid=n.guid)),i?d.splice(d.delegateCount++,0,c):d.push(c),C.event.global[p]=!0)},remove:function(e,t,n,r,i){var o,s,a,u,l,c,f,d,p,h,g,v=K.hasData(e)&&K.get(e);if(v&&(u=v.events)){for(l=(t=(t||"").match(R)||[""]).length;l--;)if(p=g=(a=Se.exec(t[l])||[])[1],h=(a[2]||"").split(".").sort(),p){for(f=C.event.special[p]||{},d=u[p=(r?f.delegateType:f.bindType)||p]||[],a=a[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),s=o=d.length;o--;)c=d[o],!i&&g!==c.origType||n&&n.guid!==c.guid||a&&!a.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(d.splice(o,1),c.selector&&d.delegateCount--,f.remove&&f.remove.call(e,c));s&&!d.length&&(f.teardown&&!1!==f.teardown.call(e,h,v.handle)||C.removeEvent(e,p,v.handle),delete u[p])}else for(p in u)C.event.remove(e,p+t[l],n,r,!0);C.isEmptyObject(u)&&K.remove(e,"handle events")}},dispatch:function(e){var t,n,r,i,o,s,a=new Array(arguments.length),u=C.event.fix(e),l=(K.get(this,"events")||Object.create(null))[u.type]||[],c=C.event.special[u.type]||{};for(a[0]=u,t=1;t<arguments.length;t++)a[t]=arguments[t];if(u.delegateTarget=this,!c.preDispatch||!1!==c.preDispatch.call(this,u)){for(s=C.event.handlers.call(this,u,l),t=0;(i=s[t++])&&!u.isPropagationStopped();)for(u.currentTarget=i.elem,n=0;(o=i.handlers[n++])&&!u.isImmediatePropagationStopped();)u.rnamespace&&!1!==o.namespace&&!u.rnamespace.test(o.namespace)||(u.handleObj=o,u.data=o.data,void 0!==(r=((C.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,a))&&!1===(u.result=r)&&(u.preventDefault(),u.stopPropagation()));return c.postDispatch&&c.postDispatch.call(this,u),u.result}},handlers:function(e,t){var n,r,i,o,s,a=[],u=t.delegateCount,l=e.target;if(u&&l.nodeType&&!("click"===e.type&&e.button>=1))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&("click"!==e.type||!0!==l.disabled)){for(o=[],s={},n=0;n<u;n++)void 0===s[i=(r=t[n]).selector+" "]&&(s[i]=r.needsContext?C(i,this).index(l)>-1:C.find(i,this,null,[l]).length),s[i]&&o.push(r);o.length&&a.push({elem:l,handlers:o})}return l=this,u<t.length&&a.push({elem:l,handlers:t.slice(u)}),a},addProp:function(e,t){Object.defineProperty(C.Event.prototype,e,{enumerable:!0,configurable:!0,get:m(t)?function(){if(this.originalEvent)return t(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[e]},set:function(t){Object.defineProperty(this,e,{enumerable:!0,configurable:!0,writable:!0,value:t})}})},fix:function(e){return e[C.expando]?e:new C.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return ve.test(t.type)&&t.click&&A(t,"input")&&De(t,"click",je),!1},trigger:function(e){var t=this||e;return ve.test(t.type)&&t.click&&A(t,"input")&&De(t,"click"),!0},_default:function(e){var t=e.target;return ve.test(t.type)&&t.click&&A(t,"input")&&K.get(t,"click")||A(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},C.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},C.Event=function(e,t){if(!(this instanceof C.Event))return new C.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?je:Ne,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&C.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[C.expando]=!0},C.Event.prototype={constructor:C.Event,isDefaultPrevented:Ne,isPropagationStopped:Ne,isImmediatePropagationStopped:Ne,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=je,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=je,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=je,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},C.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(e){var t=e.button;return null==e.which&&Ce.test(e.type)?null!=e.charCode?e.charCode:e.keyCode:!e.which&&void 0!==t&&Ee.test(e.type)?1&t?1:2&t?3:4&t?2:0:e.which}},C.event.addProp),C.each({focus:"focusin",blur:"focusout"},(function(e,t){C.event.special[e]={setup:function(){return De(this,e,qe),!1},trigger:function(){return De(this,e),!0},delegateType:t}})),C.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},(function(e,t){C.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,o=e.handleObj;return i&&(i===r||C.contains(r,i))||(e.type=o.origType,n=o.handler.apply(this,arguments),e.type=t),n}}})),C.fn.extend({on:function(e,t,n,r){return Ae(this,e,t,n,r)},one:function(e,t,n,r){return Ae(this,e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,C(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=Ne),this.each((function(){C.event.remove(this,e,n,t)}))}});var Oe=/<script|<style|<link/i,Me=/checked\s*(?:[^=]|=\s*.checked.)/i,Ie=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function Le(e,t){return A(e,"table")&&A(11!==t.nodeType?t:t.firstChild,"tr")&&C(e).children("tbody")[0]||e}function _e(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function Pe(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function Re(e,t){var n,r,i,o,s,a;if(1===t.nodeType){if(K.hasData(e)&&(a=K.get(e).events))for(i in K.remove(t,"handle events"),a)for(n=0,r=a[i].length;n<r;n++)C.event.add(t,i,a[i][n]);Z.hasData(e)&&(o=Z.access(e),s=C.extend({},o),Z.set(t,s))}}function He(e,t){var n=t.nodeName.toLowerCase();"input"===n&&ve.test(e.type)?t.checked=e.checked:"input"!==n&&"textarea"!==n||(t.defaultValue=e.defaultValue)}function Fe(e,t,n,r){t=u(t);var i,o,s,a,l,c,f=0,d=e.length,p=d-1,h=t[0],g=m(h);if(g||d>1&&"string"==typeof h&&!v.checkClone&&Me.test(h))return e.each((function(i){var o=e.eq(i);g&&(t[0]=h.call(this,i,o.html())),Fe(o,t,n,r)}));if(d&&(o=(i=Te(t,e[0].ownerDocument,!1,e,r)).firstChild,1===i.childNodes.length&&(i=o),o||r)){for(a=(s=C.map(xe(i,"script"),_e)).length;f<d;f++)l=i,f!==p&&(l=C.clone(l,!0,!0),a&&C.merge(s,xe(l,"script"))),n.call(e[f],l,f);if(a)for(c=s[s.length-1].ownerDocument,C.map(s,Pe),f=0;f<a;f++)l=s[f],ye.test(l.type||"")&&!K.access(l,"globalEval")&&C.contains(c,l)&&(l.src&&"module"!==(l.type||"").toLowerCase()?C._evalUrl&&!l.noModule&&C._evalUrl(l.src,{nonce:l.nonce||l.getAttribute("nonce")},c):w(l.textContent.replace(Ie,""),l,c))}return e}function Be(e,t,n){for(var r,i=t?C.filter(t,e):e,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||C.cleanData(xe(r)),r.parentNode&&(n&&ae(r)&&we(xe(r,"script")),r.parentNode.removeChild(r));return e}C.extend({htmlPrefilter:function(e){return e},clone:function(e,t,n){var r,i,o,s,a=e.cloneNode(!0),u=ae(e);if(!(v.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||C.isXMLDoc(e)))for(s=xe(a),r=0,i=(o=xe(e)).length;r<i;r++)He(o[r],s[r]);if(t)if(n)for(o=o||xe(e),s=s||xe(a),r=0,i=o.length;r<i;r++)Re(o[r],s[r]);else Re(e,a);return(s=xe(a,"script")).length>0&&we(s,!u&&xe(e,"script")),a},cleanData:function(e){for(var t,n,r,i=C.event.special,o=0;void 0!==(n=e[o]);o++)if(J(n)){if(t=n[K.expando]){if(t.events)for(r in t.events)i[r]?C.event.remove(n,r):C.removeEvent(n,r,t.handle);n[K.expando]=void 0}n[Z.expando]&&(n[Z.expando]=void 0)}}}),C.fn.extend({detach:function(e){return Be(this,e,!0)},remove:function(e){return Be(this,e)},text:function(e){return Q(this,(function(e){return void 0===e?C.text(this):this.empty().each((function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)}))}),null,e,arguments.length)},append:function(){return Fe(this,arguments,(function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||Le(this,e).appendChild(e)}))},prepend:function(){return Fe(this,arguments,(function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=Le(this,e);t.insertBefore(e,t.firstChild)}}))},before:function(){return Fe(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this)}))},after:function(){return Fe(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)}))},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(C.cleanData(xe(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map((function(){return C.clone(this,e,t)}))},html:function(e){return Q(this,(function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!Oe.test(e)&&!be[(me.exec(e)||["",""])[1].toLowerCase()]){e=C.htmlPrefilter(e);try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(C.cleanData(xe(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)}),null,e,arguments.length)},replaceWith:function(){var e=[];return Fe(this,arguments,(function(t){var n=this.parentNode;C.inArray(this,e)<0&&(C.cleanData(xe(this)),n&&n.replaceChild(t,this))}),e)}}),C.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},(function(e,t){C.fn[e]=function(e){for(var n,r=[],i=C(e),o=i.length-1,s=0;s<=o;s++)n=s===o?this:this.clone(!0),C(i[s])[t](n),l.apply(r,n.get());return this.pushStack(r)}}));var Ue=new RegExp("^("+re+")(?!px)[a-z%]+$","i"),$e=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=n),t.getComputedStyle(e)},We=function(e,t,n){var r,i,o={};for(i in t)o[i]=e.style[i],e.style[i]=t[i];for(i in r=n.call(e),t)e.style[i]=o[i];return r},Qe=new RegExp(oe.join("|"),"i");function ze(e,t,n){var r,i,o,s,a=e.style;return(n=n||$e(e))&&(""!==(s=n.getPropertyValue(t)||n[t])||ae(e)||(s=C.style(e,t)),!v.pixelBoxStyles()&&Ue.test(s)&&Qe.test(t)&&(r=a.width,i=a.minWidth,o=a.maxWidth,a.minWidth=a.maxWidth=a.width=s,s=n.width,a.width=r,a.minWidth=i,a.maxWidth=o)),void 0!==s?s+"":s}function Xe(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function e(){if(c){l.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",c.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",se.appendChild(l).appendChild(c);var e=n.getComputedStyle(c);r="1%"!==e.top,u=12===t(e.marginLeft),c.style.right="60%",s=36===t(e.right),i=36===t(e.width),c.style.position="absolute",o=12===t(c.offsetWidth/3),se.removeChild(l),c=null}}function t(e){return Math.round(parseFloat(e))}var r,i,o,s,a,u,l=b.createElement("div"),c=b.createElement("div");c.style&&(c.style.backgroundClip="content-box",c.cloneNode(!0).style.backgroundClip="",v.clearCloneStyle="content-box"===c.style.backgroundClip,C.extend(v,{boxSizingReliable:function(){return e(),i},pixelBoxStyles:function(){return e(),s},pixelPosition:function(){return e(),r},reliableMarginLeft:function(){return e(),u},scrollboxSize:function(){return e(),o},reliableTrDimensions:function(){var e,t,r,i;return null==a&&(e=b.createElement("table"),t=b.createElement("tr"),r=b.createElement("div"),e.style.cssText="position:absolute;left:-11111px",t.style.height="1px",r.style.height="9px",se.appendChild(e).appendChild(t).appendChild(r),i=n.getComputedStyle(t),a=parseInt(i.height)>3,se.removeChild(e)),a}}))}();var Ve=["Webkit","Moz","ms"],Ge=b.createElement("div").style,Je={};function Ye(e){var t=C.cssProps[e]||Je[e];return t||(e in Ge?e:Je[e]=function(e){for(var t=e[0].toUpperCase()+e.slice(1),n=Ve.length;n--;)if((e=Ve[n]+t)in Ge)return e}(e)||e)}var Ke=/^(none|table(?!-c[ea]).+)/,Ze=/^--/,et={position:"absolute",visibility:"hidden",display:"block"},tt={letterSpacing:"0",fontWeight:"400"};function nt(e,t,n){var r=ie.exec(t);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):t}function rt(e,t,n,r,i,o){var s="width"===t?1:0,a=0,u=0;if(n===(r?"border":"content"))return 0;for(;s<4;s+=2)"margin"===n&&(u+=C.css(e,n+oe[s],!0,i)),r?("content"===n&&(u-=C.css(e,"padding"+oe[s],!0,i)),"margin"!==n&&(u-=C.css(e,"border"+oe[s]+"Width",!0,i))):(u+=C.css(e,"padding"+oe[s],!0,i),"padding"!==n?u+=C.css(e,"border"+oe[s]+"Width",!0,i):a+=C.css(e,"border"+oe[s]+"Width",!0,i));return!r&&o>=0&&(u+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-o-u-a-.5))||0),u}function it(e,t,n){var r=$e(e),i=(!v.boxSizingReliable()||n)&&"border-box"===C.css(e,"boxSizing",!1,r),o=i,s=ze(e,t,r),a="offset"+t[0].toUpperCase()+t.slice(1);if(Ue.test(s)){if(!n)return s;s="auto"}return(!v.boxSizingReliable()&&i||!v.reliableTrDimensions()&&A(e,"tr")||"auto"===s||!parseFloat(s)&&"inline"===C.css(e,"display",!1,r))&&e.getClientRects().length&&(i="border-box"===C.css(e,"boxSizing",!1,r),(o=a in e)&&(s=e[a])),(s=parseFloat(s)||0)+rt(e,t,n||(i?"border":"content"),o,r,s)+"px"}function ot(e,t,n,r,i){return new ot.prototype.init(e,t,n,r,i)}C.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=ze(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,s,a=G(t),u=Ze.test(t),l=e.style;if(u||(t=Ye(a)),s=C.cssHooks[t]||C.cssHooks[a],void 0===n)return s&&"get"in s&&void 0!==(i=s.get(e,!1,r))?i:l[t];"string"===(o=typeof n)&&(i=ie.exec(n))&&i[1]&&(n=ce(e,t,i),o="number"),null!=n&&n==n&&("number"!==o||u||(n+=i&&i[3]||(C.cssNumber[a]?"":"px")),v.clearCloneStyle||""!==n||0!==t.indexOf("background")||(l[t]="inherit"),s&&"set"in s&&void 0===(n=s.set(e,n,r))||(u?l.setProperty(t,n):l[t]=n))}},css:function(e,t,n,r){var i,o,s,a=G(t);return Ze.test(t)||(t=Ye(a)),(s=C.cssHooks[t]||C.cssHooks[a])&&"get"in s&&(i=s.get(e,!0,n)),void 0===i&&(i=ze(e,t,r)),"normal"===i&&t in tt&&(i=tt[t]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),C.each(["height","width"],(function(e,t){C.cssHooks[t]={get:function(e,n,r){if(n)return!Ke.test(C.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?it(e,t,r):We(e,et,(function(){return it(e,t,r)}))},set:function(e,n,r){var i,o=$e(e),s=!v.scrollboxSize()&&"absolute"===o.position,a=(s||r)&&"border-box"===C.css(e,"boxSizing",!1,o),u=r?rt(e,t,r,a,o):0;return a&&s&&(u-=Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-parseFloat(o[t])-rt(e,t,"border",!1,o)-.5)),u&&(i=ie.exec(n))&&"px"!==(i[3]||"px")&&(e.style[t]=n,n=C.css(e,t)),nt(0,n,u)}}})),C.cssHooks.marginLeft=Xe(v.reliableMarginLeft,(function(e,t){if(t)return(parseFloat(ze(e,"marginLeft"))||e.getBoundingClientRect().left-We(e,{marginLeft:0},(function(){return e.getBoundingClientRect().left})))+"px"})),C.each({margin:"",padding:"",border:"Width"},(function(e,t){C.cssHooks[e+t]={expand:function(n){for(var r=0,i={},o="string"==typeof n?n.split(" "):[n];r<4;r++)i[e+oe[r]+t]=o[r]||o[r-2]||o[0];return i}},"margin"!==e&&(C.cssHooks[e+t].set=nt)})),C.fn.extend({css:function(e,t){return Q(this,(function(e,t,n){var r,i,o={},s=0;if(Array.isArray(t)){for(r=$e(e),i=t.length;s<i;s++)o[t[s]]=C.css(e,t[s],!1,r);return o}return void 0!==n?C.style(e,t,n):C.css(e,t)}),e,t,arguments.length>1)}}),C.Tween=ot,ot.prototype={constructor:ot,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||C.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(C.cssNumber[n]?"":"px")},cur:function(){var e=ot.propHooks[this.prop];return e&&e.get?e.get(this):ot.propHooks._default.get(this)},run:function(e){var t,n=ot.propHooks[this.prop];return this.options.duration?this.pos=t=C.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):ot.propHooks._default.set(this),this}},ot.prototype.init.prototype=ot.prototype,ot.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=C.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){C.fx.step[e.prop]?C.fx.step[e.prop](e):1!==e.elem.nodeType||!C.cssHooks[e.prop]&&null==e.elem.style[Ye(e.prop)]?e.elem[e.prop]=e.now:C.style(e.elem,e.prop,e.now+e.unit)}}},ot.propHooks.scrollTop=ot.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},C.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},C.fx=ot.prototype.init,C.fx.step={};var st,at,ut=/^(?:toggle|show|hide)$/,lt=/queueHooks$/;function ct(){at&&(!1===b.hidden&&n.requestAnimationFrame?n.requestAnimationFrame(ct):n.setTimeout(ct,C.fx.interval),C.fx.tick())}function ft(){return n.setTimeout((function(){st=void 0})),st=Date.now()}function dt(e,t){var n,r=0,i={height:e};for(t=t?1:0;r<4;r+=2-t)i["margin"+(n=oe[r])]=i["padding"+n]=e;return t&&(i.opacity=i.width=e),i}function pt(e,t,n){for(var r,i=(ht.tweeners[t]||[]).concat(ht.tweeners["*"]),o=0,s=i.length;o<s;o++)if(r=i[o].call(n,t,e))return r}function ht(e,t,n){var r,i,o=0,s=ht.prefilters.length,a=C.Deferred().always((function(){delete u.elem})),u=function(){if(i)return!1;for(var t=st||ft(),n=Math.max(0,l.startTime+l.duration-t),r=1-(n/l.duration||0),o=0,s=l.tweens.length;o<s;o++)l.tweens[o].run(r);return a.notifyWith(e,[l,r,n]),r<1&&s?n:(s||a.notifyWith(e,[l,1,0]),a.resolveWith(e,[l]),!1)},l=a.promise({elem:e,props:C.extend({},t),opts:C.extend(!0,{specialEasing:{},easing:C.easing._default},n),originalProperties:t,originalOptions:n,startTime:st||ft(),duration:n.duration,tweens:[],createTween:function(t,n){var r=C.Tween(e,l.opts,t,n,l.opts.specialEasing[t]||l.opts.easing);return l.tweens.push(r),r},stop:function(t){var n=0,r=t?l.tweens.length:0;if(i)return this;for(i=!0;n<r;n++)l.tweens[n].run(1);return t?(a.notifyWith(e,[l,1,0]),a.resolveWith(e,[l,t])):a.rejectWith(e,[l,t]),this}}),c=l.props;for(!function(e,t){var n,r,i,o,s;for(n in e)if(i=t[r=G(n)],o=e[n],Array.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(s=C.cssHooks[r])&&"expand"in s)for(n in o=s.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(c,l.opts.specialEasing);o<s;o++)if(r=ht.prefilters[o].call(l,e,c,l.opts))return m(r.stop)&&(C._queueHooks(l.elem,l.opts.queue).stop=r.stop.bind(r)),r;return C.map(c,pt,l),m(l.opts.start)&&l.opts.start.call(e,l),l.progress(l.opts.progress).done(l.opts.done,l.opts.complete).fail(l.opts.fail).always(l.opts.always),C.fx.timer(C.extend(u,{elem:e,anim:l,queue:l.opts.queue})),l}C.Animation=C.extend(ht,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return ce(n.elem,e,ie.exec(t),n),n}]},tweener:function(e,t){m(e)?(t=e,e=["*"]):e=e.match(R);for(var n,r=0,i=e.length;r<i;r++)n=e[r],ht.tweeners[n]=ht.tweeners[n]||[],ht.tweeners[n].unshift(t)},prefilters:[function(e,t,n){var r,i,o,s,a,u,l,c,f="width"in t||"height"in t,d=this,p={},h=e.style,g=e.nodeType&&le(e),v=K.get(e,"fxshow");for(r in n.queue||(null==(s=C._queueHooks(e,"fx")).unqueued&&(s.unqueued=0,a=s.empty.fire,s.empty.fire=function(){s.unqueued||a()}),s.unqueued++,d.always((function(){d.always((function(){s.unqueued--,C.queue(e,"fx").length||s.empty.fire()}))}))),t)if(i=t[r],ut.test(i)){if(delete t[r],o=o||"toggle"===i,i===(g?"hide":"show")){if("show"!==i||!v||void 0===v[r])continue;g=!0}p[r]=v&&v[r]||C.style(e,r)}if((u=!C.isEmptyObject(t))||!C.isEmptyObject(p))for(r in f&&1===e.nodeType&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],null==(l=v&&v.display)&&(l=K.get(e,"display")),"none"===(c=C.css(e,"display"))&&(l?c=l:(pe([e],!0),l=e.style.display||l,c=C.css(e,"display"),pe([e]))),("inline"===c||"inline-block"===c&&null!=l)&&"none"===C.css(e,"float")&&(u||(d.done((function(){h.display=l})),null==l&&(c=h.display,l="none"===c?"":c)),h.display="inline-block")),n.overflow&&(h.overflow="hidden",d.always((function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]}))),u=!1,p)u||(v?"hidden"in v&&(g=v.hidden):v=K.access(e,"fxshow",{display:l}),o&&(v.hidden=!g),g&&pe([e],!0),d.done((function(){for(r in g||pe([e]),K.remove(e,"fxshow"),p)C.style(e,r,p[r])}))),u=pt(g?v[r]:0,r,d),r in v||(v[r]=u.start,g&&(u.end=u.start,u.start=0))}],prefilter:function(e,t){t?ht.prefilters.unshift(e):ht.prefilters.push(e)}}),C.speed=function(e,t,n){var r=e&&"object"==typeof e?C.extend({},e):{complete:n||!n&&t||m(e)&&e,duration:e,easing:n&&t||t&&!m(t)&&t};return C.fx.off?r.duration=0:"number"!=typeof r.duration&&(r.duration in C.fx.speeds?r.duration=C.fx.speeds[r.duration]:r.duration=C.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){m(r.old)&&r.old.call(this),r.queue&&C.dequeue(this,r.queue)},r},C.fn.extend({fadeTo:function(e,t,n,r){return this.filter(le).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=C.isEmptyObject(e),o=C.speed(t,n,r),s=function(){var t=ht(this,C.extend({},e),o);(i||K.get(this,"finish"))&&t.stop(!0)};return s.finish=s,i||!1===o.queue?this.each(s):this.queue(o.queue,s)},stop:function(e,t,n){var r=function(e){var t=e.stop;delete e.stop,t(n)};return"string"!=typeof e&&(n=t,t=e,e=void 0),t&&this.queue(e||"fx",[]),this.each((function(){var t=!0,i=null!=e&&e+"queueHooks",o=C.timers,s=K.get(this);if(i)s[i]&&s[i].stop&&r(s[i]);else for(i in s)s[i]&&s[i].stop&&lt.test(i)&&r(s[i]);for(i=o.length;i--;)o[i].elem!==this||null!=e&&o[i].queue!==e||(o[i].anim.stop(n),t=!1,o.splice(i,1));!t&&n||C.dequeue(this,e)}))},finish:function(e){return!1!==e&&(e=e||"fx"),this.each((function(){var t,n=K.get(this),r=n[e+"queue"],i=n[e+"queueHooks"],o=C.timers,s=r?r.length:0;for(n.finish=!0,C.queue(this,e,[]),i&&i.stop&&i.stop.call(this,!0),t=o.length;t--;)o[t].elem===this&&o[t].queue===e&&(o[t].anim.stop(!0),o.splice(t,1));for(t=0;t<s;t++)r[t]&&r[t].finish&&r[t].finish.call(this);delete n.finish}))}}),C.each(["toggle","show","hide"],(function(e,t){var n=C.fn[t];C.fn[t]=function(e,r,i){return null==e||"boolean"==typeof e?n.apply(this,arguments):this.animate(dt(t,!0),e,r,i)}})),C.each({slideDown:dt("show"),slideUp:dt("hide"),slideToggle:dt("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},(function(e,t){C.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}})),C.timers=[],C.fx.tick=function(){var e,t=0,n=C.timers;for(st=Date.now();t<n.length;t++)(e=n[t])()||n[t]!==e||n.splice(t--,1);n.length||C.fx.stop(),st=void 0},C.fx.timer=function(e){C.timers.push(e),C.fx.start()},C.fx.interval=13,C.fx.start=function(){at||(at=!0,ct())},C.fx.stop=function(){at=null},C.fx.speeds={slow:600,fast:200,_default:400},C.fn.delay=function(e,t){return e=C.fx&&C.fx.speeds[e]||e,t=t||"fx",this.queue(t,(function(t,r){var i=n.setTimeout(t,e);r.stop=function(){n.clearTimeout(i)}}))},function(){var e=b.createElement("input"),t=b.createElement("select").appendChild(b.createElement("option"));e.type="checkbox",v.checkOn=""!==e.value,v.optSelected=t.selected,(e=b.createElement("input")).value="t",e.type="radio",v.radioValue="t"===e.value}();var gt,vt=C.expr.attrHandle;C.fn.extend({attr:function(e,t){return Q(this,C.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each((function(){C.removeAttr(this,e)}))}}),C.extend({attr:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return void 0===e.getAttribute?C.prop(e,t,n):(1===o&&C.isXMLDoc(e)||(i=C.attrHooks[t.toLowerCase()]||(C.expr.match.bool.test(t)?gt:void 0)),void 0!==n?null===n?void C.removeAttr(e,t):i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:(e.setAttribute(t,n+""),n):i&&"get"in i&&null!==(r=i.get(e,t))?r:null==(r=C.find.attr(e,t))?void 0:r)},attrHooks:{type:{set:function(e,t){if(!v.radioValue&&"radio"===t&&A(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,r=0,i=t&&t.match(R);if(i&&1===e.nodeType)for(;n=i[r++];)e.removeAttribute(n)}}),gt={set:function(e,t,n){return!1===t?C.removeAttr(e,n):e.setAttribute(n,n),n}},C.each(C.expr.match.bool.source.match(/\w+/g),(function(e,t){var n=vt[t]||C.find.attr;vt[t]=function(e,t,r){var i,o,s=t.toLowerCase();return r||(o=vt[s],vt[s]=i,i=null!=n(e,t,r)?s:null,vt[s]=o),i}}));var mt=/^(?:input|select|textarea|button)$/i,yt=/^(?:a|area)$/i;function bt(e){return(e.match(R)||[]).join(" ")}function xt(e){return e.getAttribute&&e.getAttribute("class")||""}function wt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(R)||[]}C.fn.extend({prop:function(e,t){return Q(this,C.prop,e,t,arguments.length>1)},removeProp:function(e){return this.each((function(){delete this[C.propFix[e]||e]}))}}),C.extend({prop:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&C.isXMLDoc(e)||(t=C.propFix[t]||t,i=C.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=C.find.attr(e,"tabindex");return t?parseInt(t,10):mt.test(e.nodeName)||yt.test(e.nodeName)&&e.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),v.optSelected||(C.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),C.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],(function(){C.propFix[this.toLowerCase()]=this})),C.fn.extend({addClass:function(e){var t,n,r,i,o,s,a,u=0;if(m(e))return this.each((function(t){C(this).addClass(e.call(this,t,xt(this)))}));if((t=wt(e)).length)for(;n=this[u++];)if(i=xt(n),r=1===n.nodeType&&" "+bt(i)+" "){for(s=0;o=t[s++];)r.indexOf(" "+o+" ")<0&&(r+=o+" ");i!==(a=bt(r))&&n.setAttribute("class",a)}return this},removeClass:function(e){var t,n,r,i,o,s,a,u=0;if(m(e))return this.each((function(t){C(this).removeClass(e.call(this,t,xt(this)))}));if(!arguments.length)return this.attr("class","");if((t=wt(e)).length)for(;n=this[u++];)if(i=xt(n),r=1===n.nodeType&&" "+bt(i)+" "){for(s=0;o=t[s++];)for(;r.indexOf(" "+o+" ")>-1;)r=r.replace(" "+o+" "," ");i!==(a=bt(r))&&n.setAttribute("class",a)}return this},toggleClass:function(e,t){var n=typeof e,r="string"===n||Array.isArray(e);return"boolean"==typeof t&&r?t?this.addClass(e):this.removeClass(e):m(e)?this.each((function(n){C(this).toggleClass(e.call(this,n,xt(this),t),t)})):this.each((function(){var t,i,o,s;if(r)for(i=0,o=C(this),s=wt(e);t=s[i++];)o.hasClass(t)?o.removeClass(t):o.addClass(t);else void 0!==e&&"boolean"!==n||((t=xt(this))&&K.set(this,"__className__",t),this.setAttribute&&this.setAttribute("class",t||!1===e?"":K.get(this,"__className__")||""))}))},hasClass:function(e){var t,n,r=0;for(t=" "+e+" ";n=this[r++];)if(1===n.nodeType&&(" "+bt(xt(n))+" ").indexOf(t)>-1)return!0;return!1}});var kt=/\r/g;C.fn.extend({val:function(e){var t,n,r,i=this[0];return arguments.length?(r=m(e),this.each((function(n){var i;1===this.nodeType&&(null==(i=r?e.call(this,n,C(this).val()):e)?i="":"number"==typeof i?i+="":Array.isArray(i)&&(i=C.map(i,(function(e){return null==e?"":e+""}))),(t=C.valHooks[this.type]||C.valHooks[this.nodeName.toLowerCase()])&&"set"in t&&void 0!==t.set(this,i,"value")||(this.value=i))}))):i?(t=C.valHooks[i.type]||C.valHooks[i.nodeName.toLowerCase()])&&"get"in t&&void 0!==(n=t.get(i,"value"))?n:"string"==typeof(n=i.value)?n.replace(kt,""):null==n?"":n:void 0}}),C.extend({valHooks:{option:{get:function(e){var t=C.find.attr(e,"value");return null!=t?t:bt(C.text(e))}},select:{get:function(e){var t,n,r,i=e.options,o=e.selectedIndex,s="select-one"===e.type,a=s?null:[],u=s?o+1:i.length;for(r=o<0?u:s?o:0;r<u;r++)if(((n=i[r]).selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!A(n.parentNode,"optgroup"))){if(t=C(n).val(),s)return t;a.push(t)}return a},set:function(e,t){for(var n,r,i=e.options,o=C.makeArray(t),s=i.length;s--;)((r=i[s]).selected=C.inArray(C.valHooks.option.get(r),o)>-1)&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),C.each(["radio","checkbox"],(function(){C.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=C.inArray(C(e).val(),t)>-1}},v.checkOn||(C.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})})),v.focusin="onfocusin"in n;var Tt=/^(?:focusinfocus|focusoutblur)$/,Ct=function(e){e.stopPropagation()};C.extend(C.event,{trigger:function(e,t,r,i){var o,s,a,u,l,c,f,d,h=[r||b],g=p.call(e,"type")?e.type:e,v=p.call(e,"namespace")?e.namespace.split("."):[];if(s=d=a=r=r||b,3!==r.nodeType&&8!==r.nodeType&&!Tt.test(g+C.event.triggered)&&(g.indexOf(".")>-1&&(v=g.split("."),g=v.shift(),v.sort()),l=g.indexOf(":")<0&&"on"+g,(e=e[C.expando]?e:new C.Event(g,"object"==typeof e&&e)).isTrigger=i?2:3,e.namespace=v.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+v.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=r),t=null==t?[e]:C.makeArray(t,[e]),f=C.event.special[g]||{},i||!f.trigger||!1!==f.trigger.apply(r,t))){if(!i&&!f.noBubble&&!y(r)){for(u=f.delegateType||g,Tt.test(u+g)||(s=s.parentNode);s;s=s.parentNode)h.push(s),a=s;a===(r.ownerDocument||b)&&h.push(a.defaultView||a.parentWindow||n)}for(o=0;(s=h[o++])&&!e.isPropagationStopped();)d=s,e.type=o>1?u:f.bindType||g,(c=(K.get(s,"events")||Object.create(null))[e.type]&&K.get(s,"handle"))&&c.apply(s,t),(c=l&&s[l])&&c.apply&&J(s)&&(e.result=c.apply(s,t),!1===e.result&&e.preventDefault());return e.type=g,i||e.isDefaultPrevented()||f._default&&!1!==f._default.apply(h.pop(),t)||!J(r)||l&&m(r[g])&&!y(r)&&((a=r[l])&&(r[l]=null),C.event.triggered=g,e.isPropagationStopped()&&d.addEventListener(g,Ct),r[g](),e.isPropagationStopped()&&d.removeEventListener(g,Ct),C.event.triggered=void 0,a&&(r[l]=a)),e.result}},simulate:function(e,t,n){var r=C.extend(new C.Event,n,{type:e,isSimulated:!0});C.event.trigger(r,null,t)}}),C.fn.extend({trigger:function(e,t){return this.each((function(){C.event.trigger(e,t,this)}))},triggerHandler:function(e,t){var n=this[0];if(n)return C.event.trigger(e,t,n,!0)}}),v.focusin||C.each({focus:"focusin",blur:"focusout"},(function(e,t){var n=function(e){C.event.simulate(t,e.target,C.event.fix(e))};C.event.special[t]={setup:function(){var r=this.ownerDocument||this.document||this,i=K.access(r,t);i||r.addEventListener(e,n,!0),K.access(r,t,(i||0)+1)},teardown:function(){var r=this.ownerDocument||this.document||this,i=K.access(r,t)-1;i?K.access(r,t,i):(r.removeEventListener(e,n,!0),K.remove(r,t))}}}));var Et=n.location,St={guid:Date.now()},jt=/\?/;C.parseXML=function(e){var t;if(!e||"string"!=typeof e)return null;try{t=(new n.DOMParser).parseFromString(e,"text/xml")}catch(e){t=void 0}return t&&!t.getElementsByTagName("parsererror").length||C.error("Invalid XML: "+e),t};var Nt=/\[\]$/,qt=/\r?\n/g,At=/^(?:submit|button|image|reset|file)$/i,Dt=/^(?:input|select|textarea|keygen)/i;function Ot(e,t,n,r){var i;if(Array.isArray(t))C.each(t,(function(t,i){n||Nt.test(e)?r(e,i):Ot(e+"["+("object"==typeof i&&null!=i?t:"")+"]",i,n,r)}));else if(n||"object"!==k(t))r(e,t);else for(i in t)Ot(e+"["+i+"]",t[i],n,r)}C.param=function(e,t){var n,r=[],i=function(e,t){var n=m(t)?t():t;r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==n?"":n)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!C.isPlainObject(e))C.each(e,(function(){i(this.name,this.value)}));else for(n in e)Ot(n,e[n],t,i);return r.join("&")},C.fn.extend({serialize:function(){return C.param(this.serializeArray())},serializeArray:function(){return this.map((function(){var e=C.prop(this,"elements");return e?C.makeArray(e):this})).filter((function(){var e=this.type;return this.name&&!C(this).is(":disabled")&&Dt.test(this.nodeName)&&!At.test(e)&&(this.checked||!ve.test(e))})).map((function(e,t){var n=C(this).val();return null==n?null:Array.isArray(n)?C.map(n,(function(e){return{name:t.name,value:e.replace(qt,"\r\n")}})):{name:t.name,value:n.replace(qt,"\r\n")}})).get()}});var Mt=/%20/g,It=/#.*$/,Lt=/([?&])_=[^&]*/,_t=/^(.*?):[ \t]*([^\r\n]*)$/gm,Pt=/^(?:GET|HEAD)$/,Rt=/^\/\//,Ht={},Ft={},Bt="*/".concat("*"),Ut=b.createElement("a");function $t(e){return function(t,n){"string"!=typeof t&&(n=t,t="*");var r,i=0,o=t.toLowerCase().match(R)||[];if(m(n))for(;r=o[i++];)"+"===r[0]?(r=r.slice(1)||"*",(e[r]=e[r]||[]).unshift(n)):(e[r]=e[r]||[]).push(n)}}function Wt(e,t,n,r){var i={},o=e===Ft;function s(a){var u;return i[a]=!0,C.each(e[a]||[],(function(e,a){var l=a(t,n,r);return"string"!=typeof l||o||i[l]?o?!(u=l):void 0:(t.dataTypes.unshift(l),s(l),!1)})),u}return s(t.dataTypes[0])||!i["*"]&&s("*")}function Qt(e,t){var n,r,i=C.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);return r&&C.extend(!0,e,r),e}Ut.href=Et.href,C.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Et.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(Et.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Bt,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":C.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?Qt(Qt(e,C.ajaxSettings),t):Qt(C.ajaxSettings,e)},ajaxPrefilter:$t(Ht),ajaxTransport:$t(Ft),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var r,i,o,s,a,u,l,c,f,d,p=C.ajaxSetup({},t),h=p.context||p,g=p.context&&(h.nodeType||h.jquery)?C(h):C.event,v=C.Deferred(),m=C.Callbacks("once memory"),y=p.statusCode||{},x={},w={},k="canceled",T={readyState:0,getResponseHeader:function(e){var t;if(l){if(!s)for(s={};t=_t.exec(o);)s[t[1].toLowerCase()+" "]=(s[t[1].toLowerCase()+" "]||[]).concat(t[2]);t=s[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return l?o:null},setRequestHeader:function(e,t){return null==l&&(e=w[e.toLowerCase()]=w[e.toLowerCase()]||e,x[e]=t),this},overrideMimeType:function(e){return null==l&&(p.mimeType=e),this},statusCode:function(e){var t;if(e)if(l)T.always(e[T.status]);else for(t in e)y[t]=[y[t],e[t]];return this},abort:function(e){var t=e||k;return r&&r.abort(t),E(0,t),this}};if(v.promise(T),p.url=((e||p.url||Et.href)+"").replace(Rt,Et.protocol+"//"),p.type=t.method||t.type||p.method||p.type,p.dataTypes=(p.dataType||"*").toLowerCase().match(R)||[""],null==p.crossDomain){u=b.createElement("a");try{u.href=p.url,u.href=u.href,p.crossDomain=Ut.protocol+"//"+Ut.host!=u.protocol+"//"+u.host}catch(e){p.crossDomain=!0}}if(p.data&&p.processData&&"string"!=typeof p.data&&(p.data=C.param(p.data,p.traditional)),Wt(Ht,p,t,T),l)return T;for(f in(c=C.event&&p.global)&&0==C.active++&&C.event.trigger("ajaxStart"),p.type=p.type.toUpperCase(),p.hasContent=!Pt.test(p.type),i=p.url.replace(It,""),p.hasContent?p.data&&p.processData&&0===(p.contentType||"").indexOf("application/x-www-form-urlencoded")&&(p.data=p.data.replace(Mt,"+")):(d=p.url.slice(i.length),p.data&&(p.processData||"string"==typeof p.data)&&(i+=(jt.test(i)?"&":"?")+p.data,delete p.data),!1===p.cache&&(i=i.replace(Lt,"$1"),d=(jt.test(i)?"&":"?")+"_="+St.guid+++d),p.url=i+d),p.ifModified&&(C.lastModified[i]&&T.setRequestHeader("If-Modified-Since",C.lastModified[i]),C.etag[i]&&T.setRequestHeader("If-None-Match",C.etag[i])),(p.data&&p.hasContent&&!1!==p.contentType||t.contentType)&&T.setRequestHeader("Content-Type",p.contentType),T.setRequestHeader("Accept",p.dataTypes[0]&&p.accepts[p.dataTypes[0]]?p.accepts[p.dataTypes[0]]+("*"!==p.dataTypes[0]?", "+Bt+"; q=0.01":""):p.accepts["*"]),p.headers)T.setRequestHeader(f,p.headers[f]);if(p.beforeSend&&(!1===p.beforeSend.call(h,T,p)||l))return T.abort();if(k="abort",m.add(p.complete),T.done(p.success),T.fail(p.error),r=Wt(Ft,p,t,T)){if(T.readyState=1,c&&g.trigger("ajaxSend",[T,p]),l)return T;p.async&&p.timeout>0&&(a=n.setTimeout((function(){T.abort("timeout")}),p.timeout));try{l=!1,r.send(x,E)}catch(e){if(l)throw e;E(-1,e)}}else E(-1,"No Transport");function E(e,t,s,u){var f,d,b,x,w,k=t;l||(l=!0,a&&n.clearTimeout(a),r=void 0,o=u||"",T.readyState=e>0?4:0,f=e>=200&&e<300||304===e,s&&(x=function(e,t,n){for(var r,i,o,s,a=e.contents,u=e.dataTypes;"*"===u[0];)u.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("Content-Type"));if(r)for(i in a)if(a[i]&&a[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||e.converters[i+" "+u[0]]){o=i;break}s||(s=i)}o=o||s}if(o)return o!==u[0]&&u.unshift(o),n[o]}(p,T,s)),!f&&C.inArray("script",p.dataTypes)>-1&&(p.converters["text script"]=function(){}),x=function(e,t,n,r){var i,o,s,a,u,l={},c=e.dataTypes.slice();if(c[1])for(s in e.converters)l[s.toLowerCase()]=e.converters[s];for(o=c.shift();o;)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!u&&r&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),u=o,o=c.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(!(s=l[u+" "+o]||l["* "+o]))for(i in l)if((a=i.split(" "))[1]===o&&(s=l[u+" "+a[0]]||l["* "+a[0]])){!0===s?s=l[i]:!0!==l[i]&&(o=a[0],c.unshift(a[1]));break}if(!0!==s)if(s&&e.throws)t=s(t);else try{t=s(t)}catch(e){return{state:"parsererror",error:s?e:"No conversion from "+u+" to "+o}}}return{state:"success",data:t}}(p,x,T,f),f?(p.ifModified&&((w=T.getResponseHeader("Last-Modified"))&&(C.lastModified[i]=w),(w=T.getResponseHeader("etag"))&&(C.etag[i]=w)),204===e||"HEAD"===p.type?k="nocontent":304===e?k="notmodified":(k=x.state,d=x.data,f=!(b=x.error))):(b=k,!e&&k||(k="error",e<0&&(e=0))),T.status=e,T.statusText=(t||k)+"",f?v.resolveWith(h,[d,k,T]):v.rejectWith(h,[T,k,b]),T.statusCode(y),y=void 0,c&&g.trigger(f?"ajaxSuccess":"ajaxError",[T,p,f?d:b]),m.fireWith(h,[T,k]),c&&(g.trigger("ajaxComplete",[T,p]),--C.active||C.event.trigger("ajaxStop")))}return T},getJSON:function(e,t,n){return C.get(e,t,n,"json")},getScript:function(e,t){return C.get(e,void 0,t,"script")}}),C.each(["get","post"],(function(e,t){C[t]=function(e,n,r,i){return m(n)&&(i=i||r,r=n,n=void 0),C.ajax(C.extend({url:e,type:t,dataType:i,data:n,success:r},C.isPlainObject(e)&&e))}})),C.ajaxPrefilter((function(e){var t;for(t in e.headers)"content-type"===t.toLowerCase()&&(e.contentType=e.headers[t]||"")})),C._evalUrl=function(e,t,n){return C.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){C.globalEval(e,t,n)}})},C.fn.extend({wrapAll:function(e){var t;return this[0]&&(m(e)&&(e=e.call(this[0])),t=C(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map((function(){for(var e=this;e.firstElementChild;)e=e.firstElementChild;return e})).append(this)),this},wrapInner:function(e){return m(e)?this.each((function(t){C(this).wrapInner(e.call(this,t))})):this.each((function(){var t=C(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)}))},wrap:function(e){var t=m(e);return this.each((function(n){C(this).wrapAll(t?e.call(this,n):e)}))},unwrap:function(e){return this.parent(e).not("body").each((function(){C(this).replaceWith(this.childNodes)})),this}}),C.expr.pseudos.hidden=function(e){return!C.expr.pseudos.visible(e)},C.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},C.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(e){}};var zt={0:200,1223:204},Xt=C.ajaxSettings.xhr();v.cors=!!Xt&&"withCredentials"in Xt,v.ajax=Xt=!!Xt,C.ajaxTransport((function(e){var t,r;if(v.cors||Xt&&!e.crossDomain)return{send:function(i,o){var s,a=e.xhr();if(a.open(e.type,e.url,e.async,e.username,e.password),e.xhrFields)for(s in e.xhrFields)a[s]=e.xhrFields[s];for(s in e.mimeType&&a.overrideMimeType&&a.overrideMimeType(e.mimeType),e.crossDomain||i["X-Requested-With"]||(i["X-Requested-With"]="XMLHttpRequest"),i)a.setRequestHeader(s,i[s]);t=function(e){return function(){t&&(t=r=a.onload=a.onerror=a.onabort=a.ontimeout=a.onreadystatechange=null,"abort"===e?a.abort():"error"===e?"number"!=typeof a.status?o(0,"error"):o(a.status,a.statusText):o(zt[a.status]||a.status,a.statusText,"text"!==(a.responseType||"text")||"string"!=typeof a.responseText?{binary:a.response}:{text:a.responseText},a.getAllResponseHeaders()))}},a.onload=t(),r=a.onerror=a.ontimeout=t("error"),void 0!==a.onabort?a.onabort=r:a.onreadystatechange=function(){4===a.readyState&&n.setTimeout((function(){t&&r()}))},t=t("abort");try{a.send(e.hasContent&&e.data||null)}catch(e){if(t)throw e}},abort:function(){t&&t()}}})),C.ajaxPrefilter((function(e){e.crossDomain&&(e.contents.script=!1)})),C.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return C.globalEval(e),e}}}),C.ajaxPrefilter("script",(function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")})),C.ajaxTransport("script",(function(e){var t,n;if(e.crossDomain||e.scriptAttrs)return{send:function(r,i){t=C("<script>").attr(e.scriptAttrs||{}).prop({charset:e.scriptCharset,src:e.url}).on("load error",n=function(e){t.remove(),n=null,e&&i("error"===e.type?404:200,e.type)}),b.head.appendChild(t[0])},abort:function(){n&&n()}}}));var Vt,Gt=[],Jt=/(=)\?(?=&|$)|\?\?/;C.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Gt.pop()||C.expando+"_"+St.guid++;return this[e]=!0,e}}),C.ajaxPrefilter("json jsonp",(function(e,t,r){var i,o,s,a=!1!==e.jsonp&&(Jt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&Jt.test(e.data)&&"data");if(a||"jsonp"===e.dataTypes[0])return i=e.jsonpCallback=m(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,a?e[a]=e[a].replace(Jt,"$1"+i):!1!==e.jsonp&&(e.url+=(jt.test(e.url)?"&":"?")+e.jsonp+"="+i),e.converters["script json"]=function(){return s||C.error(i+" was not called"),s[0]},e.dataTypes[0]="json",o=n[i],n[i]=function(){s=arguments},r.always((function(){void 0===o?C(n).removeProp(i):n[i]=o,e[i]&&(e.jsonpCallback=t.jsonpCallback,Gt.push(i)),s&&m(o)&&o(s[0]),s=o=void 0})),"script"})),v.createHTMLDocument=((Vt=b.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Vt.childNodes.length),C.parseHTML=function(e,t,n){return"string"!=typeof e?[]:("boolean"==typeof t&&(n=t,t=!1),t||(v.createHTMLDocument?((r=(t=b.implementation.createHTMLDocument("")).createElement("base")).href=b.location.href,t.head.appendChild(r)):t=b),o=!n&&[],(i=D.exec(e))?[t.createElement(i[1])]:(i=Te([e],t,o),o&&o.length&&C(o).remove(),C.merge([],i.childNodes)));var r,i,o},C.fn.load=function(e,t,n){var r,i,o,s=this,a=e.indexOf(" ");return a>-1&&(r=bt(e.slice(a)),e=e.slice(0,a)),m(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),s.length>0&&C.ajax({url:e,type:i||"GET",dataType:"html",data:t}).done((function(e){o=arguments,s.html(r?C("<div>").append(C.parseHTML(e)).find(r):e)})).always(n&&function(e,t){s.each((function(){n.apply(this,o||[e.responseText,t,e])}))}),this},C.expr.pseudos.animated=function(e){return C.grep(C.timers,(function(t){return e===t.elem})).length},C.offset={setOffset:function(e,t,n){var r,i,o,s,a,u,l=C.css(e,"position"),c=C(e),f={};"static"===l&&(e.style.position="relative"),a=c.offset(),o=C.css(e,"top"),u=C.css(e,"left"),("absolute"===l||"fixed"===l)&&(o+u).indexOf("auto")>-1?(s=(r=c.position()).top,i=r.left):(s=parseFloat(o)||0,i=parseFloat(u)||0),m(t)&&(t=t.call(e,n,C.extend({},a))),null!=t.top&&(f.top=t.top-a.top+s),null!=t.left&&(f.left=t.left-a.left+i),"using"in t?t.using.call(e,f):("number"==typeof f.top&&(f.top+="px"),"number"==typeof f.left&&(f.left+="px"),c.css(f))}},C.fn.extend({offset:function(e){if(arguments.length)return void 0===e?this:this.each((function(t){C.offset.setOffset(this,e,t)}));var t,n,r=this[0];return r?r.getClientRects().length?(t=r.getBoundingClientRect(),n=r.ownerDocument.defaultView,{top:t.top+n.pageYOffset,left:t.left+n.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,n,r=this[0],i={top:0,left:0};if("fixed"===C.css(r,"position"))t=r.getBoundingClientRect();else{for(t=this.offset(),n=r.ownerDocument,e=r.offsetParent||n.documentElement;e&&(e===n.body||e===n.documentElement)&&"static"===C.css(e,"position");)e=e.parentNode;e&&e!==r&&1===e.nodeType&&((i=C(e).offset()).top+=C.css(e,"borderTopWidth",!0),i.left+=C.css(e,"borderLeftWidth",!0))}return{top:t.top-i.top-C.css(r,"marginTop",!0),left:t.left-i.left-C.css(r,"marginLeft",!0)}}},offsetParent:function(){return this.map((function(){for(var e=this.offsetParent;e&&"static"===C.css(e,"position");)e=e.offsetParent;return e||se}))}}),C.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},(function(e,t){var n="pageYOffset"===t;C.fn[e]=function(r){return Q(this,(function(e,r,i){var o;if(y(e)?o=e:9===e.nodeType&&(o=e.defaultView),void 0===i)return o?o[t]:e[r];o?o.scrollTo(n?o.pageXOffset:i,n?i:o.pageYOffset):e[r]=i}),e,r,arguments.length)}})),C.each(["top","left"],(function(e,t){C.cssHooks[t]=Xe(v.pixelPosition,(function(e,n){if(n)return n=ze(e,t),Ue.test(n)?C(e).position()[t]+"px":n}))})),C.each({Height:"height",Width:"width"},(function(e,t){C.each({padding:"inner"+e,content:t,"":"outer"+e},(function(n,r){C.fn[r]=function(i,o){var s=arguments.length&&(n||"boolean"!=typeof i),a=n||(!0===i||!0===o?"margin":"border");return Q(this,(function(t,n,i){var o;return y(t)?0===r.indexOf("outer")?t["inner"+e]:t.document.documentElement["client"+e]:9===t.nodeType?(o=t.documentElement,Math.max(t.body["scroll"+e],o["scroll"+e],t.body["offset"+e],o["offset"+e],o["client"+e])):void 0===i?C.css(t,n,a):C.style(t,n,i,a)}),t,s?i:void 0,s)}}))})),C.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],(function(e,t){C.fn[t]=function(e){return this.on(t,e)}})),C.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)},hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),C.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),(function(e,t){C.fn[t]=function(e,n){return arguments.length>0?this.on(t,null,e,n):this.trigger(t)}}));var Yt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;C.proxy=function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),m(e))return r=a.call(arguments,2),(i=function(){return e.apply(t||this,r.concat(a.call(arguments)))}).guid=e.guid=e.guid||C.guid++,i},C.holdReady=function(e){e?C.readyWait++:C.ready(!0)},C.isArray=Array.isArray,C.parseJSON=JSON.parse,C.nodeName=A,C.isFunction=m,C.isWindow=y,C.camelCase=G,C.type=k,C.now=Date.now,C.isNumeric=function(e){var t=C.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},C.trim=function(e){return null==e?"":(e+"").replace(Yt,"")},void 0===(r=function(){return C}.apply(t,[]))||(e.exports=r);var Kt=n.jQuery,Zt=n.$;return C.noConflict=function(e){return n.$===C&&(n.$=Zt),e&&n.jQuery===C&&(n.jQuery=Kt),C},void 0===i&&(n.jQuery=n.$=C),C}))},22:function(e,t,n){"use strict";n.d(t,"b",(function(){return f})),n.d(t,"a",(function(){return d})),n.d(t,"c",(function(){return g}));var r=n(1),i=n.n(r),o=n(3),s=n.n(o),a=n(46),u={},l=s.a.sessionStorage.prefixedKey("v2-machines.json"),c=s.a.sessionStorage.prefixedKey("v1-session-machine");function f(e){e||(e=s.a.transport.host);const t=window.localStorage.getItem("superuser-key");return"localhost"==e?t:e.indexOf("@")>=0?"superuser:"+e:t?t+"@"+e:null}function d(e){let t=null;const n=f(e.host);return n&&(t=window.localStorage.getItem(n)),"sudo"!=t||e.password||(t="none"),t}function p(){var e=this,t=null;e.ready=!1;var n={},r={content:null,overlay:{localhost:{visible:!0,manifests:s.a.manifests}}};function o(e){e.key===l&&e.storageArea===window.sessionStorage&&p(JSON.parse(e.newValue||"null"))}window.addEventListener("storage",o),window.setTimeout((function(){var t=window.sessionStorage.getItem(l);!e.ready&&t&&p(JSON.parse(t))}));var f=null;function d(e,t,n){var r,o=i.a.extend({},t||{},n||{});for(r in o)e[r]!==o[r]&&(e[r]=o[r]);for(r in e)e[r]!==o[r]&&delete e[r];return e}function p(o,a){if(o){var u;r=o,t=null,a&&!f&&(f=window.setTimeout((function(){f=null,window.sessionStorage.setItem(l,JSON.stringify(r))}),10));var c={},p=o.content||{},h=o.overlay||{};for(u in p)c[u]=!0;for(u in h)c[u]=!0;var g,v,m,y=[];for(u in c){var b=n[u]||{},x=b.connection_string;p[u]&&p[u].color&&h[u]&&delete h[u].color,(g=d(b,p[u],h[u])).key=u,g.address||(g.address=u),g.connection_string=e.generate_connection_string(g.user,g.port,g.address),g.label||("localhost"==u||"localhost.localdomain"==u?0===(v=s.a.transport.application()).indexOf("cockpit+=")?g.label=v.replace("cockpit+=",""):g.label=window.location.hostname:g.label=u),g.avatar||(g.avatar="../shell/images/server-small.png"),y.push([u in n?"updated":"added",[g,u,x]]),n[u]=g}for(u in n)u in c||(g=n[u],delete n[u],delete h[u],y.push(["removed",[g,u]]));var w=i()(e),k=y.length;for(m=0;m<k;m++)w.triggerHandler(y[m][0],y[m][1])}}function h(t,n,r){var o=function(e){return c+"/"+e}(n),a=i.a.extend({},t,r);return window.sessionStorage.setItem(o,JSON.stringify(a)),e.overlay(n,r),s.a.when([])}function g(e){var t,r,i=u.colors.parse(e);for(t in n)if((r=n[t]).color&&u.colors.parse(r.color)==i)return!0;return!1}function v(e,t){for(var n in t)null===t[n]?delete e[n]:e[n]=t[n]}e.set_ready=function(){e.ready||(e.ready=!0,i()(e).triggerHandler("ready"))},e.add_key=function(e){return s.a.script(a.a,[e.trim(),"known_hosts"],{err:"message"})},e.add=function(t,n){var r=e.split_connection_string(t),o=r.address;r=i.a.extend({visible:!0,color:n||e.unused_color()},r);var s=e.lookup(o);return s&&(s.on_disk=!0),e.change(r.address,r)},e.unused_color=function(){var e,t=u.colors.length;for(e=0;e<t;e++)if(!g(u.colors[e]))return u.colors[e];return"gray"},e.change=function(t,n){var r=e.lookup(t);return r&&!r.on_disk?h(r,t,n):function(t,n){var r={};for(var i in n)null!==n[i]&&(r[i]="visible"==i?s.a.variant("b",n[i]):s.a.variant("s",n[i].toString()));return s.a.dbus(null,{bus:"internal",superuser:"try"}).call("/machines","cockpit.Machines","Update",["99-webui.json",t,r]).catch((function(e){console.error("failed to call cockpit.Machines.Update(): ",e)})).then((()=>{e.overlay(t,n)}))}(t,n)},e.data=function(e){var t,o={};for(t in e)o[t]=i.a.extend({},r.overlay[t]||{}),v(o[t],{on_disk:!0});for(t in n)e&&!e[t]&&(o[t]=i.a.extend({},r.overlay[t]||{}),v(o[t],{on_disk:null}));p({content:e,overlay:i.a.extend({},r.overlay,o)},!0)},e.overlay=function(t,n){var o=e.split_connection_string(t).address,s={};s[o]=i.a.extend({},r.overlay[o]||{}),v(s[o],n),p({content:r.content,overlay:i.a.extend({},r.overlay,s)},!0)},Object.defineProperty(e,"list",{enumerable:!0,get:function(){var e;if(!t){for(e in t=[],n)n[e].visible&&t.push(n[e]);t.sort((function(e,t){return e.label.localeCompare(t.label)}))}return t}}),Object.defineProperty(e,"addresses",{enumerable:!0,get:function(){return Object.keys(n)}}),e.lookup=function(t){var r=e.split_connection_string(t);return n[r.address||"localhost"]||null},e.generate_connection_string=function(e,t,n){var r=n;return e&&(r=e+"@"+r),t&&(r=r+":"+t),r},e.split_connection_string=function(e){var t={},n=-1,r=-1;if(e&&(n=e.lastIndexOf("@"),r=e.lastIndexOf(":")),n>0&&(t.user=e.substring(0,n),r=(e=e.substring(n+1)).lastIndexOf(":")),r>-1){var i=parseInt(e.substring(r+1),10);isNaN(i)||(t.port=i,e=e.substring(0,r))}return t.address=e,t},e.close=function(){window.removeEventListener("storage",o)}}function h(e,t){var n=this,r=!1,o={},a={},u={};function l(t,r){var i,o,s,a=t.split("/");a[0]==c&&2===a.length&&(i=a[1],r&&(o=JSON.parse(r),(s=e.lookup(i))&&s.on_disk?s.visible||e.change(i,{visible:!0}):e.overlay(i,o),n.connect(i)))}function f(){var e;for(r=!0,e=0;e<window.sessionStorage.length;e++){var t=window.sessionStorage.key(e);l(t,window.sessionStorage.getItem(t))}}function p(e){e.storageArea===window.sessionStorage&&l(e.key||"",e.newValue)}function h(t,n,r){var i={state:n,problem:r};"connected"==n?i.restarting=!1:r&&(i.manifests=null,i.checksum=null,"authentication-failed"!=r&&"authentication-not-supported"!=r||(i.restarting=!1)),e.overlay(t,i)}function g(t,r,o,u){if(r||(r=e.lookup(o))){var l=a[o];l&&l.valid||(l={});var c={};r.color||(c.color=e.unused_color());var f=l.PrettyHostname||l.StaticHostname;f&&f!==r.label&&(c.label=f);var d=l.OperatingSystemPrettyName;d&&d!=r.os&&(c.os=l.OperatingSystemPrettyName),i.a.isEmptyObject(c)||e.overlay(o,c),r.visible?u&&r.connection_string!=u&&(s.a.kill(u),n.disconnect(o),n.connect(o)):n.disconnect(o)}}function v(e,t,r){n.disconnect(r)}if(window.addEventListener("storage",p),i()(e).on("added",g),i()(e).on("updated",g),i()(e).on("removed",v),n.connect=function(t){var r=e.lookup(t);if(r){var l=o[t];if(!l){var c={host:r.connection_string,payload:"echo"};c["init-superuser"]=d(c),!r.on_disk&&r.host_key&&(c["temp-session"]=!1,c.session="shared",c["host-key"]=r.host_key),l=s.a.channel(c),o[t]=l;var f,p="localhost"===t,v=null,m=p;r.manifests||(f=r.checksum?"../../"+r.checksum+"/manifests.json":"../../@"+encodeURI(r.connection_string)+"/manifests.json"),p?(f&&b(),x(),w()):(l.send("x"),i()(l).on("message",(function(){m=!0,f&&b(),x(),w(),y()})).on("close",(function(r,i){var o=e.lookup(t);m=!1,i.problem||!o||o.visible?h(t,"failed",i.problem||"disconnected"):h(t,null,null),o&&o.restarting&&window.setTimeout((function(){n.connect(t)}),1e4),n.disconnect(t)}))),y()}}function y(){h(t,!v&&m?"connected":"connecting",null)}function b(){v=i.a.ajax({url:f,dataType:"json",cache:!0}).done((function(n){var r={manifests:n},i=v.getResponseHeader("ETag");i&&(r.checksum=i.replace(/^"(.+)"$/,"$1")),e.overlay(t,r)})).fail((function(e){console.warn("failed to load manifests from "+r.connection_string+": "+e)})).always((function(){v=null,y()}))}function x(){var n=s.a.dbus(null,{bus:"internal",host:r.connection_string});u[t]=n,n.subscribe({path:"/packages",interface:"org.freedesktop.DBus.Properties",member:"PropertiesChanged"},(function(n,r,i,o){if("cockpit.Packages"==o[0]&&o[1].Manifests){var s=JSON.parse(o[1].Manifests.v);e.overlay(t,{manifests:s})}})),n.call("/packages","cockpit.Packages","ReloadHint",[])}function w(){if(!r.static_hostname){var e=s.a.dbus("org.freedesktop.hostname1",{host:r.connection_string}).proxy();a[t]=e,e.wait((function(){i()(e).on("changed",(function(){g(0,null,t)})),g(0,null,t)}))}}},n.disconnect=function(e){if("localhost"!==e){var t=o[e];delete o[e],t&&(t.close(),i()(t).off());var n=a[e];delete a[e],n&&(n.client.close(),i()(n).off());var r=u[e];delete u[e],r&&r.close()}},n.expect_restart=function(t){var n=e.split_connection_string(t);e.overlay(n.address,{restarting:!0,problem:null})},n.close=function(){i()(e).off("added",g),i()(e).off("changed",g),i()(e).off("removed",v),e=null,window.removeEventListener("storage",p),Object.keys(o).forEach(n.disconnect)},t)f(),e.data({}),e.set_ready();else{var m=s.a.dbus(null,{bus:"internal"}).proxy("cockpit.Machines","/machines");i()(m).on("changed",(function(t){var n,i=m.Machines,o={};for(var s in i){for(var a in n={},i[s])n[a]=i[s][a].v;o[s]=n}e.data(o),r||f(),e.set_ready()}))}}u.instance=function(e){return new p},u.loader=function(e,t){return new h(e,t)},u.colors=["#0099d3","#67d300","#d39e00","#d3007c","#00d39f","#00d1d3","#00618a","#4c8a00","#8a6600","#9b005b","#008a55","#008a8a","#00b9ff","#7dff00","#ffbe00","#ff0096","#00ffc0","#00fdff","#023448","#264802","#483602","#590034","#024830","#024848"],u.colors.parse=function(e){var t=document.createElement("div");return t.style.color=e,window.getComputedStyle(t,null).getPropertyValue("color")||t.style.color};const g=u},262:function(e,t,n){(function(e){var r=void 0!==e&&e||"undefined"!=typeof self&&self||window,i=Function.prototype.apply;function o(e,t){this._id=e,this._clearFn=t}t.setTimeout=function(){return new o(i.call(setTimeout,r,arguments),clearTimeout)},t.setInterval=function(){return new o(i.call(setInterval,r,arguments),clearInterval)},t.clearTimeout=t.clearInterval=function(e){e&&e.close()},o.prototype.unref=o.prototype.ref=function(){},o.prototype.close=function(){this._clearFn.call(r,this._id)},t.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},t.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},t._unrefActive=t.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout((function(){e._onTimeout&&e._onTimeout()}),t))},n(263),t.setImmediate="undefined"!=typeof self&&self.setImmediate||void 0!==e&&e.setImmediate||this&&this.setImmediate,t.clearImmediate="undefined"!=typeof self&&self.clearImmediate||void 0!==e&&e.clearImmediate||this&&this.clearImmediate}).call(this,n(43))},263:function(e,t,n){(function(e,t){!function(e,n){"use strict";if(!e.setImmediate){var r,i,o,s,a,u=1,l={},c=!1,f=e.document,d=Object.getPrototypeOf&&Object.getPrototypeOf(e);d=d&&d.setTimeout?d:e,"[object process]"==={}.toString.call(e.process)?r=function(e){t.nextTick((function(){h(e)}))}:!function(){if(e.postMessage&&!e.importScripts){var t=!0,n=e.onmessage;return e.onmessage=function(){t=!1},e.postMessage("","*"),e.onmessage=n,t}}()?e.MessageChannel?((o=new MessageChannel).port1.onmessage=function(e){h(e.data)},r=function(e){o.port2.postMessage(e)}):f&&"onreadystatechange"in f.createElement("script")?(i=f.documentElement,r=function(e){var t=f.createElement("script");t.onreadystatechange=function(){h(e),t.onreadystatechange=null,i.removeChild(t),t=null},i.appendChild(t)}):r=function(e){setTimeout(h,0,e)}:(s="setImmediate$"+Math.random()+"$",a=function(t){t.source===e&&"string"==typeof t.data&&0===t.data.indexOf(s)&&h(+t.data.slice(s.length))},e.addEventListener?e.addEventListener("message",a,!1):e.attachEvent("onmessage",a),r=function(t){e.postMessage(s+t,"*")}),d.setImmediate=function(e){"function"!=typeof e&&(e=new Function(""+e));for(var t=new Array(arguments.length-1),n=0;n<t.length;n++)t[n]=arguments[n+1];var i={callback:e,args:t};return l[u]=i,r(u),u++},d.clearImmediate=p}function p(e){delete l[e]}function h(e){if(c)setTimeout(h,0,e);else{var t=l[e];if(t){c=!0;try{!function(e){var t=e.callback,n=e.args;switch(n.length){case 0:t();break;case 1:t(n[0]);break;case 2:t(n[0],n[1]);break;case 3:t(n[0],n[1],n[2]);break;default:t.apply(void 0,n)}}(t)}finally{p(e),c=!1}}}}}("undefined"==typeof self?void 0===e?this:e:self)}).call(this,n(43),n(264))},264:function(e,t){var n,r,i=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function s(){throw new Error("clearTimeout has not been defined")}function a(e){if(n===setTimeout)return setTimeout(e,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(e,0);try{return n(e,0)}catch(t){try{return n.call(null,e,0)}catch(t){return n.call(this,e,0)}}}!function(){try{n="function"==typeof setTimeout?setTimeout:o}catch(e){n=o}try{r="function"==typeof clearTimeout?clearTimeout:s}catch(e){r=s}}();var u,l=[],c=!1,f=-1;function d(){c&&u&&(c=!1,u.length?l=u.concat(l):f=-1,l.length&&p())}function p(){if(!c){var e=a(d);c=!0;for(var t=l.length;t;){for(u=l,l=[];++f<t;)u&&u[f].run();f=-1,t=l.length}u=null,c=!1,function(e){if(r===clearTimeout)return clearTimeout(e);if((r===s||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(e);try{r(e)}catch(t){try{return r.call(null,e)}catch(t){return r.call(this,e)}}}(e)}}function h(e,t){this.fun=e,this.array=t}function g(){}i.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)t[n-1]=arguments[n];l.push(new h(e,t)),1!==l.length||c||a(p)},h.prototype.run=function(){this.fun.apply(null,this.array)},i.title="browser",i.browser=!0,i.env={},i.argv=[],i.version="",i.versions={},i.on=g,i.addListener=g,i.once=g,i.off=g,i.removeListener=g,i.removeAllListeners=g,i.emit=g,i.prependListener=g,i.prependOnceListener=g,i.listeners=function(e){return[]},i.binding=function(e){throw new Error("process.binding is not supported")},i.cwd=function(){return"/"},i.chdir=function(e){throw new Error("process.chdir is not supported")},i.umask=function(){return 0}},265:function(e,t,n){"use strict";var r=!1;QUnit.config.autostart=!1;var i=window.onerror;window.onerror=null,QUnit.begin((function(){window.onerror=function(e,t,n){var r=!1;return i&&(r=i(e,t,n)),QUnit.config.current&&QUnit.config.current.async&&QUnit.start(),r}})),QUnit.moduleStart((function(){r=!0})),QUnit.done((function(){window.setTimeout((function(){console.log("cockpittest-tap-done")}),0),window.onerror=null}));var o=/^((not )?ok [0-9]+ (- )?)(.*)$/;qunitTap(QUnit,(function(){if(1==arguments.length&&QUnit.config.current){var e=o.exec(arguments[0]);if(e)return void console.log(e[1]+QUnit.config.current.testName+": "+e[4])}console.log.apply(console,arguments)})),window.setTimeout((function(){r||(console.log("QUnit not started by test"),console.log("cockpittest-tap-error"))}),2e4),window.tests_included=!0},266:function(e,t,n){"use strict";n.r(t)},268:function(e,t,n){"use strict";n.r(t);var r=n(3),i=n.n(r),o=n(92),s=n.n(o),a=n(131),u=n.n(a);window.QUnit=s.a,window.qunitTap=u.a,n(265),n(266);var l,c=s.a,f=n(22),d=i.a.dbus(null,{bus:"internal"});function p(e,t,n){const r=e.async();e.expect(3);var o,s=[];for(var a in t)o=a,a.indexOf("/")<0&&(o=l+"/cockpit/machines.d/"+a),s.push(i.a.file(o).replace(t[a]));Promise.all(s).then((function(){d.call("/machines","org.freedesktop.DBus.Properties","Get",["cockpit.Machines","Machines"],{type:"ss"}).done((function(t){e.equal(t[0].t,"a{sa{sv}}","expected return type"),e.deepEqual(t[0].v,n,"expected property value")})).always((function(){e.equal(this.state(),"resolved","finished successfully"),r()}))}))}function h(e,t,n,r,o){const s=e.async();e.expect(3);var a=l+"/cockpit/machines.d/99-webui.json";i.a.file(a).replace(t).done((function(t){d.call("/machines","cockpit.Machines","Update",["99-webui.json",n,r],{type:"ssa{sv}"}).then((function(t){return e.deepEqual(t,[],"no expected return value"),i.a.file(a,{syntax:JSON}).read().done((function(t,n){e.deepEqual(t,o,"expected file content")})).fail((function(t){e.equal(t,void 0,"expected no error")}))})).always((function(){e.equal(this.state(),"resolved","finished successfully"),s()}))}))}c.module("machines.d parsing tests",{beforeEach:()=>i.a.spawn(["mkdir","-p",l+"/cockpit/machines.d"]),afterEach:()=>i.a.spawn(["rm","-rf",l+"/cockpit/machines.d"]),after:()=>i.a.spawn(["rm","-r",l])}),c.test("no machine definitions",(function(e){p(e,{},{})})),c.test("empty json",(function(e){p(e,{"01.json":""},{})})),c.test("two definitions",(function(e){p(e,{"01.json":'{"green": {"visible": true, "address": "1.2.3.4"},  "9.8.7.6": {"visible": false, "address": "9.8.7.6", "user": "admin"}}'},{green:{address:{t:"s",v:"1.2.3.4"},visible:{t:"b",v:!0}},"9.8.7.6":{address:{t:"s",v:"9.8.7.6"},user:{t:"s",v:"admin"},visible:{t:"b",v:!1}}})})),c.test("invalid json",(function(e){p(e,{"01.json":'{"green":'},{})})),c.test("invalid data types",(function(e){p(e,{"01.json":'{"green": []}'},{})})),c.test("merge several JSON files",(function(e){p(e,{"01-green.json":'{"green": {"visible": true, "address": "1.2.3.4"}}',"02-blue.json":'{"blue": {"address": "9.8.7.6"}}',"09-webui.json":'{"green": {"visible": false},  "blue":  {"user": "joe"},  "yellow": {"address": "fe80::1", "user": "sue"}}'},{green:{address:{t:"s",v:"1.2.3.4"},visible:{t:"b",v:!1}},blue:{address:{t:"s",v:"9.8.7.6"},user:{t:"s",v:"joe"}},yellow:{address:{t:"s",v:"fe80::1"},user:{t:"s",v:"sue"}}})})),c.test("merge JSON files with errors",(function(e){p(e,{"01-valid.json":'{"green": {"visible": true, "address": "1.2.3.4"}}',"02-syntax.json":"[a","03-toptype.json":'["green"]',"04-toptype.json":'{"green": ["visible"]}',"05-valid.json":'{"blue": {"address": "fe80::1"}}',"06-proptype.json":'{"green": {"visible": [], "address": {"bar": null}, "goodprop": "yeah"}}',"07-valid.json":'{"green": {"user": "joe"}}',"08-empty.json":""},{green:{address:{t:"s",v:"1.2.3.4"},visible:{t:"b",v:!0},user:{t:"s",v:"joe"},goodprop:{t:"s",v:"yeah"}},blue:{address:{t:"s",v:"fe80::1"}}})})),c.test("no config files",(function(e){h(e,null,"green",{visible:i.a.variant("b",!0),address:i.a.variant("s","1.2.3.4")},{green:{address:"1.2.3.4",visible:!0}})})),c.test("add host to existing map",(function(e){h(e,'{"green": {"visible": true, "address": "1.2.3.4"}}',"blue",{visible:i.a.variant("b",!1),address:i.a.variant("s","9.8.7.6")},{green:{address:"1.2.3.4",visible:!0},blue:{address:"9.8.7.6",visible:!1}})})),c.test("change bool host property",(function(e){h(e,'{"green": {"visible": true, "address": "1.2.3.4"}}',"green",{visible:i.a.variant("b",!1)},{green:{address:"1.2.3.4",visible:!1}})})),c.test("change string host property",(function(e){h(e,'{"green": {"visible": true, "address": "1.2.3.4"}}',"green",{address:i.a.variant("s","fe80::1")},{green:{address:"fe80::1",visible:!0}})})),c.test("add host property",(function(e){h(e,'{"green": {"visible": true, "address": "1.2.3.4"}}',"green",{color:i.a.variant("s","pitchblack")},{green:{address:"1.2.3.4",visible:!0,color:"pitchblack"}})})),c.test("Update() only writes delta",(function(e){const t=e.async();i.a.file(l+"/cockpit/machines.d/01-green.json").replace('{"green": {"address": "1.2.3.4"}, "blue": {"address": "fe80::1"}}').done((function(n){h(e,null,"green",{color:i.a.variant("s","pitchblack")},{green:{color:"pitchblack"}}),t()}))})),c.test("updating and existing delta file",(function(e){const t=e.async();i.a.file(l+"/cockpit/machines.d/01-green.json").replace('{"green": {"address": "1.2.3.4"}, "blue": {"address": "fe80::1"}}').done((function(n){h(e,'{"green": {"address": "9.8.7.6", "user": "joe"}}',"green",{color:i.a.variant("s","pitchblack")},{green:{address:"9.8.7.6",user:"joe",color:"pitchblack"}}),t()}))})),c.test("colors.parse()",(function(e){const t=[["#960064","rgb(150, 0, 100)"],["rgb(150, 0, 100)","rgb(150, 0, 100)"],["#ccc","rgb(204, 204, 204)"]];e.expect(t.length),t.forEach((function(t){e.equal(f.c.colors.parse(t[0]),t[1],"parsed color "+t[0])}))}));var g=d.proxy("cockpit.Environment","/environment");g.wait((function(){l=g.Variables.XDG_CONFIG_DIRS,c.start()}))},3:function(e,t){e.exports=cockpit},43:function(e,t){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"==typeof window&&(n=window)}e.exports=n},46:function(e,t,n){"use strict";t.a='#! /bin/sh\n\nset -euf\n\nd=$HOME/.ssh\np=${2:-authorized_keys}\nf=$d/$p\n\nif ! test -f "$f"; then\n    mkdir -m 700 -p "$d"\n    touch "$f"\n    chmod 600 "$f"\nfi\n\nwhile read l; do\n    if [ "$l" = "$1" ]; then\n        exit 0\n    fi\ndone <"$f"\n\n# Add newline if necessary\n! test -s "$f" || tail -c1 < "$f" | read -r _ || echo >> "$f"\n\necho "$1" >>"$f"\n'},63:function(e,t){e.exports=function(e){return e.webpackPolyfill||(e.deprecate=function(){},e.paths=[],e.children||(e.children=[]),Object.defineProperty(e,"loaded",{enumerable:!0,get:function(){return e.l}}),Object.defineProperty(e,"id",{enumerable:!0,get:function(){return e.i}}),e.webpackPolyfill=1),e}},81:function(e,t,n){"use strict";(function(t){e.exports=function(){if("object"==typeof globalThis)return globalThis;var e;try{e=this||new Function("return this")()}catch(e){if("object"==typeof window)return window;if("object"==typeof self)return self;if(void 0!==t)return t}return e}()}).call(this,n(43))},92:function(e,t,n){(function(e,r,i){var o;
/*!
 * QUnit 2.15.0
 * https://qunitjs.com/
 *
 * Copyright OpenJS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 */!function(){"use strict";var s,a="function"==typeof a?a:function(){var e=Object.create(null);this.get=function(t){return e[t]},this.set=function(t,n){return e[t]=n,this},this.clear=function(){e=Object.create(null)}};function u(e){return(u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function l(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function c(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}function f(e,t,n){return t&&c(e.prototype,t),n&&c(e,n),e}function d(e){return function(e){if(Array.isArray(e))return h(e)}(e)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(e)||p(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function p(e,t){if(e){if("string"==typeof e)return h(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?h(e,t):void 0}}function h(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}!function(e){if("object"===("undefined"==typeof globalThis?"undefined":u(globalThis)))s=globalThis;else{var t=function(){s=this||self,delete e.prototype._T_};this?t():(e.defineProperty(e.prototype,"_T_",{configurable:!0,get:t}),_T_)}}(Object);var g=s,v=g.window,m=g.self,y=g.console,b=g.setTimeout,x=g.clearTimeout,w=v&&v.document,k=v&&v.navigator,T=function(){var e="qunit-test-string";try{return g.sessionStorage.setItem(e,e),g.sessionStorage.removeItem(e),g.sessionStorage}catch(e){return}}(),C={warn:y?(y.warn||y.log).bind(y):function(){}},E=Object.prototype.toString,S=Object.prototype.hasOwnProperty,j=Date.now||function(){return(new Date).getTime()},N=v&&void 0!==v.performance&&"function"==typeof v.performance.mark&&"function"==typeof v.performance.measure?v.performance:void 0;var q={now:N?N.now.bind(N):j,measure:N?function(e,t,n){try{N.measure(e,t,n)}catch(e){C.warn("performance.measure could not be executed because of ",e.message)}}:function(){},mark:N?N.mark.bind(N):function(){}};function A(e,t){for(var n=e.slice(),r=0;r<n.length;r++)for(var i=0;i<t.length;i++)if(n[r]===t[i]){n.splice(r,1),r--;break}return n}function D(e,t){return-1!==t.indexOf(e)}function O(e){var t=L("array",e)?[]:{};for(var n in e)if(S.call(e,n)){var r=e[n];t[n]=r===Object(r)?O(r):r}return t}function M(e,t,n){for(var r in t)S.call(t,r)&&(void 0===t[r]?delete e[r]:n&&void 0!==e[r]||(e[r]=t[r]));return e}function I(e){if(void 0===e)return"undefined";if(null===e)return"null";var t=E.call(e).match(/^\[object\s(.*)\]$/),n=t&&t[1];switch(n){case"Number":return isNaN(e)?"nan":"number";case"String":case"Boolean":case"Array":case"Set":case"Map":case"Date":case"RegExp":case"Function":case"Symbol":return n.toLowerCase();default:return u(e)}}function L(e,t){return I(t)===e}function _(e,t){for(var n=e+""+t,r=0,i=0;i<n.length;i++)r=(r<<5)-r+n.charCodeAt(i),r|=0;var o=(4294967296+r).toString(16);return o.length<8&&(o="0000000"+o),o.slice(-8)}var P=function(){var e=[],t=Object.getPrototypeOf||function(e){return e.__proto__};function n(e,t){return"object"===u(e)&&(e=e.valueOf()),"object"===u(t)&&(t=t.valueOf()),e===t}function r(e){return"flags"in e?e.flags:e.toString().match(/[gimuy]*$/)[0]}function i(t,n){return t===n||(-1===["object","array","map","set"].indexOf(I(t))?s(t,n):(e.every((function(e){return e.a!==t||e.b!==n}))&&e.push({a:t,b:n}),!0))}var o={string:n,boolean:n,number:n,null:n,undefined:n,symbol:n,date:n,nan:function(){return!0},regexp:function(e,t){return e.source===t.source&&r(e)===r(t)},function:function(){return!1},array:function(e,t){var n=e.length;if(n!==t.length)return!1;for(var r=0;r<n;r++)if(!i(e[r],t[r]))return!1;return!0},set:function(t,n){if(t.size!==n.size)return!1;var r=!0;return t.forEach((function(t){if(r){var i=!1;n.forEach((function(n){if(!i){var r=e;a(n,t)&&(i=!0),e=r}})),i||(r=!1)}})),r},map:function(t,n){if(t.size!==n.size)return!1;var r=!0;return t.forEach((function(t,i){if(r){var o=!1;n.forEach((function(n,r){if(!o){var s=e;a([n,r],[t,i])&&(o=!0),e=s}})),o||(r=!1)}})),r},object:function(e,n){if(!1===function(e,n){var r=t(e),i=t(n);return e.constructor===n.constructor||(r&&null===r.constructor&&(r=null),i&&null===i.constructor&&(i=null),null===r&&i===Object.prototype||null===i&&r===Object.prototype)}(e,n))return!1;var r=[],o=[];for(var a in e)if(r.push(a),(e.constructor===Object||void 0===e.constructor||"function"!=typeof e[a]||"function"!=typeof n[a]||e[a].toString()!==n[a].toString())&&!i(e[a],n[a]))return!1;for(var u in n)o.push(u);return s(r.sort(),o.sort())}};function s(e,t){var n=I(e);return I(t)===n&&o[n](e,t)}function a(t,n){if(arguments.length<2)return!0;e=[{a:t,b:n}];for(var r=0;r<e.length;r++){var i=e[r];if(i.a!==i.b&&!s(i.a,i.b))return!1}return 2===arguments.length||a.apply(this,[].slice.call(arguments,1))}return function(){var t=a.apply(void 0,arguments);return e.length=0,t}}(),R={queue:[],blocking:!0,reorder:!0,altertitle:!0,collapse:!0,scrolltop:!0,maxDepth:5,requireExpects:!1,urlConfig:[],modules:[],currentModule:{name:"",tests:[],childModules:[],testsRun:0,testsIgnored:0,hooks:{before:[],beforeEach:[],afterEach:[],after:[]}},callbacks:{},storage:T},H=v&&v.QUnit&&v.QUnit.config;v&&v.QUnit&&!v.QUnit.version&&M(R,H),R.modules.push(R.currentModule);var F=function(){function e(e){return'"'+e.toString().replace(/\\/g,"\\\\").replace(/"/g,'\\"')+'"'}function t(e){return e+""}function n(e,t,n){var r=o.separator(),i=o.indent(1);return t.join&&(t=t.join(","+r+i)),t?[e,i+t,o.indent()+n].join(r):e+n}function r(e,t){if(o.maxDepth&&o.depth>o.maxDepth)return"[object Array]";this.up();for(var r=e.length,i=new Array(r);r--;)i[r]=this.parse(e[r],void 0,t);return this.down(),n("[",i,"]")}var i=/^function (\w+)/,o={parse:function(e,t,n){var r=(n=n||[]).indexOf(e);if(-1!==r)return"recursion(".concat(r-n.length,")");t=t||this.typeOf(e);var i=this.parsers[t],o=u(i);if("function"===o){n.push(e);var s=i.call(this,e,n);return n.pop(),s}return"string"===o?i:this.parsers.error},typeOf:function(e){return null===e?"null":void 0===e?"undefined":L("regexp",e)?"regexp":L("date",e)?"date":L("function",e)?"function":void 0!==e.setInterval&&void 0!==e.document&&void 0===e.nodeType?"window":9===e.nodeType?"document":e.nodeType?"node":function(e){return"[object Array]"===E.call(e)||"number"==typeof e.length&&void 0!==e.item&&(e.length?e.item(0)===e[0]:null===e.item(0)&&void 0===e[0])}(e)?"array":e.constructor===Error.prototype.constructor?"error":u(e)},separator:function(){return this.multiline?this.HTML?"<br />":"\n":this.HTML?"&#160;":" "},indent:function(e){if(!this.multiline)return"";var t=this.indentChar;return this.HTML&&(t=t.replace(/\t/g,"   ").replace(/ /g,"&#160;")),new Array(this.depth+(e||0)).join(t)},up:function(e){this.depth+=e||1},down:function(e){this.depth-=e||1},setParser:function(e,t){this.parsers[e]=t},quote:e,literal:t,join:n,depth:1,maxDepth:R.maxDepth,parsers:{window:"[Window]",document:"[Document]",error:function(e){return'Error("'+e.message+'")'},unknown:"[Unknown]",null:"null",undefined:"undefined",function:function(e){var t="function",r="name"in e?e.name:(i.exec(e)||[])[1];return r&&(t+=" "+r),n(t=[t+="(",o.parse(e,"functionArgs"),"){"].join(""),o.parse(e,"functionCode"),"}")},array:r,nodelist:r,arguments:r,object:function(e,t){var r=[];if(o.maxDepth&&o.depth>o.maxDepth)return"[object Object]";o.up();var i=[];for(var s in e)i.push(s);var a=["message","name"];for(var u in a){var l=a[u];l in e&&!D(l,i)&&i.push(l)}i.sort();for(var c=0;c<i.length;c++){var f=i[c],d=e[f];r.push(o.parse(f,"key")+": "+o.parse(d,void 0,t))}return o.down(),n("{",r,"}")},node:function(e){var t=o.HTML?"&lt;":"<",n=o.HTML?"&gt;":">",r=e.nodeName.toLowerCase(),i=t+r,s=e.attributes;if(s)for(var a=0,u=s.length;a<u;a++){var l=s[a].nodeValue;l&&"inherit"!==l&&(i+=" "+s[a].nodeName+"="+o.parse(l,"attribute"))}return i+=n,3!==e.nodeType&&4!==e.nodeType||(i+=e.nodeValue),i+t+"/"+r+n},functionArgs:function(e){var t=e.length;if(!t)return"";for(var n=new Array(t);t--;)n[t]=String.fromCharCode(97+t);return" "+n.join(", ")+" "},key:e,functionCode:"[code]",attribute:e,string:e,date:e,regexp:t,number:t,boolean:t,symbol:function(e){return e.toString()}},HTML:!1,indentChar:"  ",multiline:!0};return o}(),B=function(){function e(t,n){l(this,e),this.name=t,this.fullName=n?n.fullName.concat(t):[],this.tests=[],this.childSuites=[],n&&n.pushChildSuite(this)}return f(e,[{key:"start",value:function(e){if(e){this._startTime=q.now();var t=this.fullName.length;q.mark("qunit_suite_".concat(t,"_start"))}return{name:this.name,fullName:this.fullName.slice(),tests:this.tests.map((function(e){return e.start()})),childSuites:this.childSuites.map((function(e){return e.start()})),testCounts:{total:this.getTestCounts().total}}}},{key:"end",value:function(e){if(e){this._endTime=q.now();var t=this.fullName.length,n=this.fullName.join(" – ");q.mark("qunit_suite_".concat(t,"_end")),q.measure(0===t?"QUnit Test Run":"QUnit Test Suite: ".concat(n),"qunit_suite_".concat(t,"_start"),"qunit_suite_".concat(t,"_end"))}return{name:this.name,fullName:this.fullName.slice(),tests:this.tests.map((function(e){return e.end()})),childSuites:this.childSuites.map((function(e){return e.end()})),testCounts:this.getTestCounts(),runtime:this.getRuntime(),status:this.getStatus()}}},{key:"pushChildSuite",value:function(e){this.childSuites.push(e)}},{key:"pushTest",value:function(e){this.tests.push(e)}},{key:"getRuntime",value:function(){return this._endTime-this._startTime}},{key:"getTestCounts",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{passed:0,failed:0,skipped:0,todo:0,total:0};return e=this.tests.reduce((function(e,t){return t.valid&&(e[t.getStatus()]++,e.total++),e}),e),this.childSuites.reduce((function(e,t){return t.getTestCounts(e)}),e)}},{key:"getStatus",value:function(){var e=this.getTestCounts(),t=e.total,n=e.failed,r=e.skipped,i=e.todo;return n?"failed":r===t?"skipped":i===t?"todo":"passed"}}]),e}(),U=[];function $(e,t,n){var r=U.length?U.slice(-1)[0]:null,i=null!==r?[r.name,e].join(" > "):e,o=r?r.suiteReport:Ce,s=null!==r&&r.skip||n.skip,a=null!==r&&r.todo||n.todo,u={name:i,parentModule:r,tests:[],moduleId:_(i),testsRun:0,testsIgnored:0,childModules:[],suiteReport:new B(e,o),skip:s,todo:!s&&a,ignored:n.ignored||!1},l={};return r&&(r.childModules.push(u),M(l,r.testEnvironment)),M(l,t),u.testEnvironment=l,R.modules.push(u),u}function W(e,t,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};"function"===I(t)&&(n=t,t=void 0);var i=$(e,t,r),o=i.testEnvironment,s=i.hooks={};l(s,o,"before"),l(s,o,"beforeEach"),l(s,o,"afterEach"),l(s,o,"after");var a={before:c(i,"before"),beforeEach:c(i,"beforeEach"),afterEach:c(i,"afterEach"),after:c(i,"after")},u=R.currentModule;function l(e,t,n){var r=t[n];e[n]="function"==typeof r?[r]:[],delete t[n]}function c(e,t){return function(n){R.currentModule!==e&&C.warn("The `"+t+"` hook was called inside the wrong module. Instead, use hooks provided by the callback to the containing module.This will become an error in QUnit 3.0."),e.hooks[t].push(n)}}"function"===I(n)&&(U.push(i),R.currentModule=i,n.call(i.testEnvironment,a),U.pop(),i=i.parentModule||u),R.currentModule=i}var Q=!1;function z(e,t,n){var r;W(e,t,n,{ignored:Q&&(r=R.modules.map((function(e){return e.moduleId})),!U.some((function(e){return r.includes(e.moduleId)})))})}z.only=function(){Q||(R.modules.length=0,R.queue.length=0),W.apply(void 0,arguments),Q=!0},z.skip=function(e,t,n){Q||W(e,t,n,{skip:!0})},z.todo=function(e,t,n){Q||W(e,t,n,{todo:!0})};var X=Object.create(null),V=["runStart","suiteStart","testStart","assertion","testEnd","suiteEnd","runEnd"];function G(e,t){if("string"!==I(e))throw new TypeError("eventName must be a string when emitting an event");for(var n=X[e],r=n?d(n):[],i=0;i<r.length;i++)r[i](t)}var J="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:void 0!==e?e:"undefined"!=typeof self?self:{};function Y(e){var t={exports:{}};return e(t,t.exports),t.exports}var K=Y((function(e){!function(){var t=function(){if("undefined"!=typeof globalThis)return globalThis;if("undefined"!=typeof self)return self;if("undefined"!=typeof window)return window;if(void 0!==J)return J;throw new Error("unable to locate global object")}();if("function"!=typeof t.Promise){var n=setTimeout;s.prototype.catch=function(e){return this.then(null,e)},s.prototype.then=function(e,t){var n=new this.constructor(o);return a(this,new d(e,t,n)),n},s.prototype.finally=function(e){var t=this.constructor;return this.then((function(n){return t.resolve(e()).then((function(){return n}))}),(function(n){return t.resolve(e()).then((function(){return t.reject(n)}))}))},s.all=function(e){return new s((function(t,n){if(!i(e))return n(new TypeError("Promise.all accepts an array"));var r=Array.prototype.slice.call(e);if(0===r.length)return t([]);var o=r.length;function s(e,i){try{if(i&&("object"===u(i)||"function"==typeof i)){var a=i.then;if("function"==typeof a)return void a.call(i,(function(t){s(e,t)}),n)}r[e]=i,0==--o&&t(r)}catch(e){n(e)}}for(var a=0;a<r.length;a++)s(a,r[a])}))},s.allSettled=function(e){return new this((function(t,n){if(!e||void 0===e.length)return n(new TypeError(u(e)+" "+e+" is not iterable(cannot read property Symbol(Symbol.iterator))"));var r=Array.prototype.slice.call(e);if(0===r.length)return t([]);var i=r.length;function o(e,n){if(n&&("object"===u(n)||"function"==typeof n)){var s=n.then;if("function"==typeof s)return void s.call(n,(function(t){o(e,t)}),(function(n){r[e]={status:"rejected",reason:n},0==--i&&t(r)}))}r[e]={status:"fulfilled",value:n},0==--i&&t(r)}for(var s=0;s<r.length;s++)o(s,r[s])}))},s.resolve=function(e){return e&&"object"===u(e)&&e.constructor===s?e:new s((function(t){t(e)}))},s.reject=function(e){return new s((function(t,n){n(e)}))},s.race=function(e){return new s((function(t,n){if(!i(e))return n(new TypeError("Promise.race accepts an array"));for(var r=0,o=e.length;r<o;r++)s.resolve(e[r]).then(t,n)}))},s._immediateFn="function"==typeof r&&function(e){r(e)}||function(e){n(e,0)},s._unhandledRejectionFn=function(e){"undefined"!=typeof console&&console&&console.warn("Possible Unhandled Promise Rejection:",e)},e.exports=s}else e.exports=t.Promise;function i(e){return Boolean(e&&void 0!==e.length)}function o(){}function s(e){if(!(this instanceof s))throw new TypeError("Promises must be constructed via new");if("function"!=typeof e)throw new TypeError("not a function");this._state=0,this._handled=!1,this._value=void 0,this._deferreds=[],p(e,this)}function a(e,t){for(;3===e._state;)e=e._value;0!==e._state?(e._handled=!0,s._immediateFn((function(){var n=1===e._state?t.onFulfilled:t.onRejected;if(null!==n){var r;try{r=n(e._value)}catch(e){return void c(t.promise,e)}l(t.promise,r)}else(1===e._state?l:c)(t.promise,e._value)}))):e._deferreds.push(t)}function l(e,t){try{if(t===e)throw new TypeError("A promise cannot be resolved with itself.");if(t&&("object"===u(t)||"function"==typeof t)){var n=t.then;if(t instanceof s)return e._state=3,e._value=t,void f(e);if("function"==typeof n)return void p((r=n,i=t,function(){r.apply(i,arguments)}),e)}e._state=1,e._value=t,f(e)}catch(t){c(e,t)}var r,i}function c(e,t){e._state=2,e._value=t,f(e)}function f(e){2===e._state&&0===e._deferreds.length&&s._immediateFn((function(){e._handled||s._unhandledRejectionFn(e._value)}));for(var t=0,n=e._deferreds.length;t<n;t++)a(e,e._deferreds[t]);e._deferreds=null}function d(e,t,n){this.onFulfilled="function"==typeof e?e:null,this.onRejected="function"==typeof t?t:null,this.promise=n}function p(e,t){var n=!1;try{e((function(e){n||(n=!0,l(t,e))}),(function(e){n||(n=!0,c(t,e))}))}catch(e){if(n)return;n=!0,c(t,e)}}}()}));function Z(e,t){var n=R.callbacks[e];if("log"!==e)return n.reduce((function(e,n){return e.then((function(){return K.resolve(n(t))}))}),K.resolve([]));n.map((function(e){return e(t)}))}var ee=(ne(0)||"").replace(/(:\d+)+\)?/,"").replace(/.+\//,"");function te(e,t){if(t=void 0===t?4:t,e&&e.stack){var n=e.stack.split("\n");if(/^error$/i.test(n[0])&&n.shift(),ee){for(var r=[],i=t;i<n.length&&-1===n[i].indexOf(ee);i++)r.push(n[i]);if(r.length)return r.join("\n")}return n[t]}}function ne(e){var t=new Error;if(!t.stack)try{throw t}catch(e){t=e}return te(t,e)}var re,ie=0,oe=[];function se(){var e;e=j(),R.depth=(R.depth||0)+1,ae(e),R.depth--,oe.length||R.blocking||R.current||function(){if(!R.blocking&&!R.queue.length&&0===R.depth)return void function(){var e=R.storage;ue.finished=!0;var t=j()-R.started,n=R.stats.all-R.stats.bad;if(0===R.stats.testCount){if(R.filter&&R.filter.length)throw new Error('No tests matched the filter "'.concat(R.filter,'".'));if(R.module&&R.module.length)throw new Error('No tests matched the module "'.concat(R.module,'".'));if(R.moduleId&&R.moduleId.length)throw new Error('No tests matched the moduleId "'.concat(R.moduleId,'".'));if(R.testId&&R.testId.length)throw new Error('No tests matched the testId "'.concat(R.testId,'".'));throw new Error("No tests were run.")}G("runEnd",Ce.end(!0)),Z("done",{passed:n,failed:R.stats.bad,total:R.stats.all,runtime:t}).then((function(){if(e&&0===R.stats.bad)for(var t=e.length-1;t>=0;t--){var n=e.key(t);0===n.indexOf("qunit-test-")&&e.removeItem(n)}}))}();e=R.queue.shift()(),void oe.push.apply(oe,d(e)),ie>0&&ie--;var e;se()}()}function ae(e){if(oe.length&&!R.blocking){var t=j()-e;if(!b||R.updateRate<=0||t<R.updateRate){var n=oe.shift();K.resolve(n()).then((function(){oe.length?ae(e):se()}))}else b(se)}}var ue={finished:!1,add:function(e,t,n){if(t)R.queue.splice(ie++,0,e);else if(n){re||(re=function(e){var t=parseInt(_(e),16)||-1;return function(){return t^=t<<13,t^=t>>>17,(t^=t<<5)<0&&(t+=4294967296),t/4294967296}}(n));var r=Math.floor(re()*(R.queue.length-ie+1));R.queue.splice(ie+r,0,e)}else R.queue.push(e)},advance:se,taskCount:function(){return oe.length}},le=function(){function e(t,n,r){l(this,e),this.name=t,this.suiteName=n.name,this.fullName=n.fullName.concat(t),this.runtime=0,this.assertions=[],this.skipped=!!r.skip,this.todo=!!r.todo,this.valid=r.valid,this._startTime=0,this._endTime=0,n.pushTest(this)}return f(e,[{key:"start",value:function(e){return e&&(this._startTime=q.now(),q.mark("qunit_test_start")),{name:this.name,suiteName:this.suiteName,fullName:this.fullName.slice()}}},{key:"end",value:function(e){if(e&&(this._endTime=q.now(),q)){q.mark("qunit_test_end");var t=this.fullName.join(" – ");q.measure("QUnit Test: ".concat(t),"qunit_test_start","qunit_test_end")}return M(this.start(),{runtime:this.getRuntime(),status:this.getStatus(),errors:this.getFailedAssertions(),assertions:this.getAssertions()})}},{key:"pushAssertion",value:function(e){this.assertions.push(e)}},{key:"getRuntime",value:function(){return this._endTime-this._startTime}},{key:"getStatus",value:function(){return this.skipped?"skipped":(this.getFailedAssertions().length>0?this.todo:!this.todo)?this.todo?"todo":"passed":"failed"}},{key:"getFailedAssertions",value:function(){return this.assertions.filter((function(e){return!e.passed}))}},{key:"getAssertions",value:function(){return this.assertions.slice()}},{key:"slimAssertions",value:function(){this.assertions=this.assertions.map((function(e){return delete e.actual,delete e.expected,e}))}}]),e}();function ce(e){if(this.expected=null,this.assertions=[],this.semaphore=0,this.module=R.currentModule,this.steps=[],this.timeout=void 0,M(this,e),this.module.skip?(this.skip=!0,this.todo=!1):this.module.todo&&!this.skip&&(this.todo=!0),!this.skip&&"function"!=typeof this.callback){var t=this.todo?"QUnit.todo":"QUnit.test";throw new TypeError("You must provide a callback to ".concat(t,'("').concat(this.testName,'")'))}++ce.count,this.errorForStack=new Error,this.testReport=new le(this.testName,this.module.suiteReport,{todo:this.todo,skip:this.skip,valid:this.valid()});for(var n=0,r=this.module.tests;n<r.length;n++)this.module.tests[n].name===this.testName&&(this.testName+=" ");this.testId=_(this.module.name,this.testName),this.module.tests.push({name:this.testName,testId:this.testId,skip:!!this.skip}),this.skip?(this.callback=function(){},this.async=!1,this.expected=0):this.assert=new we(this)}function fe(){if(!R.current)throw new Error("pushFailure() assertion outside test context, in "+ne(2));var e=R.current;return e.pushFailure.apply(e,arguments)}function de(){if(R.pollution=[],R.noglobals)for(var e in g)if(S.call(g,e)){if(/^qunit-test-output/.test(e))continue;R.pollution.push(e)}}ce.count=0,ce.prototype={get stack(){return te(this.errorForStack,2)},before:function(){var e=this,t=this.module;return function(e){for(var t=e,n=[];t&&0===t.testsRun;)n.push(t),t=t.parentModule;return n.reverse()}(t).reduce((function(e,t){return e.then((function(){return t.stats={all:0,bad:0,started:j()},G("suiteStart",t.suiteReport.start(!0)),Z("moduleStart",{name:t.name,tests:t.tests})}))}),K.resolve([])).then((function(){return R.current=e,e.testEnvironment=M({},t.testEnvironment),e.started=j(),G("testStart",e.testReport.start(!0)),Z("testStart",{name:e.testName,module:t.name,testId:e.testId,previousFailure:e.previousFailure}).then((function(){R.pollution||de()}))}))},run:function(){if(R.current=this,this.callbackStarted=j(),R.notrycatch)e(this);else try{e(this)}catch(e){this.pushFailure("Died on test #"+(this.assertions.length+1)+" "+this.stack+": "+(e.message||e),te(e,0)),de(),R.blocking&&ve(this)}function e(e){var t=e.callback.call(e.testEnvironment,e.assert);e.resolvePromise(t),0===e.timeout&&0!==e.semaphore&&fe("Test did not finish synchronously even though assert.timeout( 0 ) was used.",ne(2))}},after:function(){!function(){var e=R.pollution;de();var t=A(R.pollution,e);t.length>0&&fe("Introduced global variable(s): "+t.join(", "));var n=A(e,R.pollution);n.length>0&&fe("Deleted global variable(s): "+n.join(", "))}()},queueHook:function(e,t,n){var r=this,i=function(){var n=e.call(r.testEnvironment,r.assert);r.resolvePromise(n,t)};return function(){if("before"===t){if(0!==n.testsRun)return;r.preserveEnvironment=!0}if("after"!==t||function(e){return e.testsRun===ye(e).filter((function(e){return!e.skip})).length-1}(n)||!(R.queue.length>0||ue.taskCount()>2))if(R.current=r,R.notrycatch)i();else try{i()}catch(e){r.pushFailure(t+" failed on "+r.testName+": "+(e.message||e),te(e,0))}}},hooks:function(e){var t=[];return this.skip||function n(r,i){if(i.parentModule&&n(r,i.parentModule),i.hooks[e].length)for(var o=0;o<i.hooks[e].length;o++)t.push(r.queueHook(i.hooks[e][o],e,i))}(this,this.module),t},finish:function(){if(R.current=this,this.callback=void 0,this.steps.length){var e=this.steps.join(", ");this.pushFailure("Expected assert.verifySteps() to be called before end of test "+"after using assert.step(). Unverified steps: ".concat(e),this.stack)}R.requireExpects&&null===this.expected?this.pushFailure("Expected number of assertions to be defined, but expect() was not called.",this.stack):null!==this.expected&&this.expected!==this.assertions.length?this.pushFailure("Expected "+this.expected+" assertions, but "+this.assertions.length+" were run",this.stack):null!==this.expected||this.assertions.length||this.pushFailure("Expected at least one assertion, but none were run - call expect(0) to accept zero assertions.",this.stack);var t=this.module,n=t.name,r=this.testName,i=!!this.skip,o=!!this.todo,s=0,a=R.storage;this.runtime=j()-this.started,R.stats.all+=this.assertions.length,R.stats.testCount+=1,t.stats.all+=this.assertions.length;for(var u=0;u<this.assertions.length;u++)this.assertions[u].result||(s++,R.stats.bad++,t.stats.bad++);i?xe(t):function(e){e.testsRun++;for(;e=e.parentModule;)e.testsRun++}(t),a&&(s?a.setItem("qunit-test-"+n+"-"+r,s):a.removeItem("qunit-test-"+n+"-"+r)),G("testEnd",this.testReport.end(!0)),this.testReport.slimAssertions();var l=this;return Z("testDone",{name:r,module:n,skipped:i,todo:o,failed:s,passed:this.assertions.length-s,total:this.assertions.length,runtime:i?0:this.runtime,assertions:this.assertions,testId:this.testId,get source(){return l.stack}}).then((function(){if(be(t)){for(var e=[t],n=t.parentModule;n&&be(n);)e.push(n),n=n.parentModule;return e.reduce((function(e,t){return e.then((function(){return function(e){return e.hooks={},G("suiteEnd",e.suiteReport.end(!0)),Z("moduleDone",{name:e.name,tests:e.tests,failed:e.stats.bad,passed:e.stats.all-e.stats.bad,total:e.stats.all,runtime:j()-e.stats.started})}(t)}))}),K.resolve([]))}})).then((function(){R.current=void 0}))},preserveTestEnvironment:function(){this.preserveEnvironment&&(this.module.testEnvironment=this.testEnvironment,this.testEnvironment=M({},this.module.testEnvironment))},queue:function(){var e=this;if(this.valid()){var t=R.storage&&+R.storage.getItem("qunit-test-"+this.module.name+"-"+this.testName),n=R.reorder&&!!t;this.previousFailure=!!t,ue.add((function(){return[function(){return e.before()}].concat(d(e.hooks("before")),[function(){e.preserveTestEnvironment()}],d(e.hooks("beforeEach")),[function(){e.run()}],d(e.hooks("afterEach").reverse()),d(e.hooks("after").reverse()),[function(){e.after()},function(){return e.finish()}])}),n,R.seed),ue.finished&&ue.advance()}else xe(this.module)},pushResult:function(e){if(this!==R.current){var t=e&&e.message||"",n=this&&this.testName||"";throw new Error("Assertion occurred after test finished.\n> Test: "+n+"\n> Message: "+t+"\n")}var r={module:this.module.name,name:this.testName,result:e.result,message:e.message,actual:e.actual,testId:this.testId,negative:e.negative||!1,runtime:j()-this.started,todo:!!this.todo};if(S.call(e,"expected")&&(r.expected=e.expected),!e.result){var i=e.source||ne();i&&(r.source=i)}this.logAssertion(r),this.assertions.push({result:!!e.result,message:e.message})},pushFailure:function(e,t,n){if(!(this instanceof ce))throw new Error("pushFailure() assertion outside test context, was "+ne(2));this.pushResult({result:!1,message:e||"error",actual:n||null,source:t})},logAssertion:function(e){Z("log",e);var t={passed:e.result,actual:e.actual,expected:e.expected,message:e.message,stack:e.source,todo:e.todo};this.testReport.pushAssertion(t),G("assertion",t)},resolvePromise:function(e,t){if(null!=e){var n=this,r=e.then;if("function"===I(r)){var i=ge(n);R.notrycatch?r.call(e,(function(){i()})):r.call(e,(function(){i()}),(function(e){var r="Promise rejected "+(t?t.replace(/Each$/,""):"during")+' "'+n.testName+'": '+(e&&e.message||e);n.pushFailure(r,te(e,0)),de(),ve(n)}))}}},valid:function(){var e=R.filter,t=/^(!?)\/([\w\W]*)\/(i?$)/.exec(e),n=R.module&&R.module.toLowerCase(),r=this.module.name+": "+this.testName;return!(!this.callback||!this.callback.validTest)||!(R.moduleId&&R.moduleId.length>0&&!function e(t){return D(t.moduleId,R.moduleId)||t.parentModule&&e(t.parentModule)}(this.module))&&(!(R.testId&&R.testId.length>0&&!D(this.testId,R.testId))&&(!(n&&!function e(t){return(t.name?t.name.toLowerCase():null)===n||!!t.parentModule&&e(t.parentModule)}(this.module))&&(!e||(t?this.regexFilter(!!t[1],t[2],t[3],r):this.stringFilter(e,r)))))},regexFilter:function(e,t,n,r){return new RegExp(t,n).test(r)!==e},stringFilter:function(e,t){e=e.toLowerCase(),t=t.toLowerCase();var n="!"!==e.charAt(0);return n||(e=e.slice(1)),-1!==t.indexOf(e)?n:!n}};var pe=!1;function he(e,t){pe||R.currentModule.ignored||new ce({testName:e,callback:t}).queue()}function ge(e){var t,n=!1;(e.semaphore+=1,R.blocking=!0,b)&&("number"==typeof e.timeout?t=e.timeout:"number"==typeof R.testTimeout&&(t=R.testTimeout),"number"==typeof t&&t>0&&(R.timeoutHandler=function(t){return function(){R.timeout=null,fe("Test took longer than ".concat(t,"ms; test timed out."),ne(2)),n=!0,ve(e)}},x(R.timeout),R.timeout=b(R.timeoutHandler(t),t)));return function(){n||(n=!0,e.semaphore-=1,me(e))}}function ve(e){e.semaphore=0,me(e)}function me(e){return isNaN(e.semaphore)?(e.semaphore=0,void fe("Invalid value on test.semaphore",ne(2))):e.semaphore>0?void 0:e.semaphore<0?(e.semaphore=0,void fe("Tried to restart test while already started (test's semaphore was 0 already)",ne(2))):void(b?(x(R.timeout),R.timeout=b((function(){e.semaphore>0||(x(R.timeout),R.timeout=null,qe())}))):qe())}function ye(e){for(var t=[].concat(e.tests),n=d(e.childModules);n.length;){var r=n.shift();t.push.apply(t,r.tests),n.push.apply(n,d(r.childModules))}return t}function be(e){return e.testsRun+e.testsIgnored===ye(e).length}function xe(e){for(e.testsIgnored++;e=e.parentModule;)e.testsIgnored++}M(he,{todo:function(e,t){pe||R.currentModule.ignored||new ce({testName:e,callback:t,todo:!0}).queue()},skip:function(e){pe||R.currentModule.ignored||new ce({testName:e,skip:!0}).queue()},only:function(e,t){R.currentModule.ignored||(pe||(R.queue.length=0,pe=!0),new ce({testName:e,callback:t}).queue())}});var we=function(){function e(t){l(this,e),this.test=t}return f(e,[{key:"timeout",value:function(e){if("number"!=typeof e)throw new Error("You must pass a number as the duration to assert.timeout");var t;this.test.timeout=e,R.timeout&&(x(R.timeout),R.timeout=null,R.timeoutHandler&&this.test.timeout>0&&(t=this.test.timeout,x(R.timeout),R.timeout=b(R.timeoutHandler(t),t)))}},{key:"step",value:function(e){var t=e,n=!!e;this.test.steps.push(e),"undefined"===I(e)||""===e?t="You must provide a message to assert.step":"string"!==I(e)&&(t="You must provide a string value to assert.step",n=!1),this.pushResult({result:n,message:t})}},{key:"verifySteps",value:function(e,t){var n=this.test.steps.slice();this.deepEqual(n,e,t),this.test.steps.length=0}},{key:"expect",value:function(e){if(1!==arguments.length)return this.test.expected;this.test.expected=e}},{key:"async",value:function(e){var t=this.test,n=!1,r=e;void 0===r&&(r=1);var i=ge(t);return function(){if(R.current!==t)throw Error("assert.async callback called after test finished.");n?t.pushFailure("Too many calls to the `assert.async` callback",ne(2)):(r-=1)>0||(n=!0,i())}}},{key:"push",value:function(t,n,r,i,o){return C.warn("assert.push is deprecated and will be removed in QUnit 3.0. Please use assert.pushResult instead (https://api.qunitjs.com/assert/pushResult)."),(this instanceof e?this:R.current.assert).pushResult({result:t,actual:n,expected:r,message:i,negative:o})}},{key:"pushResult",value:function(t){var n=this,r=n instanceof e&&n.test||R.current;if(!r)throw new Error("assertion outside test context, in "+ne(2));return n instanceof e||(n=r.assert),n.test.pushResult(t)}},{key:"ok",value:function(e,t){t||(t=e?"okay":"failed, expected argument to be truthy, was: ".concat(F.parse(e))),this.pushResult({result:!!e,actual:e,expected:!0,message:t})}},{key:"notOk",value:function(e,t){t||(t=e?"failed, expected argument to be falsy, was: ".concat(F.parse(e)):"okay"),this.pushResult({result:!e,actual:e,expected:!1,message:t})}},{key:"true",value:function(e,t){this.pushResult({result:!0===e,actual:e,expected:!0,message:t})}},{key:"false",value:function(e,t){this.pushResult({result:!1===e,actual:e,expected:!1,message:t})}},{key:"equal",value:function(e,t,n){var r=t==e;this.pushResult({result:r,actual:e,expected:t,message:n})}},{key:"notEqual",value:function(e,t,n){var r=t!=e;this.pushResult({result:r,actual:e,expected:t,message:n,negative:!0})}},{key:"propEqual",value:function(e,t,n){e=O(e),t=O(t),this.pushResult({result:P(e,t),actual:e,expected:t,message:n})}},{key:"notPropEqual",value:function(e,t,n){e=O(e),t=O(t),this.pushResult({result:!P(e,t),actual:e,expected:t,message:n,negative:!0})}},{key:"deepEqual",value:function(e,t,n){this.pushResult({result:P(e,t),actual:e,expected:t,message:n})}},{key:"notDeepEqual",value:function(e,t,n){this.pushResult({result:!P(e,t),actual:e,expected:t,message:n,negative:!0})}},{key:"strictEqual",value:function(e,t,n){this.pushResult({result:t===e,actual:e,expected:t,message:n})}},{key:"notStrictEqual",value:function(e,t,n){this.pushResult({result:t!==e,actual:e,expected:t,message:n,negative:!0})}},{key:"throws",value:function(t,n,r){var i,o=!1,s=this instanceof e&&this.test||R.current;if("string"===I(n)){if(null!=r)throw new Error("throws/raises does not accept a string value for the expected argument.\nUse a non-string object value (e.g. regExp) instead if it's necessary.");r=n,n=null}s.ignoreGlobalErrors=!0;try{t.call(s.testEnvironment)}catch(e){i=e}if(s.ignoreGlobalErrors=!1,i){var a=I(n);if(n){if("regexp"===a)o=n.test(ke(i)),n=String(n);else if("function"===a&&void 0!==n.prototype&&i instanceof n)o=!0;else if("object"===a)o=i instanceof n.constructor&&i.name===n.name&&i.message===n.message,n=ke(n);else if("function"===a)try{o=!0===n.call({},i),n=null}catch(e){n=ke(e)}}else o=!0}s.assert.pushResult({result:o,actual:i&&ke(i),expected:n,message:r})}},{key:"rejects",value:function(t,n,r){var i=!1,o=this instanceof e&&this.test||R.current;if("string"===I(n)){if(void 0!==r)return r="assert.rejects does not accept a string value for the expected argument.\nUse a non-string object value (e.g. validator function) instead if necessary.",void o.assert.pushResult({result:!1,message:r});r=n,n=void 0}var s=t&&t.then;if("function"===I(s)){var a=this.async();return s.call(t,(function(){var e='The promise returned by the `assert.rejects` callback in "'+o.testName+'" did not reject.';o.assert.pushResult({result:!1,message:e,actual:t}),a()}),(function(e){var t=I(n);void 0===n?i=!0:"regexp"===t?(i=n.test(ke(e)),n=String(n)):"function"===t&&e instanceof n?i=!0:"object"===t?(i=e instanceof n.constructor&&e.name===n.name&&e.message===n.message,n=ke(n)):"function"===t?(i=!0===n.call({},e),n=null):(i=!1,r='invalid expected value provided to `assert.rejects` callback in "'+o.testName+'": '+t+"."),o.assert.pushResult({result:i,actual:e&&ke(e),expected:n,message:r}),a()}))}var u='The value provided to `assert.rejects` in "'+o.testName+'" was not a promise.';o.assert.pushResult({result:!1,message:u,actual:t})}}]),e}();function ke(e){var t=e.toString();if("[object"===t.slice(0,7)){var n=e.name?String(e.name):"Error";return e.message?"".concat(n,": ").concat(e.message):n}return t}we.prototype.raises=we.prototype.throws;var Te={},Ce=new B;R.currentModule.suiteReport=Ce;var Ee=!1,Se=!1;function je(){Se=!0,b?b((function(){qe()})):qe()}function Ne(){R.blocking=!1,ue.advance()}function qe(){if(R.started)Ne();else{R.started=j(),""===R.modules[0].name&&0===R.modules[0].tests.length&&R.modules.shift();for(var e=R.modules.length,t=[],n=0;n<e;n++)t.push({name:R.modules[n].name,tests:R.modules[n].tests});G("runStart",Ce.start(!0)),Z("begin",{totalTests:ce.count,modules:t}).then(Ne)}}Te.isLocal=v&&v.location&&"file:"===v.location.protocol,Te.version="2.15.0",M(Te,{config:R,dump:F,equiv:P,is:L,objectType:I,on:function(e,t){if("string"!==I(e))throw new TypeError("eventName must be a string when registering a listener");if(!D(e,V)){var n=V.join(", ");throw new Error('"'.concat(e,'" is not a valid event; must be one of: ').concat(n,"."))}if("function"!==I(t))throw new TypeError("callback must be a function when registering a listener");X[e]||(X[e]=[]),D(t,X[e])||X[e].push(t)},onError:function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];if(R.current){if(R.current.ignoreGlobalErrors)return!0;fe.apply(void 0,[e.message,e.stacktrace||e.fileName+":"+e.lineNumber].concat(n))}else he("global failure",M((function(){fe.apply(void 0,[e.message,e.stacktrace||e.fileName+":"+e.lineNumber].concat(n))}),{validTest:!0}));return!1},onUnhandledRejection:function(e){var t={result:!1,message:e.message||"error",actual:e,source:e.stack||ne(3)},n=R.current;n?n.assert.pushResult(t):he("global failure",M((function(e){e.pushResult(t)}),{validTest:!0}))},pushFailure:fe,assert:we.prototype,module:z,test:he,todo:he.todo,skip:he.skip,only:he.only,start:function(e){if(R.current)throw new Error("QUnit.start cannot be called inside a test context.");var t=Ee;if(Ee=!0,Se)throw new Error("Called start() while test already started running");if(t||e>1)throw new Error("Called start() outside of a test context too many times");if(R.autostart)throw new Error("Called start() outside of a test context when QUnit.config.autostart was true");if(!R.pageLoaded)return R.autostart=!0,void(w||Te.load());je()},extend:function(){C.warn("QUnit.extend is deprecated and will be removed in QUnit 3.0. Please use Object.assign instead.");for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return M.apply(this,t)},load:function(){R.pageLoaded=!0,M(R,{stats:{all:0,bad:0,testCount:0},started:0,updateRate:1e3,autostart:!0,filter:""},!0),Se||(R.blocking=!1,R.autostart&&je())},stack:function(e){return ne(e=(e||0)+2)}}),function(e){var t=["begin","done","log","testStart","testDone","moduleStart","moduleDone"];function n(e){return function(t){if("function"!==I(t))throw new Error("QUnit logging methods require a callback function as their first parameters.");R.callbacks[e].push(t)}}for(var r=0,i=t.length;r<i;r++){var o=t[r];"undefined"===I(R.callbacks[o])&&(R.callbacks[o]=[]),e[o]=n(o)}}(Te),function(e){var r=!1;if(v&&w){if(v.QUnit&&v.QUnit.version)throw new Error("QUnit has already been defined.");v.QUnit=e,r=!0}i&&i.exports&&(i.exports=e,i.exports.QUnit=e,r=!0),t&&(t.QUnit=e,r=!0),void 0===(o=function(){return e}.call(t,n,t,i))||(i.exports=o),e.config.autostart=!1,r=!0,m&&m.WorkerGlobalScope&&m instanceof m.WorkerGlobalScope&&(m.QUnit=e,r=!0),r||(g.QUnit=e)}(Te),function(){if(v&&w){var e=Te.config,t=Object.prototype.hasOwnProperty;Te.begin((function(){if(!t.call(e,"fixture")){var n=w.getElementById("qunit-fixture");n&&(e.fixture=n.cloneNode(!0))}})),Te.testStart((function(){if(null!=e.fixture){var t=w.getElementById("qunit-fixture");if("string"===u(e.fixture)){var n=w.createElement("div");n.setAttribute("id","qunit-fixture"),n.innerHTML=e.fixture,t.parentNode.replaceChild(n,t)}else{var r=e.fixture.cloneNode(!0);t.parentNode.replaceChild(r,t)}}}))}}(),function(){var e=void 0!==v&&v.location;if(e){var t=function(){var t,r,i,o,s=Object.create(null),a=e.search.slice(1).split("&"),u=a.length;for(t=0;t<u;t++)a[t]&&(r=a[t].split("="),i=n(r[0]),o=1===r.length||n(r.slice(1).join("=")),s[i]=i in s?[].concat(s[i],o):o);return s}();Te.urlParams=t,Te.config.moduleId=[].concat(t.moduleId||[]),Te.config.testId=[].concat(t.testId||[]),Te.config.module=t.module,Te.config.filter=t.filter,!0===t.seed?Te.config.seed=Math.random().toString(36).slice(2):t.seed&&(Te.config.seed=t.seed),Te.config.urlConfig.push({id:"hidepassed",label:"Hide passed tests",tooltip:"Only show tests and assertions that fail. Stored as query-strings."},{id:"noglobals",label:"Check for Globals",tooltip:"Enabling this will test if any test introduces new properties on the global object (`window` in Browsers). Stored as query-strings."},{id:"notrycatch",label:"No try-catch",tooltip:"Enabling this will run tests outside of a try-catch block. Makes debugging exceptions in IE reasonable. Stored as query-strings."}),Te.begin((function(){var e,n,r=Te.config.urlConfig;for(e=0;e<r.length;e++)"string"!=typeof(n=Te.config.urlConfig[e])&&(n=n.id),void 0===Te.config[n]&&(Te.config[n]=t[n])}))}function n(e){return decodeURIComponent(e.replace(/\+/g,"%20"))}}();var Ae=Y((function(e){var t,n;t=J,n=function(){var e="undefined"==typeof window,t=new a,n=new a,i=[];i.total=0;var o=[],s=[];function u(){t.clear(),n.clear(),o=[],s=[]}function l(e){for(var t=-9007199254740991,n=e.length-1;n>=0;--n){var r=e[n];if(null!==r){var i=r.score;i>t&&(t=i)}}return-9007199254740991===t?null:t}function c(e,t){var n=e[t];if(void 0!==n)return n;var r=t;Array.isArray(t)||(r=t.split("."));for(var i=r.length,o=-1;e&&++o<i;)e=e[r[o]];return e}function f(e){return"object"==typeof e}var d=function(){var e=[],t=0,n={};function r(){for(var n=0,r=e[n],i=1;i<t;){var o=i+1;n=i,o<t&&e[o].score<e[i].score&&(n=o),e[n-1>>1]=e[n],i=1+(n<<1)}for(var s=n-1>>1;n>0&&r.score<e[s].score;s=(n=s)-1>>1)e[n]=e[s];e[n]=r}return n.add=function(n){var r=t;e[t++]=n;for(var i=r-1>>1;r>0&&n.score<e[i].score;i=(r=i)-1>>1)e[r]=e[i];e[r]=n},n.poll=function(){if(0!==t){var n=e[0];return e[0]=e[--t],r(),n}},n.peek=function(n){if(0!==t)return e[0]},n.replaceTop=function(t){e[0]=t,r()},n},p=d();return function a(h){var g={single:function(e,t,n){return e?(f(e)||(e=g.getPreparedSearch(e)),t?(f(t)||(t=g.getPrepared(t)),((n&&void 0!==n.allowTypo?n.allowTypo:!h||void 0===h.allowTypo||h.allowTypo)?g.algorithm:g.algorithmNoTypo)(e,t,e[0])):null):null},go:function(e,t,n){if(!e)return i;var r=(e=g.prepareSearch(e))[0],o=n&&n.threshold||h&&h.threshold||-9007199254740991,s=n&&n.limit||h&&h.limit||9007199254740991,a=(n&&void 0!==n.allowTypo?n.allowTypo:!h||void 0===h.allowTypo||h.allowTypo)?g.algorithm:g.algorithmNoTypo,u=0,d=0,v=t.length;if(n&&n.keys)for(var m=n.scoreFn||l,y=n.keys,b=y.length,x=v-1;x>=0;--x){for(var w=t[x],k=new Array(b),T=b-1;T>=0;--T)(S=c(w,E=y[T]))?(f(S)||(S=g.getPrepared(S)),k[T]=a(e,S,r)):k[T]=null;k.obj=w;var C=m(k);null!==C&&(C<o||(k.score=C,u<s?(p.add(k),++u):(++d,C>p.peek().score&&p.replaceTop(k))))}else if(n&&n.key){var E=n.key;for(x=v-1;x>=0;--x)(S=c(w=t[x],E))&&(f(S)||(S=g.getPrepared(S)),null!==(j=a(e,S,r))&&(j.score<o||(j={target:j.target,_targetLowerCodes:null,_nextBeginningIndexes:null,score:j.score,indexes:j.indexes,obj:w},u<s?(p.add(j),++u):(++d,j.score>p.peek().score&&p.replaceTop(j)))))}else for(x=v-1;x>=0;--x){var S,j;(S=t[x])&&(f(S)||(S=g.getPrepared(S)),null!==(j=a(e,S,r))&&(j.score<o||(u<s?(p.add(j),++u):(++d,j.score>p.peek().score&&p.replaceTop(j)))))}if(0===u)return i;var N=new Array(u);for(x=u-1;x>=0;--x)N[x]=p.poll();return N.total=u+d,N},goAsync:function(t,n,o){var s=!1,a=new Promise((function(a,u){if(!t)return a(i);var p=(t=g.prepareSearch(t))[0],v=d(),m=n.length-1,y=o&&o.threshold||h&&h.threshold||-9007199254740991,b=o&&o.limit||h&&h.limit||9007199254740991,x=(o&&void 0!==o.allowTypo?o.allowTypo:!h||void 0===h.allowTypo||h.allowTypo)?g.algorithm:g.algorithmNoTypo,w=0,k=0;function T(){if(s)return u("canceled");var d=Date.now();if(o&&o.keys)for(var h=o.scoreFn||l,C=o.keys,E=C.length;m>=0;--m){for(var S=n[m],j=new Array(E),N=E-1;N>=0;--N)(D=c(S,A=C[N]))?(f(D)||(D=g.getPrepared(D)),j[N]=x(t,D,p)):j[N]=null;j.obj=S;var q=h(j);if(null!==q&&!(q<y)&&(j.score=q,w<b?(v.add(j),++w):(++k,q>v.peek().score&&v.replaceTop(j)),m%1e3==0&&Date.now()-d>=10))return void(e?r(T):setTimeout(T))}else if(o&&o.key){for(var A=o.key;m>=0;--m)if((D=c(S=n[m],A))&&(f(D)||(D=g.getPrepared(D)),null!==(O=x(t,D,p))&&!(O.score<y)&&(O={target:O.target,_targetLowerCodes:null,_nextBeginningIndexes:null,score:O.score,indexes:O.indexes,obj:S},w<b?(v.add(O),++w):(++k,O.score>v.peek().score&&v.replaceTop(O)),m%1e3==0&&Date.now()-d>=10)))return void(e?r(T):setTimeout(T))}else for(;m>=0;--m){var D,O;if((D=n[m])&&(f(D)||(D=g.getPrepared(D)),null!==(O=x(t,D,p))&&!(O.score<y)&&(w<b?(v.add(O),++w):(++k,O.score>v.peek().score&&v.replaceTop(O)),m%1e3==0&&Date.now()-d>=10)))return void(e?r(T):setTimeout(T))}if(0===w)return a(i);for(var M=new Array(w),I=w-1;I>=0;--I)M[I]=v.poll();M.total=w+k,a(M)}e?r(T):T()}));return a.cancel=function(){s=!0},a},highlight:function(e,t,n){if(null===e)return null;void 0===t&&(t="<b>"),void 0===n&&(n="</b>");for(var r="",i=0,o=!1,s=e.target,a=s.length,u=e.indexes,l=0;l<a;++l){var c=s[l];if(u[i]===l){if(o||(o=!0,r+=t),++i===u.length){r+=c+n+s.substr(l+1);break}}else o&&(o=!1,r+=n);r+=c}return r},prepare:function(e){if(e)return{target:e,_targetLowerCodes:g.prepareLowerCodes(e),_nextBeginningIndexes:null,score:null,indexes:null,obj:null}},prepareSlow:function(e){if(e)return{target:e,_targetLowerCodes:g.prepareLowerCodes(e),_nextBeginningIndexes:g.prepareNextBeginningIndexes(e),score:null,indexes:null,obj:null}},prepareSearch:function(e){if(e)return g.prepareLowerCodes(e)},getPrepared:function(e){if(e.length>999)return g.prepare(e);var n=t.get(e);return void 0!==n||(n=g.prepare(e),t.set(e,n)),n},getPreparedSearch:function(e){if(e.length>999)return g.prepareSearch(e);var t=n.get(e);return void 0!==t||(t=g.prepareSearch(e),n.set(e,t)),t},algorithm:function(e,t,n){for(var r=t._targetLowerCodes,i=e.length,a=r.length,u=0,l=0,c=0,f=0;;){if(n===r[l]){if(o[f++]=l,++u===i)break;n=e[0===c?u:c===u?u+1:c===u-1?u-1:u]}if(++l>=a)for(;;){if(u<=1)return null;if(0===c){if(n===e[--u])continue;c=u}else{if(1===c)return null;if((n=e[1+(u=--c)])===e[u])continue}l=o[(f=u)-1]+1;break}}u=0;var d=0,p=!1,h=0,v=t._nextBeginningIndexes;null===v&&(v=t._nextBeginningIndexes=g.prepareNextBeginningIndexes(t.target));var m=l=0===o[0]?0:v[o[0]-1];if(l!==a)for(;;)if(l>=a){if(u<=0){if(++d>i-2)break;if(e[d]===e[d+1])continue;l=m;continue}--u,l=v[s[--h]]}else if(e[0===d?u:d===u?u+1:d===u-1?u-1:u]===r[l]){if(s[h++]=l,++u===i){p=!0;break}++l}else l=v[l];if(p)var y=s,b=h;else y=o,b=f;for(var x=0,w=-1,k=0;k<i;++k)w!==(l=y[k])-1&&(x-=l),w=l;for(p?0!==d&&(x+=-20):(x*=1e3,0!==c&&(x+=-20)),x-=a-i,t.score=x,t.indexes=new Array(b),k=b-1;k>=0;--k)t.indexes[k]=y[k];return t},algorithmNoTypo:function(e,t,n){for(var r=t._targetLowerCodes,i=e.length,a=r.length,u=0,l=0,c=0;;){if(n===r[l]){if(o[c++]=l,++u===i)break;n=e[u]}if(++l>=a)return null}u=0;var f=!1,d=0,p=t._nextBeginningIndexes;if(null===p&&(p=t._nextBeginningIndexes=g.prepareNextBeginningIndexes(t.target)),(l=0===o[0]?0:p[o[0]-1])!==a)for(;;)if(l>=a){if(u<=0)break;--u,l=p[s[--d]]}else if(e[u]===r[l]){if(s[d++]=l,++u===i){f=!0;break}++l}else l=p[l];if(f)var h=s,v=d;else h=o,v=c;for(var m=0,y=-1,b=0;b<i;++b)y!==(l=h[b])-1&&(m-=l),y=l;for(f||(m*=1e3),m-=a-i,t.score=m,t.indexes=new Array(v),b=v-1;b>=0;--b)t.indexes[b]=h[b];return t},prepareLowerCodes:function(e){for(var t=e.length,n=[],r=e.toLowerCase(),i=0;i<t;++i)n[i]=r.charCodeAt(i);return n},prepareBeginningIndexes:function(e){for(var t=e.length,n=[],r=0,i=!1,o=!1,s=0;s<t;++s){var a=e.charCodeAt(s),u=a>=65&&a<=90,l=u||a>=97&&a<=122||a>=48&&a<=57,c=u&&!i||!o||!l;i=u,o=l,c&&(n[r++]=s)}return n},prepareNextBeginningIndexes:function(e){for(var t=e.length,n=g.prepareBeginningIndexes(e),r=[],i=n[0],o=0,s=0;s<t;++s)i>s?r[s]=i:(i=n[++o],r[s]=void 0===i?t:i);return r},cleanup:u,new:a};return g}()},e.exports?e.exports=n():t.fuzzysort=n()})),De={passedTests:0,failedTests:0,skippedTests:0,todoTests:0};function Oe(e){return e?(e+="").replace(/['"<>&]/g,(function(e){switch(e){case"'":return"&#039;";case'"':return"&quot;";case"<":return"&lt;";case">":return"&gt;";case"&":return"&amp;"}})):""}!function(){if(v&&w){var e=Te.config,t=[],n=!1,r=Object.prototype.hasOwnProperty,i=E({filter:void 0,module:void 0,moduleId:void 0,testId:void 0});Te.begin((function(){I()})),Te.done((function(t){var n,r,i,o=b("qunit-banner"),s=b("qunit-tests"),a=b("qunit-abort-tests-button"),u=[De.passedTests+De.skippedTests+De.todoTests+De.failedTests," tests completed in ",t.runtime," milliseconds, with ",De.failedTests," failed, ",De.skippedTests," skipped, and ",De.todoTests," todo.<br />","<span class='passed'>",t.passed,"</span> assertions of <span class='total'>",t.total,"</span> passed, <span class='failed'>",t.failed,"</span> failed."].join("");if(a&&a.disabled){u="Tests aborted after "+t.runtime+" milliseconds.";for(var l=0;l<s.children.length;l++)""!==(n=s.children[l]).className&&"running"!==n.className||(n.className="aborted",i=n.getElementsByTagName("ol")[0],(r=w.createElement("li")).className="fail",r.innerHTML="Test aborted.",i.appendChild(r))}!o||a&&!1!==a.disabled||(o.className=De.failedTests?"qunit-fail":"qunit-pass"),a&&a.parentNode.removeChild(a),s&&(b("qunit-testresult-display").innerHTML=u),e.altertitle&&w.title&&(w.title=[De.failedTests?"✖":"✔",w.title.replace(/^[\u2714\u2716] /i,"")].join(" ")),e.scrolltop&&v.scrollTo&&v.scrollTo(0,0)})),Te.testStart((function(t){var n,r,i,o,s,a,u,l,c,f;i=t.name,o=t.testId,s=t.module,(f=b("qunit-tests"))&&((a=w.createElement("strong")).innerHTML=L(i,s),(u=w.createElement("a")).innerHTML="Rerun",u.href=E({testId:o}),(l=w.createElement("li")).appendChild(a),l.appendChild(u),l.id="qunit-test-output-"+o,(c=w.createElement("ol")).className="qunit-assert-list",l.appendChild(c),f.appendChild(l)),(n=b("qunit-testresult-display"))&&(h(n,"running"),r=Te.config.reorder&&t.previousFailure,n.innerHTML=[r?"Rerunning previously failed test: <br />":"Running: <br />",L(t.name,t.module),_(j()-e.started,De,ce.count)].join(""))})),Te.log((function(e){var t,n,i,o,s,a,u=!1,l=b("qunit-test-output-"+e.testId);l&&(i="<span class='test-message'>"+(i=Oe(e.message)||(e.result?"okay":"failed"))+"</span>",i+="<span class='runtime'>@ "+e.runtime+" ms</span>",!e.result&&r.call(e,"expected")?(o=e.negative?"NOT "+Te.dump.parse(e.expected):Te.dump.parse(e.expected),s=Te.dump.parse(e.actual),i+="<table><tr class='test-expected'><th>Expected: </th><td><pre>"+Oe(o)+"</pre></td></tr>",s!==o?(i+="<tr class='test-actual'><th>Result: </th><td><pre>"+Oe(s)+"</pre></td></tr>","number"==typeof e.actual&&"number"==typeof e.expected?isNaN(e.actual)||isNaN(e.expected)||(u=!0,a=((a=e.actual-e.expected)>0?"+":"")+a):"boolean"!=typeof e.actual&&"boolean"!=typeof e.expected&&(u=P(a=Te.diff(o,s)).length!==P(o).length+P(s).length),u&&(i+="<tr class='test-diff'><th>Diff: </th><td><pre>"+a+"</pre></td></tr>")):-1!==o.indexOf("[object Array]")||-1!==o.indexOf("[object Object]")?i+="<tr class='test-message'><th>Message: </th><td>Diff suppressed as the depth of object is more than current max depth ("+Te.config.maxDepth+").<p>Hint: Use <code>QUnit.dump.maxDepth</code> to  run with a higher max depth or <a href='"+Oe(E({maxDepth:-1}))+"'>Rerun</a> without max depth.</p></td></tr>":i+="<tr class='test-message'><th>Message: </th><td>Diff suppressed as the expected and actual results have an equivalent serialization</td></tr>",e.source&&(i+="<tr class='test-source'><th>Source: </th><td><pre>"+Oe(e.source)+"</pre></td></tr>"),i+="</table>"):!e.result&&e.source&&(i+="<table><tr class='test-source'><th>Source: </th><td><pre>"+Oe(e.source)+"</pre></td></tr></table>"),t=l.getElementsByTagName("ol")[0],(n=w.createElement("li")).className=e.result?"pass":"fail",n.innerHTML=i,t.appendChild(n))})),Te.testDone((function(r){var i,o,s,a,u,c,f,d,p,v=b("qunit-tests"),y=b("qunit-test-output-"+r.testId);if(v&&y){m(y,"running"),a=r.failed>0?"failed":r.todo?"todo":r.skipped?"skipped":"passed",s=y.getElementsByTagName("ol")[0],u=r.passed,c=r.failed;var x=r.failed>0?r.todo:!r.todo;if(x?h(s,"qunit-collapsed"):e.collapse&&(n?h(s,"qunit-collapsed"):n=!0),f=c?"<b class='failed'>"+c+"</b>, <b class='passed'>"+u+"</b>, ":"",(i=y.firstChild).innerHTML+=" <b class='counts'>("+f+r.assertions.length+")</b>",r.skipped)De.skippedTests++,y.className="skipped",(d=w.createElement("em")).className="qunit-skipped-label",d.innerHTML="skipped",y.insertBefore(d,i);else{if(l(i,"click",(function(){g(s,"qunit-collapsed")})),y.className=x?"pass":"fail",r.todo){var k=w.createElement("em");k.className="qunit-todo-label",k.innerHTML="todo",y.className+=" todo",y.insertBefore(k,i)}(o=w.createElement("span")).className="runtime",o.innerHTML=r.runtime+" ms",y.insertBefore(o,s),x?r.todo?De.todoTests++:De.passedTests++:De.failedTests++}r.source&&((p=w.createElement("p")).innerHTML="<strong>Source: </strong>"+Oe(r.source),h(p,"qunit-source"),x&&h(p,"qunit-collapsed"),l(i,"click",(function(){g(p,"qunit-collapsed")})),y.appendChild(p)),e.hidepassed&&("passed"===a||r.skipped)&&(t.push(y),v.removeChild(y))}}));var o,s=(o=v.phantom)&&o.version&&o.version.major>0;s&&y.warn("Support for PhantomJS is deprecated and will be removed in QUnit 3.0."),s||"complete"!==w.readyState?l(v,"load",Te.load):Te.load();var a=v.onerror;v.onerror=function(e,t,n,r,i){var o=!1;if(a){for(var s=arguments.length,u=new Array(s>5?s-5:0),l=5;l<s;l++)u[l-5]=arguments[l];o=a.call.apply(a,[this,e,t,n,r,i].concat(u))}if(!0!==o){var c={message:e,fileName:t,lineNumber:n};i&&i.stack&&(c.stacktrace=te(i,0)),o=Te.onError(c)}return o},v.addEventListener("unhandledrejection",(function(e){Te.onUnhandledRejection(e.reason)}))}function u(e){return"function"==typeof e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}function l(e,t,n){e.addEventListener(t,n,!1)}function c(e,t,n){e.removeEventListener(t,n,!1)}function f(e,t,n){for(var r=e.length;r--;)l(e[r],t,n)}function d(e,t){return(" "+e.className+" ").indexOf(" "+t+" ")>=0}function h(e,t){d(e,t)||(e.className+=(e.className?" ":"")+t)}function g(e,t,n){n||void 0===n&&!d(e,t)?h(e,t):m(e,t)}function m(e,t){for(var n=" "+e.className+" ";n.indexOf(" "+t+" ")>=0;)n=n.replace(" "+t+" "," ");e.className=u(n)}function b(e){return w.getElementById&&w.getElementById(e)}function x(){var e=b("qunit-abort-tests-button");return e&&(e.disabled=!0,e.innerHTML="Aborting..."),Te.config.queue.length=0,!1}function T(e){var t=b("qunit-filter-input");return t.value=u(t.value),S(),e&&e.preventDefault&&e.preventDefault(),!1}function C(){var n,r,i,o=this,s={};if(r="selectedIndex"in o?o.options[o.selectedIndex].value||void 0:o.checked?o.defaultValue||!0:void 0,s[o.name]=r,n=E(s),"hidepassed"===o.name&&"replaceState"in v.history){if(Te.urlParams[o.name]=r,e[o.name]=r||!1,i=b("qunit-tests")){var a=i.children.length,u=i.children;if(o.checked){for(var l=0;l<a;l++){var c=u[l],f=c?c.className:"",d=f.indexOf("pass")>-1,h=f.indexOf("skipped")>-1;(d||h)&&t.push(c)}var g,m=function(e,t){var n;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(n=p(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var r=0,i=function(){};return{s:i,n:function(){return r>=e.length?{done:!0}:{done:!1,value:e[r++]}},e:function(e){throw e},f:i}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){n=e[Symbol.iterator]()},n:function(){var e=n.next();return s=e.done,e},e:function(e){a=!0,o=e},f:function(){try{s||null==n.return||n.return()}finally{if(a)throw o}}}}(t);try{for(m.s();!(g=m.n()).done;){var y=g.value;i.removeChild(y)}}catch(e){m.e(e)}finally{m.f()}}else for(;null!=(c=t.pop());)i.appendChild(c)}v.history.replaceState(null,"",n)}else v.location=n}function E(e){var t,n,i,o="?",s=v.location;for(t in e=M(M({},Te.urlParams),e))if(r.call(e,t)&&void 0!==e[t])for(n=[].concat(e[t]),i=0;i<n.length;i++)o+=encodeURIComponent(t),!0!==n[i]&&(o+="="+encodeURIComponent(n[i])),o+="&";return s.protocol+"//"+s.host+s.pathname+o.slice(0,-1)}function S(){var e,t=[],n=b("qunit-modulefilter-dropdown-list").getElementsByTagName("input"),r=b("qunit-filter-input").value;for(e=0;e<n.length;e++)n[e].checked&&t.push(n[e].value);v.location=E({filter:""===r?void 0:r,moduleId:0===t.length?void 0:t,module:void 0,testId:void 0})}function N(){var t=w.createElement("span");return t.innerHTML=function(){var t,n,i,o,s,a=!1,u=e.urlConfig,l="";for(t=0;t<u.length;t++)if("string"==typeof(i=e.urlConfig[t])&&(i={id:i,label:i}),o=Oe(i.id),s=Oe(i.tooltip),i.value&&"string"!=typeof i.value){if(l+="<label for='qunit-urlconfig-"+o+"' title='"+s+"'>"+i.label+": </label><select id='qunit-urlconfig-"+o+"' name='"+o+"' title='"+s+"'><option></option>",Te.is("array",i.value))for(n=0;n<i.value.length;n++)l+="<option value='"+(o=Oe(i.value[n]))+"'"+(e[i.id]===i.value[n]?(a=!0)&&" selected='selected'":"")+">"+o+"</option>";else for(n in i.value)r.call(i.value,n)&&(l+="<option value='"+Oe(n)+"'"+(e[i.id]===n?(a=!0)&&" selected='selected'":"")+">"+Oe(i.value[n])+"</option>");e[i.id]&&!a&&(l+="<option value='"+(o=Oe(e[i.id]))+"' selected='selected' disabled='disabled'>"+o+"</option>"),l+="</select>"}else l+="<label for='qunit-urlconfig-"+o+"' title='"+s+"'><input id='qunit-urlconfig-"+o+"' name='"+o+"' type='checkbox'"+(i.value?" value='"+Oe(i.value)+"'":"")+(e[i.id]?" checked='checked'":"")+" title='"+s+"' />"+Oe(i.label)+"</label>";return l}(),h(t,"qunit-url-config"),f(t.getElementsByTagName("input"),"change",C),f(t.getElementsByTagName("select"),"change",C),t}function q(t){var n,r,i="";for(n=0;n<t.length;n++)""!==t[n].name&&(i+="<li><label class='clickable"+((r=e.moduleId.indexOf(t[n].moduleId)>-1)?" checked":"")+"'><input type='checkbox' value='"+t[n].moduleId+"'"+(r?" checked='checked'":"")+" />"+Oe(t[n].name)+"</label></li>");return i}function A(){var t,n,r,i=w.createElement("form"),o=w.createElement("label"),s=w.createElement("input"),a=w.createElement("div"),u=w.createElement("span"),f=w.createElement("button"),d=w.createElement("button"),p=w.createElement("label"),h=w.createElement("input"),y=w.createElement("ul"),b=!1;function x(){function e(t){var n=i.contains(t.target);27!==t.keyCode&&n||(27===t.keyCode&&n&&s.focus(),a.style.display="none",c(w,"click",e),c(w,"keydown",e),s.value="",k())}"none"===a.style.display&&(a.style.display="block",l(w,"click",e),l(w,"keydown",e))}function k(){v.clearTimeout(r),r=v.setTimeout((function(){var t=function(t){return""===t?e.modules:Ae.go(t,e.modules,{key:"namePrepared",threshold:-1e4}).map((function(e){return e.obj}))}(s.value.toLowerCase());y.innerHTML=q(t)}),200)}function C(e){var r,i,o=e&&e.target||h,a=y.getElementsByTagName("input"),u=[];for(g(o.parentNode,"checked",o.checked),b=!1,o.checked&&o!==h&&(h.checked=!1,m(h.parentNode,"checked")),r=0;r<a.length;r++)i=a[r],e?o===h&&o.checked&&(i.checked=!1,m(i.parentNode,"checked")):g(i.parentNode,"checked",i.checked),b=b||i.checked!==i.defaultChecked,i.checked&&u.push(i.parentNode.textContent);t.style.display=n.style.display=b?"":"none",s.placeholder=u.join(", ")||h.parentNode.textContent,s.title="Type to filter list. Current selection:\n"+(u.join("\n")||h.parentNode.textContent)}return s.id="qunit-modulefilter-search",s.autocomplete="off",l(s,"input",k),l(s,"input",x),l(s,"focus",x),l(s,"click",x),e.modules.forEach((function(e){return e.namePrepared=Ae.prepare(e.name)})),o.id="qunit-modulefilter-search-container",o.innerHTML="Module: ",o.appendChild(s),f.textContent="Apply",f.style.display="none",d.textContent="Reset",d.type="reset",d.style.display="none",h.type="checkbox",h.checked=0===e.moduleId.length,p.className="clickable",e.moduleId.length&&(p.className="checked"),p.appendChild(h),p.appendChild(w.createTextNode("All modules")),u.id="qunit-modulefilter-actions",u.appendChild(f),u.appendChild(d),u.appendChild(p),t=u.firstChild,n=t.nextSibling,l(t,"click",S),y.id="qunit-modulefilter-dropdown-list",y.innerHTML=q(e.modules),a.id="qunit-modulefilter-dropdown",a.style.display="none",a.appendChild(u),a.appendChild(y),l(a,"change",C),C(),i.id="qunit-modulefilter",i.appendChild(o),i.appendChild(a),l(i,"submit",T),l(i,"reset",(function(){v.setTimeout(C)})),i}function D(){var t,n,r,i,o=w.createElement("span");return o.id="qunit-toolbar-filters",o.appendChild((t=w.createElement("form"),n=w.createElement("label"),r=w.createElement("input"),i=w.createElement("button"),h(t,"qunit-filter"),n.innerHTML="Filter: ",r.type="text",r.value=e.filter||"",r.name="filter",r.id="qunit-filter-input",i.innerHTML="Go",n.appendChild(r),t.appendChild(n),t.appendChild(w.createTextNode(" ")),t.appendChild(i),l(t,"submit",T),t)),o.appendChild(A()),o}function O(){var e,t,n=b("qunit-tests"),r=b("qunit-testresult");r&&r.parentNode.removeChild(r),n&&(n.innerHTML="",(r=w.createElement("p")).id="qunit-testresult",r.className="result",n.parentNode.insertBefore(r,n),r.innerHTML='<div id="qunit-testresult-display">Running...<br />&#160;</div><div id="qunit-testresult-controls"></div><div class="clearfix"></div>',e=b("qunit-testresult-controls")),e&&e.appendChild(((t=w.createElement("button")).id="qunit-abort-tests-button",t.innerHTML="Abort",l(t,"click",x),t))}function I(){var e,t,n,r,o,s=b("qunit");s&&(s.setAttribute("role","main"),s.innerHTML="<h1 id='qunit-header'>"+Oe(w.title)+"</h1><h2 id='qunit-banner'></h2><div id='qunit-testrunner-toolbar' role='navigation'></div>"+((!(e=Te.config.testId)||e.length<=0?"":"<div id='qunit-filteredTest'>Rerunning selected tests: "+Oe(e.join(", "))+" <a id='qunit-clearFilter' href='"+Oe(i)+"'>Run all tests</a></div>")+"<h2 id='qunit-userAgent'></h2><ol id='qunit-tests'></ol>")),(t=b("qunit-header"))&&(t.innerHTML="<a href='"+Oe(i)+"'>"+t.innerHTML+"</a> "),(n=b("qunit-banner"))&&(n.className=""),O(),(r=b("qunit-userAgent"))&&(r.innerHTML="",r.appendChild(w.createTextNode("QUnit "+Te.version+"; "+k.userAgent))),(o=b("qunit-testrunner-toolbar"))&&(o.appendChild(N()),o.appendChild(D()),o.appendChild(w.createElement("div")).className="clearfix")}function L(e,t){var n="";return t&&(n="<span class='module-name'>"+Oe(t)+"</span>: "),n+="<span class='test-name'>"+Oe(e)+"</span>"}function _(e,t,n){return["<br />",t.passedTests+t.skippedTests+t.todoTests+t.failedTests," / ",n," tests completed in ",e," milliseconds, with ",t.failedTests," failed, ",t.skippedTests," skipped, and ",t.todoTests," todo."].join("")}function P(e){return e.replace(/<\/?[^>]+(>|$)/g,"").replace(/&quot;/g,"").replace(/\s+/g,"")}}(),Te.diff=function(){function e(){}var t=-1,n=Object.prototype.hasOwnProperty;return e.prototype.DiffMain=function(e,t,n){var r,i,o,s,a,u;if(r=(new Date).getTime()+1e3,null===e||null===t)throw new Error("Null input. (DiffMain)");return e===t?e?[[0,e]]:[]:(void 0===n&&(n=!0),i=n,o=this.diffCommonPrefix(e,t),s=e.substring(0,o),e=e.substring(o),t=t.substring(o),o=this.diffCommonSuffix(e,t),a=e.substring(e.length-o),e=e.substring(0,e.length-o),t=t.substring(0,t.length-o),u=this.diffCompute(e,t,i,r),s&&u.unshift([0,s]),a&&u.push([0,a]),this.diffCleanupMerge(u),u)},e.prototype.diffCleanupEfficiency=function(e){var n,r,i,o,s,a,u,l,c;for(n=!1,r=[],i=0,o=null,s=0,a=!1,u=!1,l=!1,c=!1;s<e.length;)0===e[s][0]?(e[s][1].length<4&&(l||c)?(r[i++]=s,a=l,u=c,o=e[s][1]):(i=0,o=null),l=c=!1):(e[s][0]===t?c=!0:l=!0,o&&(a&&u&&l&&c||o.length<2&&a+u+l+c===3)&&(e.splice(r[i-1],0,[t,o]),e[r[i-1]+1][0]=1,i--,o=null,a&&u?(l=c=!0,i=0):(s=--i>0?r[i-1]:-1,l=c=!1),n=!0)),s++;n&&this.diffCleanupMerge(e)},e.prototype.diffPrettyHtml=function(e){var n,r,i,o=[];for(i=0;i<e.length;i++)switch(n=e[i][0],r=e[i][1],n){case 1:o[i]="<ins>"+Oe(r)+"</ins>";break;case t:o[i]="<del>"+Oe(r)+"</del>";break;case 0:o[i]="<span>"+Oe(r)+"</span>"}return o.join("")},e.prototype.diffCommonPrefix=function(e,t){var n,r,i,o;if(!e||!t||e.charAt(0)!==t.charAt(0))return 0;for(i=0,n=r=Math.min(e.length,t.length),o=0;i<n;)e.substring(o,n)===t.substring(o,n)?o=i=n:r=n,n=Math.floor((r-i)/2+i);return n},e.prototype.diffCommonSuffix=function(e,t){var n,r,i,o;if(!e||!t||e.charAt(e.length-1)!==t.charAt(t.length-1))return 0;for(i=0,n=r=Math.min(e.length,t.length),o=0;i<n;)e.substring(e.length-n,e.length-o)===t.substring(t.length-n,t.length-o)?o=i=n:r=n,n=Math.floor((r-i)/2+i);return n},e.prototype.diffCompute=function(e,n,r,i){var o,s,a,u,l,c,f,d,p,h,g,v;return e?n?(s=e.length>n.length?e:n,a=e.length>n.length?n:e,-1!==(u=s.indexOf(a))?(o=[[1,s.substring(0,u)],[0,a],[1,s.substring(u+a.length)]],e.length>n.length&&(o[0][0]=o[2][0]=t),o):1===a.length?[[t,e],[1,n]]:(l=this.diffHalfMatch(e,n))?(c=l[0],d=l[1],f=l[2],p=l[3],h=l[4],g=this.DiffMain(c,f,r,i),v=this.DiffMain(d,p,r,i),g.concat([[0,h]],v)):r&&e.length>100&&n.length>100?this.diffLineMode(e,n,i):this.diffBisect(e,n,i)):[[t,e]]:[[1,n]]},e.prototype.diffHalfMatch=function(e,t){var n,r,i,o,s,a,u,l,c,f;if(n=e.length>t.length?e:t,r=e.length>t.length?t:e,n.length<4||2*r.length<n.length)return null;function d(e,t,n){var r,o,s,a,u,l,c,f,d;for(r=e.substring(n,n+Math.floor(e.length/4)),o=-1,s="";-1!==(o=t.indexOf(r,o+1));)a=i.diffCommonPrefix(e.substring(n),t.substring(o)),u=i.diffCommonSuffix(e.substring(0,n),t.substring(0,o)),s.length<u+a&&(s=t.substring(o-u,o)+t.substring(o,o+a),l=e.substring(0,n-u),c=e.substring(n+a),f=t.substring(0,o-u),d=t.substring(o+a));return 2*s.length>=e.length?[l,c,f,d,s]:null}return i=this,l=d(n,r,Math.ceil(n.length/4)),c=d(n,r,Math.ceil(n.length/2)),l||c?(f=c?l&&l[4].length>c[4].length?l:c:l,e.length>t.length?(o=f[0],u=f[1],a=f[2],s=f[3]):(a=f[0],s=f[1],o=f[2],u=f[3]),[o,u,a,s,f[4]]):null},e.prototype.diffLineMode=function(e,n,r){var i,o,s,a,u,l,c,f,d;for(e=(i=this.diffLinesToChars(e,n)).chars1,n=i.chars2,s=i.lineArray,o=this.DiffMain(e,n,!1,r),this.diffCharsToLines(o,s),this.diffCleanupSemantic(o),o.push([0,""]),a=0,l=0,u=0,f="",c="";a<o.length;){switch(o[a][0]){case 1:u++,c+=o[a][1];break;case t:l++,f+=o[a][1];break;case 0:if(l>=1&&u>=1){for(o.splice(a-l-u,l+u),a=a-l-u,d=(i=this.DiffMain(f,c,!1,r)).length-1;d>=0;d--)o.splice(a,0,i[d]);a+=i.length}u=0,l=0,f="",c=""}a++}return o.pop(),o},e.prototype.diffBisect=function(e,n,r){var i,o,s,a,u,l,c,f,d,p,h,g,v,m,y,b,x,w,k,T,C,E,S;for(i=e.length,o=n.length,a=s=Math.ceil((i+o)/2),u=2*s,l=new Array(u),c=new Array(u),f=0;f<u;f++)l[f]=-1,c[f]=-1;for(l[a+1]=0,c[a+1]=0,p=(d=i-o)%2!=0,h=0,g=0,v=0,m=0,C=0;C<s&&!((new Date).getTime()>r);C++){for(E=-C+h;E<=C-g;E+=2){for(b=a+E,k=(x=E===-C||E!==C&&l[b-1]<l[b+1]?l[b+1]:l[b-1]+1)-E;x<i&&k<o&&e.charAt(x)===n.charAt(k);)x++,k++;if(l[b]=x,x>i)g+=2;else if(k>o)h+=2;else if(p&&(y=a+d-E)>=0&&y<u&&-1!==c[y]&&x>=(w=i-c[y]))return this.diffBisectSplit(e,n,x,k,r)}for(S=-C+v;S<=C-m;S+=2){for(y=a+S,T=(w=S===-C||S!==C&&c[y-1]<c[y+1]?c[y+1]:c[y-1]+1)-S;w<i&&T<o&&e.charAt(i-w-1)===n.charAt(o-T-1);)w++,T++;if(c[y]=w,w>i)m+=2;else if(T>o)v+=2;else if(!p&&(b=a+d-S)>=0&&b<u&&-1!==l[b]&&(k=a+(x=l[b])-b,x>=(w=i-w)))return this.diffBisectSplit(e,n,x,k,r)}}return[[t,e],[1,n]]},e.prototype.diffBisectSplit=function(e,t,n,r,i){var o,s,a,u,l,c;return o=e.substring(0,n),a=t.substring(0,r),s=e.substring(n),u=t.substring(r),l=this.DiffMain(o,a,!1,i),c=this.DiffMain(s,u,!1,i),l.concat(c)},e.prototype.diffCleanupSemantic=function(e){var n,r,i,o,s,a,u,l,c,f,d,p,h;for(n=!1,r=[],i=0,o=null,s=0,l=0,c=0,a=0,u=0;s<e.length;)0===e[s][0]?(r[i++]=s,l=a,c=u,a=0,u=0,o=e[s][1]):(1===e[s][0]?a+=e[s][1].length:u+=e[s][1].length,o&&o.length<=Math.max(l,c)&&o.length<=Math.max(a,u)&&(e.splice(r[i-1],0,[t,o]),e[r[i-1]+1][0]=1,i--,s=--i>0?r[i-1]:-1,l=0,c=0,a=0,u=0,o=null,n=!0)),s++;for(n&&this.diffCleanupMerge(e),s=1;s<e.length;)e[s-1][0]===t&&1===e[s][0]&&(f=e[s-1][1],d=e[s][1],(p=this.diffCommonOverlap(f,d))>=(h=this.diffCommonOverlap(d,f))?(p>=f.length/2||p>=d.length/2)&&(e.splice(s,0,[0,d.substring(0,p)]),e[s-1][1]=f.substring(0,f.length-p),e[s+1][1]=d.substring(p),s++):(h>=f.length/2||h>=d.length/2)&&(e.splice(s,0,[0,f.substring(0,h)]),e[s-1][0]=1,e[s-1][1]=d.substring(0,d.length-h),e[s+1][0]=t,e[s+1][1]=f.substring(h),s++),s++),s++},e.prototype.diffCommonOverlap=function(e,t){var n,r,i,o,s,a,u;if(n=e.length,r=t.length,0===n||0===r)return 0;if(n>r?e=e.substring(n-r):n<r&&(t=t.substring(0,n)),i=Math.min(n,r),e===t)return i;for(o=0,s=1;;){if(a=e.substring(i-s),-1===(u=t.indexOf(a)))return o;s+=u,0!==u&&e.substring(i-s)!==t.substring(0,s)||(o=s,s++)}},e.prototype.diffLinesToChars=function(e,t){var r,i;function o(e){var t,o,s,a,u;for(t="",o=0,s=-1,a=r.length;s<e.length-1;)-1===(s=e.indexOf("\n",o))&&(s=e.length-1),u=e.substring(o,s+1),o=s+1,n.call(i,u)?t+=String.fromCharCode(i[u]):(t+=String.fromCharCode(a),i[u]=a,r[a++]=u);return t}return i={},(r=[])[0]="",{chars1:o(e),chars2:o(t),lineArray:r}},e.prototype.diffCharsToLines=function(e,t){var n,r,i,o;for(n=0;n<e.length;n++){for(r=e[n][1],i=[],o=0;o<r.length;o++)i[o]=t[r.charCodeAt(o)];e[n][1]=i.join("")}},e.prototype.diffCleanupMerge=function(e){var n,r,i,o,s,a,u,l;for(e.push([0,""]),n=0,r=0,i=0,s="",o="";n<e.length;)switch(e[n][0]){case 1:i++,o+=e[n][1],n++;break;case t:r++,s+=e[n][1],n++;break;case 0:r+i>1?(0!==r&&0!==i&&(0!==(a=this.diffCommonPrefix(o,s))&&(n-r-i>0&&0===e[n-r-i-1][0]?e[n-r-i-1][1]+=o.substring(0,a):(e.splice(0,0,[0,o.substring(0,a)]),n++),o=o.substring(a),s=s.substring(a)),0!==(a=this.diffCommonSuffix(o,s))&&(e[n][1]=o.substring(o.length-a)+e[n][1],o=o.substring(0,o.length-a),s=s.substring(0,s.length-a))),0===r?e.splice(n-i,r+i,[1,o]):0===i?e.splice(n-r,r+i,[t,s]):e.splice(n-r-i,r+i,[t,s],[1,o]),n=n-r-i+(r?1:0)+(i?1:0)+1):0!==n&&0===e[n-1][0]?(e[n-1][1]+=e[n][1],e.splice(n,1)):n++,i=0,r=0,s="",o=""}for(""===e[e.length-1][1]&&e.pop(),u=!1,n=1;n<e.length-1;)0===e[n-1][0]&&0===e[n+1][0]&&((l=e[n][1]).substring(l.length-e[n-1][1].length)===e[n-1][1]?(e[n][1]=e[n-1][1]+e[n][1].substring(0,e[n][1].length-e[n-1][1].length),e[n+1][1]=e[n-1][1]+e[n+1][1],e.splice(n-1,1),u=!0):l.substring(0,e[n+1][1].length)===e[n+1][1]&&(e[n-1][1]+=e[n+1][1],e[n][1]=e[n][1].substring(e[n+1][1].length)+e[n+1][1],e.splice(n+1,1),u=!0)),n++;u&&this.diffCleanupMerge(e)},function(t,n){var r,i;return i=(r=new e).DiffMain(t,n),r.diffCleanupEfficiency(i),r.diffPrettyHtml(i)}}()}()}).call(this,n(43),n(262).setImmediate,n(63)(e))}});